%==========================================================================
% MODEL_PATHS_SCC_1DATE_vFINAL.m
%==========================================================================
% Date last updated: 9 October 2015

clear all; close all; clc;

 
%==========================================================================
%==========================================================================
%==========================================================================   
 % CHOICE OF THE DAMAGE FUNCTION SPECIFICATION
 
    QUADRATIC  = 1;  
        % 1 if choice of quadratic function, 0 if use of alternative damage function based on Weitzman 2012  
        % If QUADRATIC = 1, this means the damage function is as in
        % DICE-2007 (NOT DICE-2013): DAMAGES = YGROSS(t)* [AD1*TATM(t)+AD2*TATM(t)^2]/[1+(AD1*TATM(t)+AD2*TATM(t)^2)^10];
        
    WEITZMAN   = 0;  
        % 1 if choice of alternative damage function based on Weitzman 2012, 0 if quadratic
        % If WEITZMAN = 1, this means the damage function is as in
        % WEITZMAN 2012: DAMAGES = YGROSS(t)-YGROSS(t)/(1+(AW2*TATM(t))^2+(AW7*TATM(t))^AWGAMMA);
    
        % Check that the Boolean indicators for the damage function
        % specification are correct
        temp = QUADRATIC + WEITZMAN;
        ErrorMessage=['Error: check choice of damage function specification'];
        if ne(temp,1) 
            disp(ErrorMessage);break;
        end;
%--------------------------------------------------------------------------
%--------------------------------------------------------------------------
%--------------------------------------------------------------------------
% DISCOUNTING

year_SCC = 2015;   

% Constant discount rate
rate_vect = [0:0.01:0.05]; 

% Ramsey discounting
rho_vect = [0 0.01 0.015];
eta_vect = [0 0.5 1.0 1.45 1.5 2.0 2.5 3.0 3.5 4.0 4.5 5.0];
 

%--------------------------------------------------------------------------
%--------------------------------------------------------------------------
%--------------------------------------------------------------------------
% MC ITERATIONS
    MC         = 1; % number of MC simulations
    MC_max     = 5; % number of MC simulations which will be written in Excel file
 
% PCF switch   
    PCF        = 1; % replace 1 by 0 if you want to remove the PCF                   
        
% End date
    end_date   = 2300;
    nb_periods = (end_date-2010)/5+1;
    
    
%--------------------------------------------------------------------------
%--------------------------------------------------------------------------
%--------------------------------------------------------------------------
% IMPORT MIU
    
InputFile = [pwd,'\INPUT_MIU.xlsx'];
MIU = xlsread(InputFile,'MIU'); 
MIU = MIU(:,2); 
temp = nb_periods+1;
MIU = MIU(1:temp);
MIU = round(MIU*1e3)/1e3;

%--------------------------------------------------------------------------
%--------------------------------------------------------------------------
%--------------------------------------------------------------------------
% IMPORT S
    
InputFile = [pwd,'\INPUT_S.xlsx'];
S = xlsread(InputFile,'SAVINGS'); 
S = S(:,2);  
S = S(1:temp);
S = round(S*1e3)/1e3;
  

%==========================================================================
%==========================================================================
%==========================================================================   
% PARAMETERS OF THE MODEL

%--------------------------------------------------------------------------
% DICE-2013 FIXED PARAMETERS
%--------------------------------------------------------------------------
iterations  = MC;
years       = [2010:5:end_date]'; % (NB: model is based on a 5 year time step)

count       = 0;
starttime   = cputime;
      
% Time step
TSTEP       = 5;         % Years per period

% Population
POP0        = 6838;      % Initial population (in millions) 
POPADJ      = 0.134490;  % Growth rate to calibrate to 2050 pop projection

% Technology
GAMMA       = 0.300;     % Capital elasticity in production function
DK          = 0.100;     % Depreciation rate on capital per year
Q0          = 66.950;    % 2005 world gross output trill 2005 US dollars   
K0          = 135;       % 2005 value capital trill 2005 US dollars
AL0         = 3.7976214; % Initial level of total factor productivity
DELA        = 0.006;     % Decline rate of technological change per decade

% Emissions
ELAND0      = 1.53972;   % Carbon emissions from land 2010 [GtC per year]
DELAND      = 0.2;       % Decline rate of land emissions (per period)
E0          = 32.73738;  % Industrial emissions GtC 2010 (GtCO2 per year)
MIU0        = 0.005;     % Initial emissions control rate for base case 2010
SIG0        = 8930*3.666/66.95/1000;% Carbon intensity 2010 (kgCO2 per output 2005 USD 2010)
    SIG0 = round(SIG0*1e9)/1e9;
DSIG        = -0.001;    % Decline rate of decarbonization (per period)

% Carbon cycle
    % Initial conditions
MAT0        = 818.985;          % Initial concentration in atmosphere 2010 (GtC)
MU0         = 1527;             % Initial concentration in upper strata 2010 (GtC)
ML0         = 10010;            % Initial concentration in lower strata 2010 (GtC)
MATEQ       = 588;              % Equilibrium concentration atmosphere
MUEQ        = 1350;             % Equilibrium concentration in upper strata
MLEQ        = 10000;            % Equilibrium concentration in lower strate 
 
% Climate model parameters
FEX0        = -0.06;     % Estimate of 2010 forcings of non-C02 GHG (Wm -2)
FEX1        = 0.62;      % Estimate of 2100 forcings of non-C02 GHG (Wm -2)
TOCEAN0     = 0.0068;    % Initial lower strat. temp change (degrees C) from  1900
TATM0       = 0.830;     % Initial atmpspheric temp change [C] from  1900
C3          = 0.088;     % Transfer coefficient upper to lower stratum
C4          = 0.025;     % Transfer coefficient for lower level
FCO22X      = 3.8;       % Estimated forcings of equilibrium CO2 doubling (Wm -2)

% Climate damage parameters 
AD1          = 0;            % Damage intercept

% Abatement cost
EXPCOST2    = 2.8;       % Exponent of control cost function
GBACK       = 0.025;     % Initial cost decline backstop cost per period
MIU_LIMIT2  = 0.8448;    % Emissions control rate in 2050 in the Limit2 scenario of DICE-2013R
LIMMIU      = 1.2;       % Upper limit on control rate after 2150
TNOPOL      = 45;        % Period before which no emissions control base
CPRICE0     = 1.0;       % Initial base carbon price (2005$ per tCO2)
GCPRICE     = 0.02;      % Growth rate of base carbon price per year

% Participation
PERIODFULLPART  = 21;    % Period at which we have full participation
PARTFRACT2010   = 1;     % Fraction of emissions under control regime in 2010
PARTFRACTFULL   = 1;     % Fraction of emissions under control at full time

% Transient TSC correction ("Speed of Adjustment Parameter")
C1          = 0.104;

% Coefficients from Gt[CO2/CH4] to GtC
coeff_CO2   = round((44/12)*1e3)/1e3;
coeff_CH4   = round((16/12)*1e3)/1e3;

%--------------------------------------------------------------------------
% WEITZMAN DAMAGE FUNCTION PARAMETERS
%--------------------------------------------------------------------------
AW2         = 1/20.46; 
AW7         = 1/6.081;
AWGAMMA     = 6.754;

%--------------------------------------------------------------------------
% (POTENTIALLY) UNCERTAIN PARAMETERS
%--------------------------------------------------------------------------

MU_POPASYM    = 10500;
MU_T2XCO2     = 3.2;
MU_B12        = 8.8;
MU_AD2        = 0.002131*1.25;
MU_GA0        = (1/(1-0.079))^(1/5)-1;
MU_GSIGMA1    = -0.01;
MU_CPRICE2050 = 260;
       
        
POPASYM       = MU_POPASYM;
T2XCO2        = MU_T2XCO2;
B12           = MU_B12;
AD2           = MU_AD2;
GA0           = MU_GA0;  
GSIGMA1       = MU_GSIGMA1;
CPRICE2050    = MU_CPRICE2050; 

                
% Retrieve initial growth of TFP per 5 years
GA0_5yrs = 1-(1/(1+GA0))^5;
GA0_5yrs = round(GA0_5yrs*1e9)/1e9;
   
% ******* ACHTUNG*******
GA0_5yrs = 0.079; % DICE ORIGINAL SETTING
   
% Retrieve initial cost of backstop price (PBACK)
% cf formula in Word document
% NB: 2050 = period 9
PBACK = CPRICE2050/((1-GBACK)^(9-1)*MIU_LIMIT2^(EXPCOST2-1));
PBACK = round(PBACK*1e9)/1e9;
   
% ******* ACHTUNG*******
PBACK = 344; % DICE ORIGINAL SETTING

%--------------------------------------------------------------------------
% PCF PARAMETERS
%--------------------------------------------------------------------------

% 1. PCF module
PF_C            = 1035;  % amount of carbon in near-surface permafrost (GtC)
PCF_beta        = 0.172; % beta coefficient
e_fold          = 70;    % e-folding time of permafrost carbon decomposition (years)
prop_passive    = 0.4;   % proportion of thawed carbon in the passive pool
prop_CH4        = 0.023; % proportion of methane emissions

% 2. Methane cycle
CH4_conv        = 2.7476;  
CH4_tropo       = 9.8; 
CH4_soil        = 120;
CH4_strato      = 150;
CH4_net_lft     = 1/(1/CH4_tropo + 1/CH4_soil + 1/CH4_strato);
CH4_net_lft     = round(CH4_net_lft*1e6)/1e6;
CH4_lambda      = 0.036;
CH4_mu          = 0.12;
CH4_M0          = 722;
N2O_N0          = 270;
CH4_CONC0       = 4860; % Initial methane concentration (Tg CH4)


% 3. Other forcings
FHA_2010 = -0.40722;
FHA_2100 = -0.15944;


% 4. Import other (non PCF) CH4 emissions (RCP scenarios)
InputFile = [pwd,'\INPUT_CH4_N2O.xlsx'];
CH4_OTHER_EMISSIONS_0 = xlsread(InputFile,'CH4'); 
CH4_OTHER_EMISSIONS_0 = CH4_OTHER_EMISSIONS_0(:,2);
temp = nb_periods;
CH4_OTHER_EMISSIONS_0 = CH4_OTHER_EMISSIONS_0(1:temp);
CH4_OTHER_EMISSIONS_0 = round(CH4_OTHER_EMISSIONS_0*1e3)/1e3;


% 5. Import N2O concentration path(RCP scenarios)
N2O_CONC_0 = xlsread(InputFile,'N2O');  
N2O_CONC_0 = N2O_CONC_0(:,2); 
temp = nb_periods;
N2O_CONC_0 = N2O_CONC_0(1:temp);
N2O_CONC_0 = round(N2O_CONC_0*1e6)/1e6;

% 6. Calculate other radiative forcing ( halocarbons, aerosols) 
RAD_OTHER_PCF_0= zeros(length(years),1);  
t = 0;
for year = years(1:end)'; t = t + 1;
if t<19
RAD_OTHER_PCF_0(t) = FHA_2010+(t-1)/((2100-2010)/5)*(FHA_2100-FHA_2010);
elseif t>=19
RAD_OTHER_PCF_0(t) = FHA_2100;
end;
end;


  
%--------------------------------------------------------------------------
% STABILITY CONSTRAINTS (from DICE 2008 GAMS script)
%--------------------------------------------------------------------------

K_LOW       = 1;     % Minimum capital (US$ trillions)
MAT_LOW     = 10;    % Maximum carbon concentration in the atmosphere
MU_LOW      = 100;   % Minimum carbon concentration in shallow oceans
ML_LOW      = 1000;  % Minimum carbon concentration in lower oceans
C_LOW       = 2;     % Minimum consumption (US$ trillions)
TOCEAN_HIGH = 20;    % Maximum temperature of lower oceans (degrees C)
TOCEAN_LOW  = -1;    % Minimum temperature of lower oceans (degrees C)
TATM_HIGH   = 40;    % Maximum temperature of atmosphere (degrees C)
CPC_LOW     = 0.01;  % Minimum consumption per capita

%--------------------------------------------------------------------------
% INITIALIZATION OF OUTPUT VECTORS AND MATRICES
%--------------------------------------------------------------------------

% Uncertain inputs (column vectors)
MC_Nb                        = zeros(length(MC),1);
PF_C_Vect                    = zeros(length(MC),1);
PCF_beta_Vect                = zeros(length(MC),1);
e_fold_Vect                  = zeros(length(MC),1);
prop_passive_Vect            = zeros(length(MC),1);
prop_CH4_Vect                = zeros(length(MC),1);

% Matrices of main outputs (MC x Years)
L_0_MC                       = zeros(length(MC), length(years));  % Population (reference)
GA_0_MC                      = zeros(length(MC), length(years));  % Growth rate of TFP (per year)
GA_5yrs_0_MC                 = zeros(length(MC), length(years));  % Growth rate of TFP (per 5 years)
AL_0_MC                      = zeros(length(MC), length(years));  % Level of TFP
GSIG_0_MC                    = zeros(length(MC), length(years));  % Change in sigma
SIGMA_0_MC                   = zeros(length(MC), length(years));  % CO2eq-emissions / output ratio
PBACKTIME_0_MC               = zeros(length(MC), length(years));
COST1_0_MC                   = zeros(length(MC), length(years));
ETREE_0_MC                   = zeros(length(MC), length(years));  % Emissions from land use change (reference)
FORCOTH_0_MC                 = zeros(length(MC), length(years));  % Exogenous forcing (reference)

MU_R_MC                      = zeros(length(MC), length(years));  % Upper ocean carbon concentration (reference)
MU_MC                        = zeros(length(MC), length(years));  % Upper ocean carbon concentration (perturbed)
MU_PCF_R_MC                  = zeros(length(MC), length(years)); 
MU_PCF_MC                    = zeros(length(MC), length(years)); 

MAT_R_MC                     = zeros(length(MC), length(years));  % Atmospheric carbon concentration (reference)
MAT_MC                       = zeros(length(MC), length(years));  % Atmospheric carbon concentration (perturbed)
MAT_PCF_R_MC                 = zeros(length(MC), length(years));
MAT_PCF_MC                   = zeros(length(MC), length(years));

ML_R_MC                      = zeros(length(MC), length(years));  % Lower ocean carbon concentration (reference)
ML_MC                        = zeros(length(MC), length(years));  % Lower ocean carbon concentration (perturbed)
ML_PCF_R_MC                  = zeros(length(MC), length(years)); 
ML_PCF_MC                    = zeros(length(MC), length(years));  

MATAV_R_MC                   = zeros(length(MC), length(years));  % 2-decade lag atmospheric carbon concentration (reference)
MATAV_MC                     = zeros(length(MC), length(years));  % 2-decade lag atmospheric carbon concentration (perturbed)
MATAV_PCF_R_MC               = zeros(length(MC), length(years));
MATAV_PCF_MC                 = zeros(length(MC), length(years));

FORC_R_MC                    = zeros(length(MC), length(years));  % Total forcing (reference)
FORC_MC                      = zeros(length(MC), length(years));  % Total forcing (perturbed)
FORC_PCF_R_MC                = zeros(length(MC), length(years));
FORC_PCF_MC                  = zeros(length(MC), length(years));

YGROSS_R_MC                  = zeros(length(MC), length(years));  % World product gross of abatement and damages (reference)
YGROSS_MC                    = zeros(length(MC), length(years));  % World product gross of abatement and damages (perturbed)
YGROSS_PCF_R_MC              = zeros(length(MC), length(years));
YGROSS_PCF_MC                = zeros(length(MC), length(years));

EIND_R_MC                    = zeros(length(MC), length(years));  % Industrial emissions (reference)
EIND_MC                      = zeros(length(MC), length(years));  % Industrial emissions (perturbed)
EIND_PCF_R_MC                = zeros(length(MC), length(years));
EIND_PCF_MC                  = zeros(length(MC), length(years));

E_R_MC                       = zeros(length(MC), length(years));  % Total emissions (reference)
E_MC                         = zeros(length(MC), length(years));  % Total emissions (perturbed)    
E_PCF_R_MC                   = zeros(length(MC), length(years));
E_PCF_MC                     = zeros(length(MC), length(years));  

TATM_R_MC                    = zeros(length(MC), length(years));  % Atmospheric temperature (reference)
TATM_MC                      = zeros(length(MC), length(years));  % Atmospheric temperature (perturbed)
TATM_PCF_R_MC                = zeros(length(MC), length(years));
TATM_PCF_MC                  = zeros(length(MC), length(years));

TOCEAN_R_MC                  = zeros(length(MC), length(years));  % Atmospheric temperature (reference)
TOCEAN_MC                    = zeros(length(MC), length(years));  % Atmospheric temperature (perturbed)
TOCEAN_PCF_R_MC              = zeros(length(MC), length(years));
TOCEAN_PCF_MC                = zeros(length(MC), length(years));

REL_DAMAGES_R_MC             = zeros(length(MC), length(years));  % Relative damages (reference)
REL_DAMAGES_MC               = zeros(length(MC), length(years));  % Relative damages (perturbed)
REL_DAMAGES_PCF_R_MC         = zeros(length(MC), length(years));
REL_DAMAGES_PCF_MC           = zeros(length(MC), length(years));

DAMAGES_R_MC                 = zeros(length(MC), length(years));  % Damages (reference)
DAMAGES_MC                   = zeros(length(MC), length(years));  % Damages (perturbed)
DAMAGES_PCF_R_MC             = zeros(length(MC), length(years));
DAMAGES_PCF_MC               = zeros(length(MC), length(years));

YNET_R_MC                    = zeros(length(MC), length(years));  % Output net of damages (reference)
YNET_MC                      = zeros(length(MC), length(years));  % Output net of damages (perturbed)
YNET_PCF_R_MC                = zeros(length(MC), length(years));
YNET_PCF_MC                  = zeros(length(MC), length(years));

ABATECOST_R_MC               = zeros(length(MC), length(years));  % Abatement costs (reference)
ABATECOST_MC                 = zeros(length(MC), length(years));  % Abatement costs (perturbed)
ABATECOST_PCF_R_MC           = zeros(length(MC), length(years));
ABATECOST_PCF_MC             = zeros(length(MC), length(years));

Y_R_MC                       = zeros(length(MC), length(years));  % Output net of damages and abatement (reference)
Y_MC                         = zeros(length(MC), length(years));  % Output net of damages and abatement (perturbed)
Y_PCF_R_MC                   = zeros(length(MC), length(years)); 
Y_PCF_MC                     = zeros(length(MC), length(years));

I_R_MC                       = zeros(length(MC), length(years));  % Investment (reference)
I_MC                         = zeros(length(MC), length(years));  % Investment (perturbed)
I_PCF_R_MC                   = zeros(length(MC), length(years)); 
I_PCF_MC                     = zeros(length(MC), length(years));  

C_R_MC                       = zeros(length(MC), length(years));  % Consumption (reference)
C_MC                         = zeros(length(MC), length(years));  % Consumption (perturbed)
C_PCF_R_MC                   = zeros(length(MC), length(years));
C_PCF_MC                     = zeros(length(MC), length(years));  

CperC_R_MC                   = zeros(length(MC), length(years));  % Consumption per capita (reference)
CperC_MC                     = zeros(length(MC), length(years));  % Consumption per capita (perturbed)
CperC_PCF_R_MC               = zeros(length(MC), length(years));  
CperC_PCF_MC                 = zeros(length(MC), length(years));

K_R_MC                       = zeros(length(MC), length(years));  % Capital(reference)
K_MC                         = zeros(length(MC), length(years));  % Capital(perturbed)
K_PCF_R_MC                   = zeros(length(MC), length(years));
K_PCF_MC                     = zeros(length(MC), length(years)); 

%SCC_const_MC                 = zeros(length(MC), length(years(1:last_period_SCC)));  % SCC w/out the PCF (constant discounting)
%SCC_ram_MC                   = zeros(length(MC), length(years(1:last_period_SCC)));  % SCC w/out the PCF (Ramsey discounting)

%SCC_PCF_const_MC             = zeros(length(MC), length(years(1:last_period_SCC)));  % SCC w/out the PCF (constant discounting)
%SCC_PCF_ram_MC               = zeros(length(MC), length(years(1:last_period_SCC)));  % SCC w/out the PCF (Ramsey discounting)

%SCC_PCF_const_MC_QUADRATIC   = zeros(length(MC), length(years(1:last_period_SCC)));
%SCC_PCF_const_MC_WEITZMAN    = zeros(length(MC), length(years(1:last_period_SCC))); 

CH4_OTHER_EMISSIONS_0_MC     = zeros(length(MC), length(years));
N2O_CONC_0_MC                = zeros(length(MC), length(years));

FLUX_CH4_EMISSIONS_PCF_R_MC  = zeros(length(MC), length(years));
FLUX_CH4_EMISSIONS_PCF_MC    = zeros(length(MC), length(years));

CH4_CONC_PPMV_PCF_R_MC       = zeros(length(MC), length(years));
CH4_CONC_PPMV_PCF_MC         = zeros(length(MC), length(years));

RAD_CH4_PCF_R_MC             = zeros(length(MC), length(years));
RAD_CH4_PCF_MC               = zeros(length(MC), length(years));

RAD_N2O_PCF__R_MC            = zeros(length(MC), length(years));
RAD_N2O_PCF_MC               = zeros(length(MC), length(years));

RAD_TOT_PCF__R_MC            = zeros(length(MC), length(years));
RAD_TOT_PCF_MC               = zeros(length(MC), length(years));




%==========================================================================
%==========================================================================
%==========================================================================   
% MONTE CARLO SIMULATIONS

for mc = 1:MC;
    
    % Print status to screen:
    count = count + 1;
    if fix(mc/100)-mc/100==0;
        clc;
        fprintf(' %-.0f of %-.0f minor iterations.\n',mc,MC); 
        fprintf('    [Est time to completion = %-.1f min]\n',...
        (cputime-starttime)/count*(iterations-count)/60);
    end;
 
 %-------------------------------------------------------------------------  
 % Run function
 %-------------------------------------------------------------------------     
    [L_0, AL_0, GFACPOP_R, GA_0, GSIG_0,SIGMA_0, FORCOTH_0, PARTFRACT_0, PBACKTIME_0, COST1_0, ETREE_0, YGROSS_R, YGROSS_PCF_R, YGROSS, YGROSS_PCF, MAT_R, MAT_PCF_R, MAT, MAT_PCF, MU_R, MU_PCF_R, MU, MU_PCF, ML_R, ML_PCF_R, ML, ML_PCF, MATAV_R, MATAV_PCF_R, MATAV, MATAV_PCF, FORC_R, FORC_PCF_R, FORC, FORC_PCF, TATM_R, TATM_PCF_R, TATM, TATM_PCF, TOCEAN_R, TOCEAN_PCF_R, TOCEAN, TOCEAN_PCF, REL_DAMAGES_R, REL_DAMAGES_PCF_R, REL_DAMAGES_PCF, REL_DAMAGES, DAMAGES_R, DAMAGES_PCF_R, DAMAGES, DAMAGES_PCF, YNET_R, YNET_PCF_R , YNET, YNET_PCF, ABATECOST_R, ABATECOST, ABATECOST_PCF_R, ABATECOST_PCF, Y_R, Y_PCF_R, Y, Y_PCF, I_R, I_PCF_R, I, I_PCF, C_R, C, C_PCF_R, C_PCF, CperC_R, CperC, CperC_PCF_R, CperC_PCF, K_R, K, K_PCF_R, K_PCF, EIND_R, EIND_PCF_R, EIND, EIND_PCF, E_R, E_PCF_R, E, E_PCF, PROP_REMAIN_PCF_R, PROP_REMAIN_PCF, CUM_THAWED_PCF, CUM_THAWED_PCF_R, FLUX_THAWED_PCF_R, FLUX_THAWED_PCF, CUM_PROP_DECOMP_PCF_R, CUM_PROP_DECOMP_PCF, FLUX_PROP_DECOMP_PCF_R, FLUX_PROP_DECOMP_PCF, FLUX_VULN_PCF_R, FLUX_VULN_PCF, FLUX_C_EMISSIONS_PCF_R, FLUX_C_EMISSIONS_PCF, CUM_C_EMISSIONS_PCF_R, CUM_C_EMISSIONS_PCF, FLUX_CH4_EMISSIONS_PCF_R, FLUX_CH4_EMISSIONS_PCF, CUM_CH4_EMISSIONS_PCF_R, CUM_CH4_EMISSIONS_PCF, FLUX_CO2_EMISSIONS_PCF_R, FLUX_CO2_EMISSIONS_PCF, CUM_CO2_EMISSIONS_PCF_R, CUM_CO2_EMISSIONS_PCF, FLUX_CO2_EMISSIONS_GTCO2_PCF_R, FLUX_CO2_EMISSIONS_GTCO2_PCF, CUM_CO2_EMISSIONS_GTCO2_PCF_R, CUM_CO2_EMISSIONS_GTCO2_PCF, CH4_CONC_PCF_R, CH4_CONC_PCF, CH4_CONC_PPMV_PCF_R, CH4_CONC_PPMV_PCF, RAD_CH4_PCF_R, RAD_CH4_PCF, RAD_N2O_PCF_R, RAD_N2O_PCF, RAD_TOT_PCF_R, RAD_TOT_PCF] = Function_CALCS_ALL( QUADRATIC, WEITZMAN, MC, MC_max, PCF, end_date, years, TSTEP,POP0,POPADJ, GAMMA, DK, Q0, K0, AL0, DELA, ELAND0, DELAND, E0, MIU0, SIG0,DSIG, MAT0, MU0, ML0, MATEQ, MUEQ, MLEQ, FEX0, FEX1, TOCEAN0, TATM0, C3, C4, FCO22X, AD1, EXPCOST2, GBACK, MIU_LIMIT2, LIMMIU, TNOPOL, CPRICE0, GCPRICE, PERIODFULLPART, PARTFRACT2010, PARTFRACTFULL, C1, coeff_CO2, coeff_CH4, AW2, AW7, AWGAMMA, MIU, S, K_LOW, MAT_LOW, MU_LOW, ML_LOW, C_LOW, TOCEAN_HIGH, TOCEAN_LOW, TATM_HIGH, CPC_LOW, POPASYM, T2XCO2, B12, AD2, GA0, GSIGMA1, CPRICE2050, GA0_5yrs, PBACK, PF_C, PCF_beta, e_fold, prop_passive, prop_CH4, CH4_conv, CH4_tropo, CH4_soil, CH4_strato, CH4_net_lft, CH4_lambda, CH4_mu, CH4_M0, N2O_N0, CH4_CONC0, FHA_2010, FHA_2100, CH4_OTHER_EMISSIONS_0, N2O_CONC_0, RAD_OTHER_PCF_0); 
 %-------------------------------------------------------------------------      
 % Fill in MC matrices
 %-------------------------------------------------------------------------  
        
    % - for the uncertain inputs (column vectors)
    
    PF_C_Vect(mc,1)         = PF_C;
    PCF_beta_Vect(mc,1)     = PCF_beta;
    e_fold_Vect(mc,1)       = e_fold;
    prop_passive_Vect(mc,1) = prop_passive;
    prop_CH4_Vect(mc,1)     = prop_CH4;
    
         
    % - for the number of MC simulations (colum vectors)  
    MC_Nb(mc) = mc;
       
    % - for variables' paths (MC x Years matrices)  
    
        % - for variables' paths (MC x Years matrices)  
    
        % -- matrices:
        L_0(end)                         = [];
        L_0_MC(mc,:)                     = L_0';
        GA_0(end)                        = [];
        GA_0_MC(mc,:)                    = GA_0';
        AL_0(end)                        = [];
        AL_0_MC(mc,:)                    = AL_0';
        GSIG_0(end)                      = [];
        GSIG_0_MC(mc,:)                  = GSIG_0';
        SIGMA_0(end)                     = [];
        SIGMA_0_MC(mc,:)                 = SIGMA_0';
        PBACKTIME_0(end)                 = [];
        PBACKTIME_0_MC(mc,:)             = PBACKTIME_0';
        COST1_0(end)                     = [];
        COST1_0_MC(mc,:)                 = COST1_0';
        ETREE_0(end)                     = []; % to get rid of the last (t+1)
        ETREE_0_MC(mc,:)                 = ETREE_0';
        FORCOTH_0(end)                   = []; % to get rid of the last (t+1)
        FORCOTH_0_MC(mc,:)               = FORCOTH_0';
        
        MAT_R_MC(mc,:)                   = MAT_R';
        MAT_MC(mc,:)                     = MAT';
        MAT_PCF_R_MC(mc,:)               = MAT_PCF_R';
        MAT_PCF_MC(mc,:)                 = MAT_PCF';
        
        ML_R_MC(mc,:)                     = ML_R';
        ML_MC(mc,:)                       = ML';
        ML_PCF_R_MC(mc,:)                 = ML_PCF_R';
        ML_PCF_MC(mc,:)                   = ML_PCF';
                
        MU_R_MC(mc,:)                     = MU_R'; 
        MU_MC(mc,:)                       = MU';
        MU_PCF_R_MC(mc,:)                 = MU_PCF_R'; 
        MU_PCF_MC(mc,:)                   = MU_PCF';
        
        FORC_R_MC(mc,:)                   = FORC_R';
        FORC_MC(mc,:)                     = FORC';
        FORC_PCF_R_MC(mc,:)               = FORC_PCF_R';
        FORC_PCF_MC(mc,:)                 = FORC_PCF';
        
        YGROSS_R(end)                     = []; % to get rid of the last (t+1)
        YGROSS_R_MC(mc,:)                 = YGROSS_R';
        YGROSS(end)                       = []; % to get rid of the last (t+1)
        YGROSS_MC(mc,:)                   = YGROSS';
        
        YGROSS_PCF_R(end)                 = []; % to get rid of the last (t+1)
        YGROSS_PCF_R_MC(mc,:)             = YGROSS_PCF_R';
        YGROSS_PCF(end)                   = []; % to get rid of the last (t+1)
        YGROSS_PCF_MC(mc,:)               = YGROSS_PCF';
        
        EIND_R(end)                       = []; % to get rid of the last (t+1)
        EIND_R_MC(mc,:)                   = EIND_R';
        EIND(end)                         = []; % to get rid of the last (t+1)
        EIND_MC(mc,:)                     = EIND';
        
        EIND_PCF_R(end)                   = []; % to get rid of the last (t+1)
        EIND_PCF_R_MC(mc,:)               = EIND_PCF_R';
        EIND_PCF(end)                     = []; % to get rid of the last (t+1)
        EIND_PCF_MC(mc,:)                 = EIND_PCF';
        
        E_R_MC(mc,:)                      = E_R';
        E_MC(mc,:)                        = E';
        E_PCF_R_MC(mc,:)                  = E_PCF_R';
        E_PCF_MC(mc,:)                    = E_PCF';
        
        TATM_R_MC(mc,:)                   = TATM_R';
        TATM_MC(mc,:)                     = TATM';
        TATM_PCF_R_MC(mc,:)               = TATM_PCF_R';
        TATM_PCF_MC(mc,:)                 = TATM_PCF';
        
        CH4_OTHER_EMISSIONS_0_MC(mc,:)    = CH4_OTHER_EMISSIONS_0';
        
        N2O_CONC_0_MC(mc,:)               = N2O_CONC_0';
        
        FLUX_CH4_EMISSIONS_PCF_R_MC(mc,:) = FLUX_CH4_EMISSIONS_PCF_R';
        FLUX_CH4_EMISSIONS_PCF_MC(mc,:)   = FLUX_CH4_EMISSIONS_PCF';
       
     
        CH4_CONC_PPMV_PCF_R_MC(mc,:)      = CH4_CONC_PPMV_PCF_R';
        CH4_CONC_PPMV_PCF_MC(mc,:)        = CH4_CONC_PPMV_PCF';
                
        RAD_CH4_PCF_R_MC(mc,:)            = RAD_CH4_PCF_R';
        RAD_CH4_PCF_MC(mc,:)              = RAD_CH4_PCF';
     
        RAD_N2O_PCF_R_MC(mc,:)            = RAD_N2O_PCF_R';
        RAD_N2O_PCF_MC(mc,:)              = RAD_N2O_PCF';
        
        RAD_TOT_PCF_R_MC(mc,:)            = RAD_TOT_PCF_R';
        RAD_TOT_PCF_MC(mc,:)              = RAD_TOT_PCF';
        
        TOCEAN_R_MC(mc,:)                 = TOCEAN_R';
        TOCEAN_MC(mc,:)                   = TOCEAN';
        TOCEAN_PCF_R_MC(mc,:)             = TOCEAN_PCF_R';
        TOCEAN_PCF_MC(mc,:)               = TOCEAN_PCF';
        
        DAMAGES_R_MC(mc,:)                = DAMAGES_R';
        DAMAGES_MC(mc,:)                  = DAMAGES';
        DAMAGES_PCF_R_MC(mc,:)            = DAMAGES_PCF_R';
        DAMAGES_PCF_MC(mc,:)              = DAMAGES_PCF';
        
        REL_DAMAGES_R_MC(mc,:)            = REL_DAMAGES_R';
        REL_DAMAGES_MC(mc,:)              = REL_DAMAGES';
        REL_DAMAGES_PCF_R_MC(mc,:)        = REL_DAMAGES_PCF_R';
        REL_DAMAGES_PCF_MC(mc,:)          = REL_DAMAGES_PCF';
        
        YNET_R_MC(mc,:)                   = YNET_R';
        YNET_MC(mc,:)                     = YNET';
        YNET_PCF_R_MC(mc,:)               = YNET_PCF_R';
        YNET_PCF_MC(mc,:)                 = YNET_PCF';
        
        ABATECOST_R_MC(mc,:)              = ABATECOST_R';
        ABATECOST_MC(mc,:)                = ABATECOST';
        ABATECOST_PCF_R_MC(mc,:)          = ABATECOST_PCF_R';
        ABATECOST_PCF_MC(mc,:)            = ABATECOST_PCF';
        
        Y_R_MC(mc,:)                      = Y_R';
        Y_MC(mc,:)                        = Y';
        Y_PCF_R_MC(mc,:)                  = Y_PCF_R';
        Y_PCF_MC(mc,:)                    = Y_PCF';
        
        I_R_MC(mc,:)                      = I_R';
        I_MC(mc,:)                        = I';            
        I_PCF_R_MC(mc,:)                  = I_PCF_R';
        I_PCF_MC(mc,:)                    = I_PCF';
        
        C_R_MC(mc,:)                      = C_R';
        C_MC(mc,:)                        = C';
        C_PCF_R_MC(mc,:)                  = C_PCF_R';
        C_PCF_MC(mc,:)                    = C_PCF';
        
        CperC_R_MC(mc,:)                  = CperC_R';
        CperC_MC(mc,:)                    = CperC';
        CperC_PCF_R_MC(mc,:)              = CperC_PCF_R';
        CperC_PCF_MC(mc,:)                = CperC_PCF';
        
        K_R(end)                          = []; % to get rid of the last (t+1)
        K_R_MC(mc,:)                      = K_R';
        K(end)                            = []; % to get rid of the last (t+1)
        K_MC(mc,:)                        = K';
        
        K_PCF_R(end)                      = []; % to get rid of the last (t+1)
        K_PCF_R_MC(mc,:)                  = K_PCF_R';
        K_PCF(end)                        = []; % to get rid of the last (t+1)
        K_PCF_MC(mc,:)                    = K_PCF';
                       

        

   
 %-------------------------------------------------------------------------      
 % SCC calcs (w/out the PCF_
 %-------------------------------------------------------------------------     
   
    SCC_ram = zeros(3,12);
    SCC_const = zeros(1,6);
 
    t = (year_SCC-2010)/5+1;    
        
        % Interpolation: 
        C_R_i    = interp1(years(t:end),C_R(t:end),years(t):years(end),'linear')'; 
        L_0_i    = interp1(years(t:end),L_0(t:end),years(t):years(end),'linear')'; 
        C_i      = interp1(years(t:end),C(t:end),years(t):years(end),'linear')'; 
                
        
        % Constant discount rate:
        h = 0;
        for rate = rate_vect(1:end); h = h + 1;
            tt = 0;
            for tau = years(t):end_date-1; tt = tt + 1;
                SCC_const(h) = SCC_const(h) + ( C_R_i(tt) - C_i(tt) ) * 1/((1+rate)^(tt-1)); 
            end;
        end;
        % Convert SCC path from trillion$/GtC/yr to $/tCO2/yr:
        SCC_const = SCC_const / (10^-3) * 12/44;
        
      
        
        % Ramsey discounting:
        i = 0;
        for rho = rho_vect(1:end); i = i + 1;
            j = 0;
            for eta = eta_vect(1:end); j = j + 1;
                tt = 0;
                for tau = years(t):end_date; tt = tt + 1; 
                    SCC_ram(i,j) = SCC_ram(i,j) + ( C_R_i(tt) - C_i(tt) ) * exp(-(eta*1/(tt-1+eps)*log((C_R_i(tt)/L_0_i(tt))/(C_R_i(1)/L_0_i(1)))+rho)*(tt-1));  
                end;
            end;
        end;
        % Convert SCC path from trillion$/GtC/yr to $/tCO2/yr:
        SCC_ram = SCC_ram / (10^-3) * 12/44;
         
         
   

    
 %-------------------------------------------------------------------------      
 % SCC calcs (with the PCF)
 %-------------------------------------------------------------------------     
  
        SCC_PCF_ram   = zeros(3,12);
        SCC_PCF_const = zeros(1,6);
 
 
        t = (year_SCC-2010)/5+1;    
        
        % Interpolation: 
        C_PCF_R_i     = interp1(years(t:end),C_PCF_R(t:end),years(t):years(end),'linear')'; 
        L_0_i         = interp1(years(t:end),L_0(t:end),years(t):years(end),'linear')'; 
        C_PCF_i       = interp1(years(t:end),C_PCF(t:end),years(t):years(end),'linear')'; 
                
        
        % Constant discount rate:
        h = 0;
        for rate = rate_vect(1:end); h = h + 1;
            tt = 0;
            for tau = years(t):end_date-1; tt = tt + 1;
                SCC_PCF_const(h) = SCC_PCF_const(h) + ( C_PCF_R_i(tt) - C_PCF_i(tt) ) * 1/((1+rate)^(tt-1)); 
            end;
        end;
        % Convert SCC path from trillion$/GtC/yr to $/tCO2/yr:
        SCC_PCF_const = SCC_PCF_const / (10^-3) * 12/44;
        

        % Ramsey discounting:
        i = 0;
        temp1 = 0;
        for rho = rho_vect(1:end); i = i + 1;
            j = 0;
            for eta = eta_vect(1:end); j = j + 1;
                tt = 0;
                for tau = years(t):end_date; tt = tt + 1; 
                SCC_PCF_ram(i,j) = SCC_PCF_ram(i,j) + ( C_PCF_R_i(tt) - C_PCF_i(tt) ) * exp(-(eta*1/(tt-1+eps)*log((C_PCF_R_i(tt)/L_0_i(tt))/(C_PCF_R_i(1)/L_0_i(1)))+rho)*(tt-1));  
                end;
            end;
        end;
        % Convert SCC path from trillion$/GtC/yr to $/tCO2/yr:
        SCC_PCF_ram = SCC_PCF_ram / (10^-3) * 12/44;
         
         
 %-------------------------------------------------------------------------
 %-------------------------------------------------------------------------
        
        
% End of MC simulations loop
   



end;


%==========================================================================
%==========================================================================
%==========================================================================
% To check Excel and Matlab (no PCF) + SCC
%Function_PATHS_NOPCF( QUADRATIC, WEITZMAN, years, end_date, MIU, S, L_0_MC, GA_0_MC, AL_0_MC, GSIG_0_MC, SIGMA_0_MC, PBACKTIME_0_MC, COST1_0_MC, FORCOTH_0_MC, YGROSS_R_MC, YGROSS_MC, ETREE_0_MC, EIND_R_MC, EIND_MC, MAT_R_MC, MAT_MC, FORC_R_MC, FORC_MC, TOCEAN_R_MC, TOCEAN_MC, TATM_R_MC, TATM_MC, REL_DAMAGES_R_MC, REL_DAMAGES_MC, DAMAGES_R_MC, DAMAGES_MC, YNET_R_MC, YNET_MC, ABATECOST_R_MC, ABATECOST_MC, Y_R_MC, Y_MC, I_R_MC, I_MC, C_R_MC, C_MC, K_R_MC, K_MC, year_SCC, rate_vect, eta_vect, rho_vect, C_R_i, C_i, L_0_i, C_PCF_R_i, C_PCF_i, SCC_const, SCC_ram)

% To check Excel and Matlab (PCF) + SCC
%Function_PATHS_PCF( QUADRATIC, WEITZMAN, years, end_date, MIU, S, L_0_MC, GA_0_MC, AL_0_MC, GSIG_0_MC, SIGMA_0_MC, PBACKTIME_0_MC, COST1_0_MC, FORCOTH_0_MC, YGROSS_PCF_R_MC, YGROSS_PCF_MC, ETREE_0_MC, EIND_PCF_R_MC, EIND_PCF_MC, MAT_PCF_R_MC, MAT_PCF_MC, FORC_PCF_R_MC, FORC_PCF_MC, TOCEAN_PCF_R_MC, TOCEAN_PCF_MC, TATM_PCF_R_MC, TATM_PCF_MC, REL_DAMAGES_PCF_R_MC, REL_DAMAGES_PCF_MC, DAMAGES_PCF_R_MC, DAMAGES_PCF_MC, YNET_PCF_R_MC, YNET_PCF_MC, ABATECOST_PCF_R_MC, ABATECOST_PCF_MC, Y_PCF_R_MC, Y_PCF_MC, I_PCF_R_MC, I_PCF_MC, C_PCF_R_MC, C_PCF_MC, K_PCF_R_MC, K_PCF_MC, year_SCC, rate_vect, eta_vect, rho_vect, C_R_i, C_i, L_0_i, C_PCF_R_i, C_PCF_i, SCC_const, SCC_PCF_const, SCC_ram, SCC_PCF_ram, CH4_OTHER_EMISSIONS_0_MC, N2O_CONC_0_MC, FLUX_CH4_EMISSIONS_PCF_R_MC, FLUX_CH4_EMISSIONS_PCF_MC, CH4_CONC_PPMV_PCF_R_MC, CH4_CONC_PPMV_PCF_MC, RAD_CH4_PCF_R_MC, RAD_CH4_PCF_MC, RAD_N2O_PCF_R_MC, RAD_N2O_PCF_MC, RAD_TOT_PCF_R_MC, RAD_TOT_PCF_MC)

% To chart paths for CO2 emissions, CO2 concentration, TATM and consumption (PCF vs no PCF) 
Function_CHARTS_PCF(QUADRATIC, WEITZMAN, years, E_R, E_PCF_R, MAT_R, MAT_PCF_R, TATM_R, TATM_PCF_R, C_R, C_PCF_R)

% To write interpolated paths and SCC sensitivity tables in Excel
Function_SCC_for_v2(QUADRATIC, WEITZMAN, years, end_date, year_SCC, rate_vect, eta_vect, rho_vect, C_R_i, C_i, L_0_i, C_PCF_R_i, C_PCF_i, SCC_ram, SCC_PCF_ram, SCC_const, SCC_PCF_const)

%==========================================================================
%==========================================================================
%==========================================================================

% Show when programme has finished running

scriptname = mfilename('fullpath'); 
EndMessage=[scriptname, ' has finished running'];
disp(EndMessage);



