function [W] = mscr_W_NOPCF_QUAD_noconsend(MIU_X)
%UNTITLED Summary of this function goes here
%   Detailed explanation goes here


%==========================================================================
end_date = 2300;
nb_periods = (end_date-2010)/5+1;
years      = [2010:5:end_date]'; % (NB: model is based on a 5 year time step)

%==========================================================================
 % PCF switch   
    PCF = 0; % replace 1 by 0 if you want to remove the PCF
        
%==========================================================================    
  % Choice of damage function specification
    QUADRATIC  = 1;  
        % 1 if choice of quadratic function, 0 if use of alternative damage function based on Dietz and Asheim 2012  
        % If QUADRATIC = 1, this means the damage function is as in
        % DICE-2007 (NOT DICE-2013): DAMAGES = YGROSS(t)* [AD1*TATM(t)+AD2*TATM(t)^2]/[1+(AD1*TATM(t)+AD2*TATM(t)^2)^10];
        
    WEITZMAN   = 0;  
        % 1 if choice of alternative damage function based on Dietz and Asheim 2012, 0 if quadratic
        % If WEITZMAN = 1, this means the damage function is as in
        % WEITZMAN 2012: DAMAGES = YGROSS(t)-YGROSS(t)/(1+(AW2*TATM(t))^2+(AW7*TATM(t))^AWGAMMA);
    
    
%==========================================================================
  % Optimization
    
  MIU(1) = (1/344)^(1/(2.8-1)); 
  
  MIU_end = ones(8,1);
  
  MIU = [MIU(1);MIU_X;MIU_end]; 
  
  
  
      t = 53;
    for year = years(53:end)'; t = t + 1;
        MIU(t)= 1; 
    end;
    MIU(60) = 1;
    MIU(61) = 1;



%==========================================================================
  % Choice of discounting parameters
    year_NPV = 2010;
    eta = 1.45;
    rho = 0.015;
    

%--------------------------------------------------------------------------
% DICE-2013 FIXED PARAMETERS
%--------------------------------------------------------------------------

count      = 0;
starttime  = cputime;
      
% Time step
TSTEP       = 5;         % Years per period

% Population
POP0        = 6838;      % Initial population (in millions) 
POPADJ      = 0.134490;  % Growth rate to calibrate to 2050 pop projection

% Technology
GAMMA       = 0.300;     % Capital elasticity in production function
DK          = 0.100;     % Depreciation rate on capital per year
Q0          = 66.950;    % 2005 world gross output trill 2005 US dollars   
K0          = 135;       % 2005 value capital trill 2005 US dollars
AL0         = 3.7976214; % Initial level of total factor productivity
DELA        = 0.006;     % Decline rate of technological change per decade

% Emissions
ELAND0      = 1.53972;   % Carbon emissions from land 2010 [GtC per year]
DELAND      = 0.2;       % Decline rate of land emissions (per period)
E0          = 32.73738;  % Industrial emissions GtC 2010 (GtCO2 per year)
SIG0        = 8930*3.666/66.95/1000;% Carbon intensity 2010 (kgCO2 per output 2005 USD 2010)
    SIG0 = round(SIG0*1e9)/1e9;
DSIG        = -0.001;    % Decline rate of decarbonization (per period)

% Carbon cycle
    % Initial conditions
MAT0        = 818.985;          % Initial concentration in atmosphere 2010 (GtC)
MU0         = 1527;             % Initial concentration in upper strata 2010 (GtC)
ML0         = 10010;            % Initial concentration in lower strata 2010 (GtC)
MATEQ       = 588;              % Equilibrium concentration atmosphere
MUEQ        = 1350;             % Equilibrium concentration in upper strata
MLEQ        = 10000;            % Equilibrium concentration in lower strate 
 
% Climate model parameters
FEX0        = -0.06;     % Estimate of 2010 forcings of non-C02 GHG (Wm -2)
FEX1        = 0.62;      % Estimate of 2100 forcings of non-C02 GHG (Wm -2)
TOCEAN0     = 0.0068;    % Initial lower strat. temp change (degrees C) from  1900
TATM0       = 0.830;     % Initial atmpspheric temp change [C] from  1900
C3          = 0.088;     % Transfer coefficient upper to lower stratum
C4          = 0.025;     % Transfer coefficient for lower level
FCO22X      = 3.8;       % Estimated forcings of equilibrium CO2 doubling (Wm -2)

% Climate damage parameters 
AD1          = 0;            % Damage intercept

% Abatement cost
EXPCOST2    = 2.8;       % Exponent of control cost function
GBACK       = 0.025;     % Initial cost decline backstop cost per period
MIU_LIMIT2  = 0.8448;    % Emissions control rate in 2050 in the Limit2 scenario of DICE-2013R
LIMMIU      = 1.2;       % Upper limit on control rate after 2150
TNOPOL      = 45;        % Period before which no emissions control base
CPRICE0     = 1.0;       % Initial base carbon price (2005$ per tCO2)
GCPRICE     = 0.02;      % Growth rate of base carbon price per year

% Participation
PERIODFULLPART  = 21;    % Period at which we have full participation
PARTFRACT2010   = 1;     % Fraction of emissions under control regime in 2010
PARTFRACTFULL   = 1;     % Fraction of emissions under control at full time

% Transient TSC correction ("Speed of Adjustment Parameter")
C1 = 0.104;

% Coefficients from Gt[CO2/CH4] to GtC
coeff_CO2 = round((44/12)*1e3)/1e3;
coeff_CH4 = round((16/12)*1e3)/1e3;

% Constant discount rate
rate = 0.03; 

% Ramsey discounting
eta  = 2;         
rho  = 0.01;      

% End date for SCC calcs
last_date_SCC = 2050; 
last_period_SCC = (last_date_SCC-2010)/5+1;

% WEITZMAN damage function
AW2     = 1/20.46; 
AW7     = 1/6.081;
AWGAMMA = 6.754;

% OTHER PARAMETERS        
POPASYM       = 10500;
T2XCO2        = 3.2;
B12           = 8.8;
AD2           = 0.002131*1.25;
GA0           = (1/(1-0.079))^(1/5)-1; 
GSIGMA1       = -0.01;
CPRICE2050    = 260;

% Retrieve initial growth of TFP per 5 years
    GA0_5yrs = 1-(1/(1+GA0))^5;
    GA0_5yrs = round(GA0_5yrs*1e9)/1e9;
   
% ******* ACHTUNG*******
    GA0_5yrs = 0.079; % DICE ORIGINAL SETTING
   
% Retrieve initial cost of backstop price (PBACK)
% cf formula in Word document
% NB: 2050 = period 9
    PBACK = CPRICE2050/((1-GBACK)^(9-1)*MIU_LIMIT2^(EXPCOST2-1));
    PBACK = round(PBACK*1e9)/1e9;
   
% ******* ACHTUNG*******
    PBACK = 344; % DICE ORIGINAL SETTING




%--------------------------------------------------------------------------
% STABILITY CONSTRAINTS (from DICE 2008 GAMS script)
%--------------------------------------------------------------------------
K_LOW       = 1;     % Minimum capital (US$ trillions)
MAT_LOW     = 10;    % Maximum carbon concentration in the atmosphere
MU_LOW      = 100;   % Minimum carbon concentration in shallow oceans
ML_LOW      = 1000;  % Minimum carbon concentration in lower oceans
C_LOW       = 2;     % Minimum consumption (US$ trillions)
TOCEAN_HIGH = 20;    % Maximum temperature of lower oceans (degrees C)
TOCEAN_LOW  = -1;    % Minimum temperature of lower oceans (degrees C)
TATM_HIGH   = 40;    % Maximum temperature of atmosphere (degrees C)
CPC_LOW     = 0.01;  % Minimum consumption per capita

%--------------------------------------------------------------------------
% Import savings rate (S) from Excel file
%--------------------------------------------------------------------------

    
   S = [0.258
   0.255
   0.253
   0.250
   0.248
   0.246
   0.245
   0.243
   0.242
   0.241
   0.240
   0.239
   0.239
   0.238
   0.238
   0.237
   0.237
   0.237
   0.237
   0.236
   0.236
   0.236
   0.236
   0.236
   0.237
   0.237
   0.237
   0.237
   0.238
   0.237
   0.238
   0.238
   0.239
   0.239
   0.239
   0.240
   0.240
   0.241
   0.241
   0.242
   0.243
   0.244
   0.245
   0.247
   0.249
   0.247
   0.247
   0.246
   0.244
   0.242
   0.258
   0.258
   0.258
   0.258
   0.258
   0.258
   0.258
   0.258
   0.258
   0.258];

%--------------------------------------------------------------------------
% Carbon cycle coefficients matrix
%--------------------------------------------------------------------------  
        
    B23     = 0.250;              % Carbon cycle transition matrix
    B11     = 100 - B12;          % Carbon cycle transition matrix
    B21     = B12*MATEQ/MUEQ;     % Carbon cycle transition matrix
    B21     = round(B21*1e3)/1e3; % (to avoid discrepancies with the Excel file)
    B22     = 100 - B21 - B23;    % Carbon cycle transition matrix
    B32     = B23*MUEQ/MLEQ;      % Carbon cycle transition matrix
    B32     = round(B32*1e5)/1e5; % (to avoid discrepancies with the Excel file)
    B33     = 100 - B32;          % Carbon cycle transition matrix
    
%--------------------------------------------------------------------------
% Initialize output variables paths (column vectors for each MC iteration)  
%--------------------------------------------------------------------------  
       
    % Reference paths which don't depend on emissions
    L_0               = zeros(length(years),1);  % Population
    AL_0              = zeros(length(years),1);  % Level of total factor productivity
    GFACPOP_R         = zeros(length(years),1);  % Growth factor of population
    GA_0              = zeros(length(years),1);  % Growth rate of productivity
    GSIG_0            = zeros(length(years),1);  % Cumulative improvement of energy efficiency
    SIGMA_0           = zeros(length(years),1);  % Co2-eq emissions-output ratio
    FORCOTH_0         = zeros(length(years),1);  % Exogenous forcing
    PARTFRACT_0       = zeros(length(years),1);  % Fraction of emissions in control regime
    PBACKTIME_0       = zeros(length(years),1);  % Backstop price
    COST1_0           = zeros(length(years),1);  % Adjusted cost for backstop
    ETREE_0           = zeros(length(years),1);  % decline rate of land emissions per year = 0.1
    
    % Reference paths of variables which depend on emissions (no PCF)
    YGROSS_R          = zeros(length(years),1);  % World product gross of abatement and damages
    MAT_R             = zeros(length(years),1);  % Atmospheric carbon concentration
    MU_R              = zeros(length(years),1);  % Upper ocean carbon concentration
    ML_R              = zeros(length(years),1);  % Lower ocean carbon concentration
    MATAV_R           = zeros(length(years),1);  % 2-decade lag atmospheric carbon conc.
    FORC_R            = zeros(length(years),1);  % Total forcing 
    TATM_R            = zeros(length(years),1);  % Atmospheric temperature
    TOCEAN_R          = zeros(length(years),1);  % Ocean temperature
    REL_DAMAGES_R     = zeros(length(years),1);  % Relative damages
    DAMAGES_R         = zeros(length(years),1);  % Climate damages
    YNET_R            = zeros(length(years),1);  % Output after damages before abatement
    ABATECOST_R       = zeros(length(years),1);  % Cost of emissions reduction
    Y_R               = zeros(length(years),1);  % Output net of damages and abatement
    I_R               = zeros(length(years),1);  % Investment
    C_R               = zeros(length(years),1);  % Consumption
    CperC_R           = zeros(length(years),1);  % Consumption per capita ($000s per year)
    K_R               = zeros(length(years),1);  % Capital stock
    EIND_R            = zeros(length(years),1);  % Industrial emissions
    CumEIND_R         = zeros(length(years),1);  % Cumulative industrial emissions
    E_R               = zeros(length(years),1);  % Total emissions   
        
%--------------------------------------------------------------------------
% Calculate paths for variables that DO NOT depend on emissions levels (noted NAME_0)    
%--------------------------------------------------------------------------             
        
    % Variables
    % L_0         = Population
    % GFACPOP_0   = Growth factor of population
    % GA_0        = Growth rate of productivity
    % AL_0        = Level of total factor productivity
    % GSIG_0      = Cumulative improvement of energy efficiency
    % SIGMA_0     = Co2-eq emissions-output ratio
    % FORCOTH_0   = Exogenous forcing
    % PARTFRACT_0 = Fraction of emissions in control regime
    % ETREE_0     = Emissions from land use change
    % COST1_0     = Adjusted cost for backstop
        
    % Paths initialization:
    L_0(1)          = POP0;
    GA_0(1)         = GA0_5yrs; 
    AL_0(1)         = AL0;
    GSIG_0(1)       = GSIGMA1; 
    SIGMA_0(1)      = SIG0;
    PBACKTIME_0(1)  = PBACK;
    COST1_0(1)      = PBACK*SIGMA_0(1)/EXPCOST2/1000;
    ETREE_0(1)      = ELAND0;
    FORCOTH_0(1)    = FEX0+0.05*(FEX1-FEX0)*(1+1);
    PARTFRACT_0(1)  = PARTFRACT2010;
    
    % Paths calculations:
    t = 1;
    for year = years(1:end)'; t = t + 1;
        L_0(t)= L_0(t-1)*(POPASYM/L_0(t-1))^POPADJ; 
        GA_0(t) = GA0_5yrs*exp(-DELA*TSTEP*(t-1)); 
        AL_0(t) = AL_0(t-1)/((1-GA_0(t-1))); 
            
        % **GSIG** - first value of GSIG = GSIGMA1 is for year 2 (as GSIG = growth rate)
        if t<=2
        GSIG_0(t)  = GSIGMA1;
        elseif t>2
        GSIG_0(t)  = GSIG_0(t-1)*((1+DSIG)^TSTEP);
        end;
        
        SIGMA_0(t) = SIGMA_0(t-1)*(exp(GSIG_0(t)*TSTEP));
        PBACKTIME_0(t) = PBACK*(1-GBACK)^(t-1);
        COST1_0(t)  = PBACKTIME_0(t)*SIGMA_0(t)/EXPCOST2/1000;
        ETREE_0(t) = ELAND0*((1-DELAND)^(t-1)); 
        
        % **FORCOTH** - change after period 19
        if t<19
        FORCOTH_0(t) = FEX0+0.05*(FEX1-FEX0)*(t+1); % as in the Excel model for DICE 2013R on Nordhaus' website
        elseif t>=19
        FORCOTH_0(t) = FEX1;
        end;
                
        PARTFRACT_0(t) = (PARTFRACT2010 + (PARTFRACTFULL-PARTFRACT2010)*(t-1)/PERIODFULLPART)*(t<PERIODFULLPART+1) + PARTFRACTFULL*(t>PERIODFULLPART) ;
    end;
  
%--------------------------------------------------------------------------
% Calculate paths for variables that DO depend on emissions levels (noted NAME_0)    
%--------------------------------------------------------------------------                
       
    K_R(1)         = K0; 
    YGROSS_R(1)    = AL_0(1)*(L_0(1)/1000)^(1-GAMMA)*(K_R(1)^GAMMA);
    YGROSS_R(1)    = round(YGROSS_R(1)*1e3)/1e3;
    EIND_R(1)      = SIGMA_0(1)*(1-MIU(1))*YGROSS_R(1);
    CumEIND_R(1)   = EIND_R(1)*coeff_CO2*5;
    E_R(1)         = EIND_R(1)+ ETREE_0(1);
    MAT_R(1)       = MAT0;
    ML_R(1)        = ML0; 
    MU_R(1)        = MU0; 
    FORC_R(1)      = FCO22X*log((MAT_R(1)/588.000))/log(2) + FORCOTH_0(1); 
    TATM_R(1)      = TATM0; 
    TOCEAN_R(1)    = TOCEAN0; 
    
    % Damages (quadratic or as in Weitzman, depending on the
    % initial setting - cf lines 35-40) 
    if QUADRATIC == 1
        DAMAGES_R(1) = YGROSS_R(1)*(AD1*TATM_R(1) + AD2*TATM_R(1)^2)/(1+(AD1*TATM_R(1) + AD2*TATM_R(1)^2)^10);
        REL_DAMAGES_R(1) = AD1*TATM_R(1) + AD2*TATM_R(1)^2;
    elseif WEITZMAN == 1
        DAMAGES_R(1) = YGROSS_R(1)-YGROSS_R(1)/(1 + (AW2*TATM_R(1))^2 + (AW7*TATM_R(1))^AWGAMMA);
        REL_DAMAGES_R(1) = 1-1/(1 + (AW2*TATM_R(1))^2 + (AW7*TATM_R(1))^AWGAMMA);
    end;
        
    YNET_R(1)      = YGROSS_R(1)-DAMAGES_R(1);
    ABATECOST_R(1) = (PARTFRACT_0(1)^(1-EXPCOST2))*YGROSS_R(1)*COST1_0(1)*(MIU(1)^EXPCOST2);
    Y_R(1)         = YNET_R(1)-ABATECOST_R(1);
    I_R(1)         = S(1)*Y_R(1);
    C_R(1)         = max(C_LOW, Y_R(1)-I_R(1));
    CperC_R(1)     = (C_R(1)/L_0(1))*1000;
    K_R(2)         = max(K_LOW, ((1-DK)^TSTEP)*K_R(1)+TSTEP*I_R(1));
    YGROSS_R(2)    = AL_0(2)*(L_0(2)/1000)^(1-GAMMA)*(K_R(2)^GAMMA);
    EIND_R(2)      = SIGMA_0(2)*(1-MIU_X(2))*YGROSS_R(2);
    
    % Reference paths calculations:

    % OPTIMISATION!!!
    
    t=1;
    for year = years(2:53-1)'; t = t + 1;
        CumEIND_R(t)   = CumEIND_R(t-1) + EIND_R(t)*coeff_CO2*5;
        E_R(t)         = EIND_R(t)+ ETREE_0(t);
        MAT_R(t)       = max(MAT_LOW, B11/100*MAT_R(t-1) + B21/100*MU_R(t-1) + E_R(t-1)*5/coeff_CO2); % cf lower bound MAT_LOW
        ML_R(t)        = max(ML_LOW, B23/100*MU_R(t-1) + B33/100*ML_R(t-1)); % cf lower bound ML_LOW
        MU_R(t)        = max(MU_LOW, B12/100*MAT_R(t-1) + B22/100*MU_R(t-1) + B32/100*ML_R(t-1)); % cf lower bound MU_LOW
        FORC_R(t)      = FCO22X * (log((MAT_R(t)/588.000))/log(2)) + FORCOTH_0(t); 
        TATM_R(t)      = min(TATM_HIGH, TATM_R(t-1) + C1*(FORC_R(t) - FCO22X/T2XCO2*TATM_R(t-1) - C3*(TATM_R(t-1) - TOCEAN_R(t-1))));
        
        % Upper and lower bounds on atmospheric temperature
        if TOCEAN_R(t-1) + C4*(TATM_R(t-1)-TOCEAN_R(t-1))>=0
        TOCEAN_R(t)    = min(TOCEAN_HIGH, TOCEAN_R(t-1) + C4*(TATM_R(t-1)-TOCEAN_R(t-1)));
            elseif TOCEAN_R(t-1) + C4*(TATM_R(t-1)-TOCEAN_R(t-1))<0
        TOCEAN_R(t)    = max(TOCEAN_LOW, TOCEAN_R(t-1) + C4*(TATM_R(t-1)-TOCEAN_R(t-1)));
        end;
        
        % Damages (quadratic or as in Weitzman, depending on the
        % initial setting - cf lines 35-40) 
        if QUADRATIC == 1
        DAMAGES_R(t) = YGROSS_R(t)*(AD1*TATM_R(t) + AD2*TATM_R(t)^2)/(1+(AD1*TATM_R(t) + AD2*TATM_R(t)^2)^10);
        REL_DAMAGES_R(t) = AD1*TATM_R(t) + AD2*TATM_R(t)^2;
            elseif WEITZMAN == 1
        DAMAGES_R(t) = YGROSS_R(t)-YGROSS_R(t)/(1 + (AW2*TATM_R(t))^2 + (AW7*TATM_R(t))^AWGAMMA);
        REL_DAMAGES_R(t) = 1-1/(1 + (AW2*TATM_R(t))^2 + (AW7*TATM_R(t))^AWGAMMA);
        end;
                       
        YNET_R(t)      = YGROSS_R(t)-DAMAGES_R(t);
        ABATECOST_R(t) = (PARTFRACT_0(t)^(1-EXPCOST2))*YGROSS_R(t)*COST1_0(t)*(MIU_X(t)^EXPCOST2);
        Y_R(t)         = YNET_R(t)-ABATECOST_R(t);
        I_R(t)         = S(t)*Y_R(t);
        C_R(t)         = max(C_LOW, Y_R(t)-I_R(t));
        CperC_R(t)     = (C_R(t)/L_0(t))*1000;
        K_R(t+1)       = ((1-DK)^TSTEP)*K_R(t)+TSTEP*I_R(t);
        YGROSS_R(t+1)  = AL_0(t+1)*((L_0(t+1)/1000)^(1-GAMMA))*(K_R(t+1)^GAMMA);
        if t < 52 
            EIND_R(t+1)    = SIGMA_0(t+1)*(1-MIU_X(t+1))*YGROSS_R(t+1);
        elseif t == 52 
            EIND_R(t+1)    = SIGMA_0(t+1)*(1-MIU(t+1))*YGROSS_R(t+1);
        end;
    end;          
 
    
    
        % Reference paths calculations:
    t=53;
    for year = years(53:end-1)'; t = t + 1;
        CumEIND_R(t)   = CumEIND_R(t-1) + EIND_R(t)*coeff_CO2*5;
        E_R(t)         = EIND_R(t)+ ETREE_0(t);
        MAT_R(t)       = max(MAT_LOW, B11/100*MAT_R(t-1) + B21/100*MU_R(t-1) + E_R(t-1)*5/coeff_CO2); % cf lower bound MAT_LOW
        ML_R(t)        = max(ML_LOW, B23/100*MU_R(t-1) + B33/100*ML_R(t-1)); % cf lower bound ML_LOW
        MU_R(t)        = max(MU_LOW, B12/100*MAT_R(t-1) + B22/100*MU_R(t-1) + B32/100*ML_R(t-1)); % cf lower bound MU_LOW
        FORC_R(t)      = FCO22X * (log((MAT_R(t)/588.000))/log(2)) + FORCOTH_0(t); 
        TATM_R(t)      = min(TATM_HIGH, TATM_R(t-1) + C1*(FORC_R(t) - FCO22X/T2XCO2*TATM_R(t-1) - C3*(TATM_R(t-1) - TOCEAN_R(t-1))));
        
        % Upper and lower bounds on atmospheric temperature
        if TOCEAN_R(t-1) + C4*(TATM_R(t-1)-TOCEAN_R(t-1))>=0
        TOCEAN_R(t)    = min(TOCEAN_HIGH, TOCEAN_R(t-1) + C4*(TATM_R(t-1)-TOCEAN_R(t-1)));
            elseif TOCEAN_R(t-1) + C4*(TATM_R(t-1)-TOCEAN_R(t-1))<0
        TOCEAN_R(t)    = max(TOCEAN_LOW, TOCEAN_R(t-1) + C4*(TATM_R(t-1)-TOCEAN_R(t-1)));
        end;
        
        % Damages (quadratic or as in Weitzman, depending on the
        % initial setting - cf lines 35-40) 
        if QUADRATIC == 1
        DAMAGES_R(t) = YGROSS_R(t)*(AD1*TATM_R(t) + AD2*TATM_R(t)^2)/(1+(AD1*TATM_R(t) + AD2*TATM_R(t)^2)^10);
        REL_DAMAGES_R(t) = AD1*TATM_R(t) + AD2*TATM_R(t)^2;
            elseif WEITZMAN == 1
        DAMAGES_R(t) = YGROSS_R(t)-YGROSS_R(t)/(1 + (AW2*TATM_R(t))^2 + (AW7*TATM_R(t))^AWGAMMA);
        REL_DAMAGES_R(t) = 1-1/(1 + (AW2*TATM_R(t))^2 + (AW7*TATM_R(t))^AWGAMMA);
        end;
                       
        YNET_R(t)      = YGROSS_R(t)-DAMAGES_R(t);
        ABATECOST_R(t) = (PARTFRACT_0(t)^(1-EXPCOST2))*YGROSS_R(t)*COST1_0(t)*(MIU(t)^EXPCOST2);
        Y_R(t)         = YNET_R(t)-ABATECOST_R(t);
        I_R(t)         = S(t)*Y_R(t);
        C_R(t)         = max(C_LOW, Y_R(t)-I_R(t));
        CperC_R(t)     = (C_R(t)/L_0(t))*1000;
        K_R(t+1)       = ((1-DK)^TSTEP)*K_R(t)+TSTEP*I_R(t);
        YGROSS_R(t+1)  = AL_0(t+1)*((L_0(t+1)/1000)^(1-GAMMA))*(K_R(t+1)^GAMMA);
        EIND_R(t+1)    = SIGMA_0(t+1)*(1-MIU(t+1))*YGROSS_R(t+1); 
    end;          
 
    
    
    
%--------------------------------------------------------------------------
% Calcs for social welfare   
%--------------------------------------------------------------------------       
    t = (year_NPV-2010)/5+1;
    W = 0;
    L_0(end)=[];
    
    % Initialization
    temp                  = length(years(t):years(end));
    C_R_i                 = zeros(length(temp),1);
    L_0_i                 = zeros(length(temp),1); 
    UTILperC_i            = zeros(length(temp),1);
    UTIL_i                = zeros(length(temp),1);
    
    % Interpolation
    C_R_i                 = interp1(years(t:end),C_R(t:end),years(t):years(end),'linear')';
    L_0_i                 = interp1(years(t:end),L_0(t:end),years(t):years(end),'linear')';

    
    % Utility per year
    tt = 0;
    for tau = years(t):end_date-1; tt = tt + 1;
        UTILperC_i(tt)     = ((C_R_i(tt)/L_0_i(tt))^(1-eta))/(1-eta);
        UTIL_i(tt)         = UTILperC_i(tt)*L_0_i(tt);
    end;
    
    % Ramsey discounting:
    tt = 0;
    for tau = years(t):end_date-1; tt = tt + 1;
        W = W + UTIL_i(tt)*(1+rho)^(-tt);  
    end;
       
   
    W = - W;

end

