%==========================================================================
% MODEL_PCF_OPT_PATHS_vFINAL.m
%==========================================================================
% Date last updated: 28 October 2015

clear all; close all; clc;

 
%==========================================================================
%==========================================================================
%==========================================================================   
 % CHOICE OF THE DAMAGE FUNCTION SPECIFICATION
 
    QUADRATIC  = 1;  
        % 1 if choice of quadratic function, 0 if use of alternative damage function based on Weitzman 2012  
        % If QUADRATIC = 1, this means the damage function is as in
        % DICE-2007 (NOT DICE-2013): DAMAGES = YGROSS(t)* [AD1*TATM(t)+AD2*TATM(t)^2]/[1+(AD1*TATM(t)+AD2*TATM(t)^2)^10];
        
    WEITZMAN   = 0;  
        % 1 if choice of alternative damage function based on Weitzman 2012, 0 if quadratic
        % If WEITZMAN = 1, this means the damage function is as in
        % WEITZMAN 2012: DAMAGES = YGROSS(t)-YGROSS(t)/(1+(AW2*TATM(t))^2+(AW7*TATM(t))^AWGAMMA);
    
        % Check that the Boolean indicators for the damage function
        % specification are correct
        temp = QUADRATIC + WEITZMAN;
        ErrorMessage=['Error: check choice of damage function specification'];
        if ne(temp,1) 
            disp(ErrorMessage);break;
        end;
 
%==========================================================================
%==========================================================================
%==========================================================================
        
  % Number of MC iterations
    MC         = 1; % number of MC simulations
    MC_max     = 1; % number of MC simulations which will be written in Excel file
 
 % PCF switch   
    PCF        = 0; % replace 1 by 0 if you want to remove the PCF                
        
 % End date
    end_date   = 2300;
    nb_periods = (end_date-2010)/5+1;
%==========================================================================
%==========================================================================
%==========================================================================
% Import emissions control rate (MIU) from Excel file


if QUADRATIC == 1
    InputFile = [pwd,'\OUTPUT_OPT_MIU_W_NOPCF_T2C_QUAD.xlsx'];
    MIU = xlsread(InputFile,'OPT_MIU_W_NOPCF_QUAD'); 
    elseif WEITZMAN == 1
    InputFile = [pwd,'\OUTPUT_OPT_MIU_W_NOPCF_T2C_WEITZ.xlsx'];
    MIU = xlsread(InputFile,'OPT_MIU_W_NOPCF_WEITZ');
end;
MIU = MIU(:,2); 
temp = nb_periods+1;
MIU = MIU(1:temp);
MIU = round(MIU*1e3)/1e3;
    
% Import savings rate (S) from Excel file
    
InputFile = [pwd,'\INPUT_S.xlsx'];
S = xlsread(InputFile,'SAVINGS'); 
S = S(:,2);  
S = S(1:temp);
S = round(S*1e3)/1e3;

%==========================================================================
%==========================================================================
%==========================================================================
% A) DICE-2013 FIXED PARAMETERS

iterations = MC;
years      = [2010:5:end_date]'; % (NB: model is based on a 5 year time step)

count      = 0;
starttime  = cputime;
      
% Time step
TSTEP       = 5;         % Years per period

% Population
POP0        = 6838;      % Initial population (in millions) 
POPADJ      = 0.134490;  % Growth rate to calibrate to 2050 pop projection

% Technology
GAMMA       = 0.300;     % Capital elasticity in production function
DK          = 0.100;     % Depreciation rate on capital per year
Q0          = 66.950;    % 2005 world gross output trill 2005 US dollars   
K0          = 135;       % 2005 value capital trill 2005 US dollars
AL0         = 3.7976214; % Initial level of total factor productivity
DELA        = 0.006;     % Decline rate of technological change per decade

% Emissions
ELAND0      = 1.53972;   % Carbon emissions from land 2010 [GtC per year]
DELAND      = 0.2;       % Decline rate of land emissions (per period)
E0          = 32.73738;  % Industrial emissions GtC 2010 (GtCO2 per year)
MIU0        = 0.005;     % Initial emissions control rate for base case 2010
SIG0        = 8930*3.666/66.95/1000;% Carbon intensity 2010 (kgCO2 per output 2005 USD 2010)
    SIG0 = round(SIG0*1e9)/1e9;
DSIG        = -0.001;    % Decline rate of decarbonization (per period)

% Carbon cycle
    % Initial conditions
MAT0        = 818.985;          % Initial concentration in atmosphere 2010 (GtC)
MU0         = 1527;             % Initial concentration in upper strata 2010 (GtC)
ML0         = 10010;            % Initial concentration in lower strata 2010 (GtC)
MATEQ       = 588;              % Equilibrium concentration atmosphere
MUEQ        = 1350;             % Equilibrium concentration in upper strata
MLEQ        = 10000;            % Equilibrium concentration in lower strate 
 
% Climate model parameters
FEX0        = -0.06;     % Estimate of 2010 forcings of non-C02 GHG (Wm -2)
FEX1        = 0.62;      % Estimate of 2100 forcings of non-C02 GHG (Wm -2)
TOCEAN0     = 0.0068;    % Initial lower strat. temp change (degrees C) from  1900
TATM0       = 0.830;     % Initial atmpspheric temp change [C] from  1900
C3          = 0.088;     % Transfer coefficient upper to lower stratum
C4          = 0.025;     % Transfer coefficient for lower level
FCO22X      = 3.8;       % Estimated forcings of equilibrium CO2 doubling (Wm -2)

% Climate damage parameters 
AD1          = 0;            % Damage intercept

% Abatement cost
EXPCOST2    = 2.8;       % Exponent of control cost function
GBACK       = 0.025;     % Initial cost decline backstop cost per period
MIU_LIMIT2  = 0.8448;    % Emissions control rate in 2050 in the Limit2 scenario of DICE-2013R
LIMMIU      = 1.2;       % Upper limit on control rate after 2150
TNOPOL      = 45;        % Period before which no emissions control base
CPRICE0     = 1.0;       % Initial base carbon price (2005$ per tCO2)
GCPRICE     = 0.02;      % Growth rate of base carbon price per year

% Participation
PERIODFULLPART  = 21;    % Period at which we have full participation
PARTFRACT2010   = 1;     % Fraction of emissions under control regime in 2010
PARTFRACTFULL   = 1;     % Fraction of emissions under control at full time

% Transient TSC correction ("Speed of Adjustment Parameter")
C1 = 0.104;

% Coefficients from Gt[CO2/CH4] to GtC
coeff_CO2 = round((44/12)*1e3)/1e3;
coeff_CH4 = round((16/12)*1e3)/1e3;

% Constant discount rate
rate = 0.03; 

% Ramsey discounting
eta  = 2;         
rho  = 0.01;      

% End date for SCC calcs
last_date_SCC = 2050; 
last_period_SCC = (last_date_SCC-2010)/5+1;

% WEITZMAN damage function
AW2     = 1/20.46; 
AW7     = 1/6.081;
AWGAMMA = 6.754;


%--------------------------------------------------------------------------
%--------------------------------------------------------------------------
% B) PCF MODULE FIXED PARAMETERS

% 1. PCF module
PF_C            = 1035;  % amount of carbon in near-surface permafrost (GtC)
PCF_beta        = 0.172; % beta coefficient
e_fold          = 70;    % e-folding time of permafrost carbon decomposition (years)
prop_passive    = 0.4;   % proportion of thawed carbon in the passive pool
prop_CH4        = 0.023; % proportion of methane emissions

% 2. Methane cycle
CH4_conv        = 2.7476;  
CH4_tropo       = 9.8; 
CH4_soil        = 120;
CH4_strato      = 150;
CH4_net_lft     = 1/(1/CH4_tropo + 1/CH4_soil + 1/CH4_strato);
CH4_net_lft     = round(CH4_net_lft*1e6)/1e6;
CH4_lambda      = 0.036;
CH4_mu          = 0.12;
CH4_M0          = 722;
N2O_N0          = 270;
CH4_CONC0       = 4860; % Initial methane concentration (Tg CH4)


% 3. Other forcings
FHA_2010 = -0.40722;
FHA_2100 = -0.15944;


% 4. Import other (non PCF) CH4 emissions (RCP scenarios)
InputFile = [pwd,'\INPUT_CH4_N2O.xlsx'];
CH4_OTHER_EMISSIONS_0 = xlsread(InputFile,'CH4'); 
CH4_OTHER_EMISSIONS_0 = CH4_OTHER_EMISSIONS_0(:,2);
temp = nb_periods;
CH4_OTHER_EMISSIONS_0 = CH4_OTHER_EMISSIONS_0(1:temp);
CH4_OTHER_EMISSIONS_0 = round(CH4_OTHER_EMISSIONS_0*1e3)/1e3;


% 5. Import N2O concentration path(RCP scenarios)
N2O_CONC_0 = xlsread(InputFile,'N2O');  
N2O_CONC_0 = N2O_CONC_0(:,2); 
temp = nb_periods;
N2O_CONC_0 = N2O_CONC_0(1:temp);
N2O_CONC_0 = round(N2O_CONC_0*1e6)/1e6;

% 6. Calculate other radiative forcing ( halocarbons, aerosols) 
RAD_OTHER_PCF_0= zeros(length(years),1);  
t = 0;
for year = years(1:end)'; t = t + 1;
if t<19
RAD_OTHER_PCF_0(t) = FHA_2010+(t-1)/((2100-2010)/5)*(FHA_2100-FHA_2010);
elseif t>=19
RAD_OTHER_PCF_0(t) = FHA_2100;
end;
end;

%--------------------------------------------------------------------------
%--------------------------------------------------------------------------
% C) STABILITY CONSTRAINTS (from DICE 2008 GAMS script)

K_LOW       = 1;     % Minimum capital (US$ trillions)
MAT_LOW     = 10;    % Maximum carbon concentration in the atmosphere
MU_LOW      = 100;   % Minimum carbon concentration in shallow oceans
ML_LOW      = 1000;  % Minimum carbon concentration in lower oceans
C_LOW       = 2;     % Minimum consumption (US$ trillions)
TOCEAN_HIGH = 20;    % Maximum temperature of lower oceans (degrees C)
TOCEAN_LOW  = -1;    % Minimum temperature of lower oceans (degrees C)
TATM_HIGH   = 40;    % Maximum temperature of atmosphere (degrees C)
CPC_LOW     = 0.01;  % Minimum consumption per capita

%--------------------------------------------------------------------------
%--------------------------------------------------------------------------
% C) INITIALIZATION OF OUTPUT VECTORS AND MATRICES
  
% Uncertain inputs (column vectors)
MC_Nb                = zeros(length(MC),1);
PF_C_Vect            = zeros(length(MC),1);
PCF_beta_Vect        = zeros(length(MC),1);
e_fold_Vect          = zeros(length(MC),1);
prop_passive_Vect    = zeros(length(MC),1);
prop_CH4_Vect        = zeros(length(MC),1);
            
% Matrices of main outputs (MC x Years)
L_0_MC               = zeros(length(MC), length(years));  % Population (reference)
GA_0_MC              = zeros(length(MC), length(years));  % Growth rate of TFP (per year)
GA_5yrs_0_MC         = zeros(length(MC), length(years));  % Growth rate of TFP (per 5 years)
AL_0_MC              = zeros(length(MC), length(years));  % Level of TFP
GSIG_0_MC            = zeros(length(MC), length(years));  % Change in sigma
SIGMA_0_MC           = zeros(length(MC), length(years));  % CO2eq-emissions / output ratio
CPRICE_0_MC          = zeros(length(MC), length(years));  % Carbon price
PBACKTIME_0_MC       = zeros(length(MC), length(years));  % Price of the backstop
CPRICE_0_MC          = zeros(length(MC), length(years));  % Carbon price
COST1_0_MC           = zeros(length(MC), length(years));
ETREE_0_MC           = zeros(length(MC), length(years));  % Emissions from land use change (reference)
FORCOTH_0_MC         = zeros(length(MC), length(years));  % Exogenous forcing (reference)

MU_R_MC              = zeros(length(MC), length(years));  % Upper ocean carbon concentration (reference)
MU_MC                = zeros(length(MC), length(years));  % Upper ocean carbon concentration (perturbed)
MU_PCF_R_MC          = zeros(length(MC), length(years)); 
MU_PCF_MC            = zeros(length(MC), length(years)); 

MAT_R_MC             = zeros(length(MC), length(years));  % Atmospheric carbon concentration (reference)
MAT_MC               = zeros(length(MC), length(years));  % Atmospheric carbon concentration (perturbed)
MAT_PCF_R_MC         = zeros(length(MC), length(years));
MAT_PCF_MC           = zeros(length(MC), length(years));

ML_R_MC              = zeros(length(MC), length(years));  % Lower ocean carbon concentration (reference)
ML_MC                = zeros(length(MC), length(years));  % Lower ocean carbon concentration (perturbed)
ML_PCF_R_MC          = zeros(length(MC), length(years)); 
ML_PCF_MC            = zeros(length(MC), length(years));  

MATAV_R_MC           = zeros(length(MC), length(years));  % 2-decade lag atmospheric carbon concentration (reference)
MATAV_MC             = zeros(length(MC), length(years));  % 2-decade lag atmospheric carbon concentration (perturbed)
MATAV_PCF_R_MC       = zeros(length(MC), length(years));
MATAV_PCF_MC         = zeros(length(MC), length(years));

FORC_R_MC            = zeros(length(MC), length(years));  % Total forcing (reference)
FORC_MC              = zeros(length(MC), length(years));  % Total forcing (perturbed)
FORC_PCF_R_MC        = zeros(length(MC), length(years));
FORC_PCF_MC          = zeros(length(MC), length(years));

YGROSS_R_MC          = zeros(length(MC), length(years));  % World product gross of abatement and damages (reference)
YGROSS_MC            = zeros(length(MC), length(years));  % World product gross of abatement and damages (perturbed)
YGROSS_PCF_R_MC      = zeros(length(MC), length(years));
YGROSS_PCF_MC        = zeros(length(MC), length(years));

EIND_R_MC            = zeros(length(MC), length(years));  % Industrial emissions (reference)
EIND_MC              = zeros(length(MC), length(years));  % Industrial emissions (perturbed)
EIND_PCF_R_MC        = zeros(length(MC), length(years));
EIND_PCF_MC          = zeros(length(MC), length(years));

E_R_MC               = zeros(length(MC), length(years));  % Total emissions (reference)
E_MC                 = zeros(length(MC), length(years));  % Total emissions (perturbed)    
E_PCF_R_MC           = zeros(length(MC), length(years));
E_PCF_MC             = zeros(length(MC), length(years));  

TATM_R_MC            = zeros(length(MC), length(years));  % Atmospheric temperature (reference)
TATM_MC              = zeros(length(MC), length(years));  % Atmospheric temperature (perturbed)
TATM_PCF_R_MC        = zeros(length(MC), length(years));
TATM_PCF_MC          = zeros(length(MC), length(years));

TOCEAN_R_MC          = zeros(length(MC), length(years));  % Atmospheric temperature (reference)
TOCEAN_MC            = zeros(length(MC), length(years));  % Atmospheric temperature (perturbed)
TOCEAN_PCF_R_MC      = zeros(length(MC), length(years));
TOCEAN_PCF_MC        = zeros(length(MC), length(years));

REL_DAMAGES_R_MC     = zeros(length(MC), length(years));  % Relative damages (reference)
REL_DAMAGES_MC       = zeros(length(MC), length(years));  % Relative damages (perturbed)
REL_DAMAGES_PCF_R_MC = zeros(length(MC), length(years));
REL_DAMAGES_PCF_MC   = zeros(length(MC), length(years));

DAMAGES_R_MC         = zeros(length(MC), length(years));  % Damages (reference)
DAMAGES_MC           = zeros(length(MC), length(years));  % Damages (perturbed)
DAMAGES_PCF_R_MC     = zeros(length(MC), length(years));
DAMAGES_PCF_MC       = zeros(length(MC), length(years));

YNET_R_MC            = zeros(length(MC), length(years));  % Output net of damages (reference)
YNET_MC              = zeros(length(MC), length(years));  % Output net of damages (perturbed)
YNET_PCF_R_MC        = zeros(length(MC), length(years));
YNET_PCF_MC          = zeros(length(MC), length(years));

ABATECOST_R_MC       = zeros(length(MC), length(years));  % Abatement costs (reference)
ABATECOST_MC         = zeros(length(MC), length(years));  % Abatement costs (perturbed)
ABATECOST_PCF_R_MC   = zeros(length(MC), length(years));
ABATECOST_PCF_MC     = zeros(length(MC), length(years));

Y_R_MC               = zeros(length(MC), length(years));  % Output net of damages and abatement (reference)
Y_MC                 = zeros(length(MC), length(years));  % Output net of damages and abatement (perturbed)
Y_PCF_R_MC           = zeros(length(MC), length(years)); 
Y_PCF_MC             = zeros(length(MC), length(years));

I_R_MC               = zeros(length(MC), length(years));  % Investment (reference)
I_MC                 = zeros(length(MC), length(years));  % Investment (perturbed)
I_PCF_R_MC           = zeros(length(MC), length(years)); 
I_PCF_MC             = zeros(length(MC), length(years));  

C_R_MC               = zeros(length(MC), length(years));  % Consumption (reference)
C_MC                 = zeros(length(MC), length(years));  % Consumption (perturbed)
C_PCF_R_MC           = zeros(length(MC), length(years));
C_PCF_MC             = zeros(length(MC), length(years));  

CperC_R_MC                 = zeros(length(MC), length(years));  % Consumption per capita (reference)
CperC_MC                   = zeros(length(MC), length(years));  % Consumption per capita (perturbed)
CperC_PCF_R_MC             = zeros(length(MC), length(years));  
CperC_PCF_MC               = zeros(length(MC), length(years));

K_R_MC                     = zeros(length(MC), length(years));  % Capital(reference)
K_MC                       = zeros(length(MC), length(years));  % Capital(perturbed)
K_PCF_R_MC                 = zeros(length(MC), length(years));
K_PCF_MC                   = zeros(length(MC), length(years)); 

SCC_const_MC               = zeros(length(MC), length(years(1:last_period_SCC)));  % SCC w/out the PCF (constant discounting)
SCC_ram_MC                 = zeros(length(MC), length(years(1:last_period_SCC)));  % SCC w/out the PCF (Ramsey discounting)

SCC_PCF_const_MC             = zeros(length(MC), length(years(1:last_period_SCC)));  % SCC w/out the PCF (constant discounting)
SCC_PCF_ram_MC               = zeros(length(MC), length(years(1:last_period_SCC)));  % SCC w/out the PCF (Ramsey discounting)

SCC_PCF_const_MC_QUADRATIC   = zeros(length(MC), length(years(1:last_period_SCC)));
SCC_PCF_const_MC_WEITZMAN    = zeros(length(MC), length(years(1:last_period_SCC))); 

CH4_OTHER_EMISSIONS_0_MC     = zeros(length(MC), length(years));
N2O_CONC_0_MC                = zeros(length(MC), length(years));

FLUX_CH4_EMISSIONS_PCF_R_MC  = zeros(length(MC), length(years));
FLUX_CH4_EMISSIONS_PCF_MC    = zeros(length(MC), length(years));

CH4_CONC_PPMV_PCF_R_MC       = zeros(length(MC), length(years));
CH4_CONC_PPMV_PCF_MC         = zeros(length(MC), length(years));

RAD_CH4_PCF_R_MC             = zeros(length(MC), length(years));
RAD_CH4_PCF_MC               = zeros(length(MC), length(years));

RAD_N2O_PCF__R_MC            = zeros(length(MC), length(years));
RAD_N2O_PCF_MC               = zeros(length(MC), length(years));

RAD_TOT_PCF__R_MC            = zeros(length(MC), length(years));
RAD_TOT_PCF_MC               = zeros(length(MC), length(years));
%--------------------------------------------------------------------------
%--------------------------------------------------------------------------


    MU_POPASYM    = 10500;
    MU_T2XCO2     = 3.2;
    MU_B12        = 8.8;
    MU_AD2        = 0.002131*1.25;
    MU_A7         = 0.0828;
    MU_GA0        = (1/(1-0.079))^(1/5)-1;
    MU_GSIGMA1    = -0.01;
    MU_CPRICE2050 = 260;
       
        
    POPASYM       = MU_POPASYM;
    T2XCO2        = MU_T2XCO2;
    B12           = MU_B12;
    AD2           = MU_AD2;
    A7            = MU_A7;
    GA0           = MU_GA0;  
    GSIGMA1       = MU_GSIGMA1;
    CPRICE2050    = MU_CPRICE2050; 

                
    % Retrieve initial growth of TFP per 5 years
    GA0_5yrs = 1-(1/(1+GA0))^5;
    GA0_5yrs = round(GA0_5yrs*1e9)/1e9;
   
    % ******* ACHTUNG*******
    GA0_5yrs = 0.079; % DICE ORIGINAL SETTING
   
    % Retrieve initial cost of backstop price (PBACK)
    % cf formula in Word document
    % NB: 2050 = period 9
    PBACK = CPRICE2050/((1-GBACK)^(9-1)*MIU_LIMIT2^(EXPCOST2-1));
    PBACK = round(PBACK*1e9)/1e9;
   
    % ******* ACHTUNG*******
    PBACK = 344; % DICE ORIGINAL SETTING

 
    
%--------------------------------------------------------------------------
%--------------------------------------------------------------------------
% E) MONTE CARLO SIMULATIONS

for mc = 1:MC;
    
    % Print status to screen:
    count = count + 1;
    if fix(mc/100)-mc/100==0;
        clc;
        fprintf(' %-.0f of %-.0f minor iterations.\n',mc,MC); 
        fprintf('    [Est time to completion = %-.1f min]\n',...
        (cputime-starttime)/count*(iterations-count)/60);
    end;
    
    %----------------------------------------------------------------------
    % E.1.d) Carbon cycle coefficients matrix
    %---------------------------------------------------------------------- 
    B23     = 0.250;              % Carbon cycle transition matrix
    B11     = 100 - B12;          % Carbon cycle transition matrix
    B21     = B12*MATEQ/MUEQ;     % Carbon cycle transition matrix
    B21     = round(B21*1e3)/1e3; % (to avoid discrepancies with the Excel file)
    B22     = 100 - B21 - B23;    % Carbon cycle transition matrix
    B32     = B23*MUEQ/MLEQ;      % Carbon cycle transition matrix
    B32     = round(B32*1e5)/1e5; % (to avoid discrepancies with the Excel file)
    B33     = 100 - B32;          % Carbon cycle transition matrix
    
    %----------------------------------------------------------------------
    % E.1.e) Initialize output variables paths (column vectors for each MC iteration)  
    %----------------------------------------------------------------------
    
    % Reference paths which don't depend on emissions
    L_0               = zeros(length(years),1);  % Population
    AL_0              = zeros(length(years),1);  % Level of total factor productivity
    GFACPOP_R         = zeros(length(years),1);  % Growth factor of population
    GA_0              = zeros(length(years),1);  % Growth rate of productivity
    GSIG_0            = zeros(length(years),1);  % Cumulative improvement of energy efficiency
    SIGMA_0           = zeros(length(years),1);  % Co2-eq emissions-output ratio
    CPRICE_0          = zeros(length(years),1);  % Carbon price
    FORCOTH_0         = zeros(length(years),1);  % Exogenous forcing
    PARTFRACT_0       = zeros(length(years),1);  % Fraction of emissions in control regime
    PBACKTIME_0       = zeros(length(years),1);  % Backstop price
    COST1_0           = zeros(length(years),1);  % Adjusted cost for backstop
    ETREE_0           = zeros(length(years),1);  % decline rate of land emissions per year = 0.1
    
    % Reference paths of variables which depend on emissions (no PCF)
    YGROSS_R          = zeros(length(years),1);  % World product gross of abatement and damages
    MAT_R             = zeros(length(years),1);  % Atmospheric carbon concentration
    MU_R              = zeros(length(years),1);  % Upper ocean carbon concentration
    ML_R              = zeros(length(years),1);  % Lower ocean carbon concentration
    MATAV_R           = zeros(length(years),1);  % 2-decade lag atmospheric carbon conc.
    FORC_R            = zeros(length(years),1);  % Total forcing 
    TATM_R            = zeros(length(years),1);  % Atmospheric temperature
    TOCEAN_R          = zeros(length(years),1);  % Ocean temperature
    REL_DAMAGES_R     = zeros(length(years),1);  % Relative damages
    DAMAGES_R         = zeros(length(years),1);  % Climate damages
    YNET_R            = zeros(length(years),1);  % Output after damages before abatement
    ABATECOST_R       = zeros(length(years),1);  % Cost of emissions reduction
    Y_R               = zeros(length(years),1);  % Output net of damages and abatement
    I_R               = zeros(length(years),1);  % Investment
    C_R               = zeros(length(years),1);  % Consumption
    CperC_R           = zeros(length(years),1);  % Consumption per capita ($000s per year)
    K_R               = zeros(length(years),1);  % Capital stock
    EIND_R            = zeros(length(years),1);  % Industrial emissions
    E_R               = zeros(length(years),1);  % Total emissions   
        
    % Reference paths of variables which depend on emissions (PCF)
    YGROSS_PCF_R      = zeros(length(years),1);  % World product gross of abatement and damages
    MAT_PCF_R         = zeros(length(years),1);  % Atmospheric carbon concentration
    MU_PCF_R          = zeros(length(years),1);  % Upper ocean carbon concentration
    ML_PCF_R          = zeros(length(years),1);  % Lower ocean carbon concentration
    MATAV_PCF_R       = zeros(length(years),1);  % 2-decade lag atmospheric carbon conc.
    FORC_PCF_R        = zeros(length(years),1);  % Total forcing 
    TATM_PCF_R        = zeros(length(years),1);  % Atmospheric temperature
    TOCEAN_PCF_R      = zeros(length(years),1);  % Ocean temperature
    REL_DAMAGES_PCF_R = zeros(length(years),1);  % Relative damages
    DAMAGES_PCF_R     = zeros(length(years),1);  % Climate damages
    YNET_PCF_R        = zeros(length(years),1);  % Output after damages before abatement
    ABATECOST_PCF_R   = zeros(length(years),1);  % Cost of emissions reduction
    Y_PCF_R           = zeros(length(years),1);  % Output net of damages and abatement
    I_PCF_R           = zeros(length(years),1);  % Investment
    C_PCF_R           = zeros(length(years),1);  % Consumption
    CperC_PCF_R       = zeros(length(years),1);  % Consumption per capita ($000s per year)
    K_PCF_R           = zeros(length(years),1);  % Capital stock
    EIND_PCF_R        = zeros(length(years),1);  % Industrial emissions
    E_PCF_R           = zeros(length(years),1);  % Total emissions 
             
    % Perturbed paths of variables which depend on emissions (no PCF)  
    YGROSS            = zeros(length(years),1);    % World product gross of abatement and damages
    MAT               = zeros(length(years),1);    % Atmospheric carbon concentration
    MU                = zeros(length(years),1);    % Upper ocean carbon concentration
    ML                = zeros(length(years),1);    % Lower ocean carbon concentration
    MATAV             = zeros(length(years),1);    % 2-decade lag atmospheric carbon conc.
    FORC              = zeros(length(years),1);    % Total forcing 
    TATM              = zeros(length(years),1);    % Atmospheric temperature
    TOCEAN            = zeros(length(years),1);    % Ocean temperature
    REL_DAMAGES       = zeros(length(years),1);    % Relative damages
    DAMAGES           = zeros(length(years),1);    % Climate damages
    YNET              = zeros(length(years),1);    % Output after damages before abatement
    ABATECOST         = zeros(length(years),1);    % Cost of emissions reduction
    MCABATE           = zeros(length(years),1);    % Marginal cost of abatement
    Y                 = zeros(length(years),1);    % Output net of damages and abatement
    I                 = zeros(length(years),1);    % Investment
    C                 = zeros(length(years),1);    % Consumption
    CperC             = zeros(length(years),1);    % Consumption per capita ( in 000s of 2005 $s per year)
    K                 = zeros(length(years),1);    % Capital stock
    EIND              = zeros(length(years),1);    % Industrial emissions
    CumEIND           = zeros(length(years),1);    % Cumulative industrial emissions
    E                 = zeros(length(years),1);    % Total emissions   
     
    % Perturbed paths of variables which depend on emissions (PCF)  
    YGROSS_PCF        = zeros(length(years),1);    % World product gross of abatement and damages
    MAT_PCF           = zeros(length(years),1);    % Atmospheric carbon concentration
    MU_PCF            = zeros(length(years),1);    % Upper ocean carbon concentration
    ML_PCF            = zeros(length(years),1);    % Lower ocean carbon concentration
    MATAV_PCF         = zeros(length(years),1);    % 2-decade lag atmospheric carbon conc.
    FORC_PCF          = zeros(length(years),1);    % Total forcing 
    TATM_PCF          = zeros(length(years),1);    % Atmospheric temperature
    TOCEAN_PCF        = zeros(length(years),1);    % Ocean temperature
    REL_DAMAGES_PCF   = zeros(length(years),1);    % Relative damages
    DAMAGES_PCF       = zeros(length(years),1);    % Climate damages
    YNET_PCF          = zeros(length(years),1);    % Output after damages before abatement
    ABATECOST_PCF     = zeros(length(years),1);    % Cost of emissions reduction
    MCABATE_PCF       = zeros(length(years),1);    % Marginal cost of abatement
    Y_PCF             = zeros(length(years),1);    % Output net of damages and abatement
    I_PCF             = zeros(length(years),1);    % Investment
    C_PCF             = zeros(length(years),1);    % Consumption
    CperC_PCF         = zeros(length(years),1);    % Consumption per capita ( in 000s of 2005 $s per year)
    K_PCF             = zeros(length(years),1);    % Capital stock
    EIND_PCF          = zeros(length(years),1);    % Industrial emissions
    CumEIND_PCF       = zeros(length(years),1);    % Cumulative industrial emissions
    E_PCF             = zeros(length(years),1);    % Total emissions  
           
    %----------------------------------------------------------------------
    % E.1.f) Calculate reference paths for variables that DO NOT depend on
    % emissions levels (noted NAME_0)  
    %----------------------------------------------------------------------
        
    % Variables
    % L_0         = Population
    % GFACPOP_0   = Growth factor of population
    % GA_0        = Growth rate of productivity
    % AL_0        = Level of total factor productivity
    % GSIG_0      = Cumulative improvement of energy efficiency
    % SIGMA_0     = Co2-eq emissions-output ratio
    % FORCOTH_0   = Exogenous forcing
    % PARTFRACT_0 = Fraction of emissions in control regime
    % ETREE_0     = Emissions from land use change
    % COST1_0     = Adjusted cost for backstop
        
    % Paths initialization:
    L_0(1)          = POP0;
    GA_0(1)         = GA0_5yrs; 
    AL_0(1)         = AL0;
    GSIG_0(1)       = GSIGMA1; 
    SIGMA_0(1)      = SIG0;
    PBACKTIME_0(1)  = PBACK;
    COST1_0(1)      = PBACK*SIGMA_0(1)/EXPCOST2/1000;
    ETREE_0(1)      = ELAND0;
    FORCOTH_0(1)    = FEX0+0.05*(FEX1-FEX0)*(1+1);
    PARTFRACT_0(1)  = PARTFRACT2010;
    
    % Paths calculations:
    t = 1;
    for year = years(1:end)'; t = t + 1;
        L_0(t)= L_0(t-1)*(POPASYM/L_0(t-1))^POPADJ; 
        GA_0(t) = GA0_5yrs*exp(-DELA*TSTEP*(t-1)); 
        AL_0(t) = AL_0(t-1)/((1-GA_0(t-1))); 
            
        % **GSIG** - first value of GSIG = GSIGMA1 is for year 2 (as GSIG = growth rate)
        if t<=2
        GSIG_0(t)  = GSIGMA1;
        elseif t>2
        GSIG_0(t)  = GSIG_0(t-1)*((1+DSIG)^TSTEP);
        end;
        
        SIGMA_0(t) = SIGMA_0(t-1)*(exp(GSIG_0(t)*TSTEP));
        PBACKTIME_0(t) = PBACK*(1-GBACK)^(t-1);
        COST1_0(t)  = PBACKTIME_0(t)*SIGMA_0(t)/EXPCOST2/1000;
        ETREE_0(t) = ELAND0*((1-DELAND)^(t-1)); 
        
        % **FORCOTH** - change after period 19
        if t<19
        FORCOTH_0(t) = FEX0+0.05*(FEX1-FEX0)*(t+1); % as in the Excel model for DICE 2013R on Nordhaus' website
        elseif t>=19
        FORCOTH_0(t) = FEX1;
        end;
                
        PARTFRACT_0(t) = (PARTFRACT2010 + (PARTFRACTFULL-PARTFRACT2010)*(t-1)/PERIODFULLPART)*(t<PERIODFULLPART+1) + PARTFRACTFULL*(t>PERIODFULLPART) ;
    end;
  
          
    %----------------------------------------------------------------------
    %----------------------------------------------------------------------
    % E.2)MODEL WITHOUT PCF MODULE
    %----------------------------------------------------------------------
    
    %----------------------------------------------------------------------
    % E.2.a) Calculate reference paths for variables that do depend on
    % emissions (no PCF)
    %----------------------------------------------------------------------  
    
    % Reference paths initialization:
    K_R(1)         = K0; 
    YGROSS_R(1)    = AL_0(1)*(L_0(1)/1000)^(1-GAMMA)*(K_R(1)^GAMMA);
    YGROSS_R(1)    = round(YGROSS_R(1)*1e3)/1e3;
    EIND_R(1)      = SIGMA_0(1)*(1-MIU(1))*YGROSS_R(1);
    CumEIND_R(1)   = EIND_R(1)*coeff_CO2*5;
    E_R(1)         = EIND_R(1)+ ETREE_0(1);
    MAT_R(1)       = MAT0;
    ML_R(1)        = ML0; 
    MU_R(1)        = MU0; 
    FORC_R(1)      = FCO22X*log((MAT_R(1)/588.000))/log(2) + FORCOTH_0(1); 
    TATM_R(1)      = TATM0; 
    TOCEAN_R(1)    = TOCEAN0; 
    
    % Damages (quadratic or as in Weitzman, depending on the
    % initial setting - cf lines 35-40) 
    if QUADRATIC == 1
        DAMAGES_R(1) = YGROSS_R(1)*(AD1*TATM_R(1) + AD2*TATM_R(1)^2)/(1+(AD1*TATM_R(1) + AD2*TATM_R(1)^2)^10);
        REL_DAMAGES_R(1) = AD1*TATM_R(1) + AD2*TATM_R(1)^2;
    elseif WEITZMAN == 1
        DAMAGES_R(1) = YGROSS_R(1)-YGROSS_R(1)/(1 + (AW2*TATM_R(1))^2 + (AW7*TATM_R(1))^AWGAMMA);
        REL_DAMAGES_R(1) = 1-1/(1 + (AW2*TATM_R(1))^2 + (AW7*TATM_R(1))^AWGAMMA);
    end;
        
    YNET_R(1)      = YGROSS_R(1)-DAMAGES_R(1);
    ABATECOST_R(1) = (PARTFRACT_0(1)^(1-EXPCOST2))*YGROSS_R(1)*COST1_0(1)*(MIU(1)^EXPCOST2);
    Y_R(1)         = YNET_R(1)-ABATECOST_R(1);
    I_R(1)         = S(1)*Y_R(1);
    C_R(1)         = max(C_LOW, Y_R(1)-I_R(1));
    CperC_R(1)     = (C_R(1)/L_0(1))*1000;
    K_R(2)         = max(K_LOW, ((1-DK)^TSTEP)*K_R(1)+TSTEP*I_R(1));
    YGROSS_R(2)    = AL_0(2)*(L_0(2)/1000)^(1-GAMMA)*(K_R(2)^GAMMA);
    EIND_R(2)      = SIGMA_0(2)*(1-MIU(2))*YGROSS_R(2);
    
    % Reference paths calculations:
    t=1;
    for year = years(1:end-1)'; t = t + 1;
        CumEIND_R(t)   = CumEIND_R(t-1) + EIND_R(t)*coeff_CO2*5;
        E_R(t)         = EIND_R(t)+ ETREE_0(t);
        MAT_R(t)       = max(MAT_LOW, B11/100*MAT_R(t-1) + B21/100*MU_R(t-1) + E_R(t-1)*5/coeff_CO2); % cf lower bound MAT_LOW
        ML_R(t)        = max(ML_LOW, B23/100*MU_R(t-1) + B33/100*ML_R(t-1)); % cf lower bound ML_LOW
        MU_R(t)        = max(MU_LOW, B12/100*MAT_R(t-1) + B22/100*MU_R(t-1) + B32/100*ML_R(t-1)); % cf lower bound MU_LOW
        FORC_R(t)      = FCO22X * (log((MAT_R(t)/588.000))/log(2)) + FORCOTH_0(t); 
        TATM_R(t)      = min(TATM_HIGH, TATM_R(t-1) + C1*(FORC_R(t) - FCO22X/T2XCO2*TATM_R(t-1) - C3*(TATM_R(t-1) - TOCEAN_R(t-1))));
        
        % Upper and lower bounds on atmospheric temperature
        if TOCEAN_R(t-1) + C4*(TATM_R(t-1)-TOCEAN_R(t-1))>=0
        TOCEAN_R(t)    = min(TOCEAN_HIGH, TOCEAN_R(t-1) + C4*(TATM_R(t-1)-TOCEAN_R(t-1)));
            elseif TOCEAN_R(t-1) + C4*(TATM_R(t-1)-TOCEAN_R(t-1))<0
        TOCEAN_R(t)    = max(TOCEAN_LOW, TOCEAN_R(t-1) + C4*(TATM_R(t-1)-TOCEAN_R(t-1)));
        end;
        
        % Damages (quadratic or as in Weitzman, depending on the
        % initial setting - cf lines 35-40) 
        if QUADRATIC == 1
        DAMAGES_R(t) = YGROSS_R(t)*(AD1*TATM_R(t) + AD2*TATM_R(t)^2)/(1+(AD1*TATM_R(t) + AD2*TATM_R(t)^2)^10);
        REL_DAMAGES_R(t) = AD1*TATM_R(t) + AD2*TATM_R(t)^2;
            elseif WEITZMAN == 1
        DAMAGES_R(t) = YGROSS_R(t)-YGROSS_R(t)/(1 + (AW2*TATM_R(t))^2 + (AW7*TATM_R(t))^AWGAMMA);
        REL_DAMAGES_R(t) = 1-1/(1 + (AW2*TATM_R(t))^2 + (AW7*TATM_R(t))^AWGAMMA);
        end;
                       
        YNET_R(t)      = YGROSS_R(t)-DAMAGES_R(t);
        ABATECOST_R(t) = (PARTFRACT_0(t)^(1-EXPCOST2))*YGROSS_R(t)*COST1_0(t)*(MIU(t)^EXPCOST2);
        Y_R(t)         = YNET_R(t)-ABATECOST_R(t);
        I_R(t)         = S(t)*Y_R(t);
        C_R(t)         = max(C_LOW, Y_R(t)-I_R(t));
        CperC_R(t)     = (C_R(t)/L_0(t))*1000;
        K_R(t+1)       = ((1-DK)^TSTEP)*K_R(t)+TSTEP*I_R(t);
        YGROSS_R(t+1)  = AL_0(t+1)*((L_0(t+1)/1000)^(1-GAMMA))*(K_R(t+1)^GAMMA);
        EIND_R(t+1)    = SIGMA_0(t+1)*(1-MIU(t+1))*YGROSS_R(t+1); 
    end;          
    
    %----------------------------------------------------------------------      
    % E.2.b) Introduction of a mitigation project
    %----------------------------------------------------------------------  
    
    % We now introduce a mitigation project: as in the SCC exercise by the EPA (2008), the perturbed emissions' path is modelled as a reduction of 1 unit of
    % emissions in year 2. We then calculate the consequently perturbed paths.
    
    % The following paths do not change
    % L_0         = Population
    % GFACPOP_0   = Growth factor of population
    % GA_0        = Growth rate of productivity
    % AL_0        = Level of total factor productivity
    % GSIG_0      = Cumulative improvement of energy efficiency
    % SIGMA_0     = Co2-eq emissions-output ratio
    % FORCOTH_0   = Exogenous forcing
    % PARTFRACT_0 = Fraction of emissions in control regime
    % ETREE_0     = Emissions from land use change
    % COST1_0     = Adjusted cost for backstop
 
    
    % We now calculate the perturbed paths for the variables which depend on the level of emissions :
        
    % Perturbed paths initialization: 
    K(1)           = K0; 
    YGROSS(1)      = AL_0(1)*(L_0(1)/1000)^(1-GAMMA)*(K(1)^GAMMA);
    YGROSS(1)      = round(YGROSS(1)*1e3)/1e3;
    EIND(1)        = SIGMA_0(1)*(1-MIU(1))*YGROSS(1);
    
    CumEIND(1)     = EIND(1)*coeff_CO2*5;
    E(1)           = EIND(1)+ ETREE_0(1);
    MAT(1)         = MAT0;
    ML(1)          = ML0; 
    MU(1)          = MU0; 
    FORC(1)        = FCO22X*log((MAT(1)/588.000))/log(2) + FORCOTH_0(1); 
    TATM(1)        = TATM0; 
    TOCEAN(1)      = TOCEAN0; 
    
    % Damages (quadratic or as in Weitzman, depending on the
    % initial setting - cf lines 35-40)
    if QUADRATIC == 1
    DAMAGES(1) = YGROSS(1)*(AD1*TATM(1) + AD2*TATM(1)^2)/(1+(AD1*TATM(1) + AD2*TATM(1)^2)^10);
    REL_DAMAGES(1) = AD1*TATM(1) + AD2*TATM(1)^2;
        elseif WEITZMAN == 1
    DAMAGES(1) = YGROSS(1)-YGROSS(1)/(1 + (AW2*TATM(1))^2 + (AW7*TATM(1))^AWGAMMA);
    REL_DAMAGES(1) = 1-1/(1 + (AW2*TATM(1))^2 + (AW7*TATM(1))^AWGAMMA);
    end;        
    
    YNET(1)        = YGROSS(1)-DAMAGES(1);
    ABATECOST(1)   = (PARTFRACT_0(1)^(1-EXPCOST2))*YGROSS(1)*COST1_0(1)*(MIU(1)^EXPCOST2);
    Y(1)           = YNET(1)-ABATECOST(1);
    I(1)           = S(1)*Y(1);
    C(1)           = max(C_LOW, Y(1)-I(1));
    CperC(1)       = (C(1)/L_0(1))*1000;
    K(2)           = max(K_LOW, ((1-DK)^TSTEP)*K(1)+TSTEP*I(1));
    YGROSS(2)      = AL_0(2)*(L_0(2)/1000)^(1-GAMMA)*(K(2)^GAMMA);
    
    % Additional unit of emissions in year 2:
    EIND(2)        = (SIGMA_0(2)*(1-MIU(2))*YGROSS(2))+1;
    
    % Perturbed paths calculations:
    t=1;
    for year = years(1:end-1)'; t = t + 1;
        CumEIND(t)     = CumEIND(t-1) + EIND(t)*coeff_CO2*5;
        E(t)           = EIND(t)+ ETREE_0(t);
        MAT(t)         = max(MAT_LOW, B11/100*MAT(t-1) + B21/100*MU(t-1) + E(t-1)*5/coeff_CO2); % cf lower bound MAT_LOW
        ML(t)          = max(ML_LOW, B23/100*MU(t-1) + B33/100*ML(t-1)); % cf lower bound ML_LOW
        MU(t)          = max(MU_LOW, B12/100*MAT(t-1) + B22/100*MU(t-1) + B32/100*ML(t-1)); % cf lower bound MU_LOW
        FORC(t)        = FCO22X * (log((MAT(t)/588.000))/log(2)) + FORCOTH_0(t); 
        TATM(t)        = min(TATM_HIGH, TATM(t-1) + C1*(FORC(t) - FCO22X/T2XCO2*TATM(t-1) - C3*(TATM(t-1) - TOCEAN(t-1))));
        
        % Upper and lower bounds on atmospheric temperature
        if TOCEAN(t-1) + C4*(TATM(t-1)-TOCEAN(t-1))>=0
        TOCEAN(t)      = min(TOCEAN_HIGH, TOCEAN(t-1) + C4*(TATM(t-1)-TOCEAN(t-1)));
            elseif TOCEAN(t-1) + C4*(TATM(t-1)-TOCEAN(t-1))<0
        TOCEAN(t)      = max(TOCEAN_LOW, TOCEAN(t-1) + C4*(TATM(t-1)-TOCEAN(t-1)));
        end;
          
        % Damages (quadratic or as in Weitzman, depending on the
        % initial setting - cf lines 35-40)
        if QUADRATIC == 1
        DAMAGES(t) = YGROSS(t)*(AD1*TATM(t) + AD2*TATM(t)^2)/(1+(AD1*TATM(t) + AD2*TATM(t)^2)^10);
        REL_DAMAGES(t) = AD1*TATM(t) + AD2*TATM(t)^2;
            elseif WEITZMAN == 1
        DAMAGES(t) = YGROSS(t)-YGROSS(t)/(1 + (AW2*TATM(t))^2 + (AW7*TATM(t))^AWGAMMA);
        REL_DAMAGES(t) = 1-1/(1 + (AW2*TATM(t))^2 + (AW7*TATM(t))^AWGAMMA);
        end;

        YNET(t)        = YGROSS(t)-DAMAGES(t);
        ABATECOST(t)   = (PARTFRACT_0(t)^(1-EXPCOST2))*YGROSS(t)*COST1_0(t)*(MIU(t)^EXPCOST2);
        Y(t)           = YNET(t)-ABATECOST(t);
        I(t)           = S(t)*Y(t);
        C(t)           = max(C_LOW, Y(t)-I(t));
        CperC(t)       = (C(t)/L_0(t))*1000;
        K(t+1)         = ((1-DK)^TSTEP)*K(t)+TSTEP*I(t);
        YGROSS(t+1)    = AL_0(t+1)*((L_0(t+1)/1000)^(1-GAMMA))*(K(t+1)^GAMMA);
        EIND(t+1)      = SIGMA_0(t+1)*(1-MIU(t+1))*YGROSS(t+1); 
    end;
   

   
    %----------------------------------------------------------------------
    % E.3)MODEL WITH PCF MODULE
    %----------------------------------------------------------------------
    %----------------------------------------------------------------------
      
    %----------------------------------------------------------------------
    % E.3.a) Calculate reference paths for variables that do depend on
    % emissions (PCF)
    %----------------------------------------------------------------------  
    
    
    % Reference paths initialization:
    %K_PCF_R(1)                        = K0; 
    %YGROSS_PCF_R(1)                   = AL_0(1)*(L_0(1)/1000)^(1-GAMMA)*(K_PCF_R(1)^GAMMA);
    %YGROSS_PCF_R(1)                   = round(YGROSS_PCF_R(1)*1e3)/1e3;
    %EIND_PCF_R(1)                     = SIGMA_0(1)*(1-MIU(1))*YGROSS_PCF_R(1);
    %CumEIND_PCF_R(1)                  = EIND_PCF_R(1)*coeff_CO2*5;
    %E_PCF_R(1)                        = EIND_PCF_R(1)+ ETREE_0(1);
    %MAT_PCF_R(1)                      = MAT0;
    %ML_PCF_R(1)                       = ML0; 
    %MU_PCF_R(1)                       = MU0; 
    %FORC_PCF_R(1)                     = FCO22X*log((MAT_PCF_R(1)/588.000))/log(2) + FORCOTH_0(1); 
    %TATM_PCF_R(1)                     = TATM0;
    
    %PROP_REMAIN_PCF_R(1)              = 1;
    %CUM_THAWED_PCF_R(1)               =(1-PROP_REMAIN_PCF_R(1))*PF_C;
    %FLUX_THAWED_PCF_R(1)              = CUM_THAWED_PCF_R(1)-CUM_THAWED_PCF_R(1);
    %FLUX_VULN_PCF_R(1)                = (1-prop_passive)*FLUX_THAWED_PCF_R(1);
    %CUM_PROP_DECOMP_PCF_R(1)          = 0;
    %FLUX_PROP_DECOMP_PCF_R(1)         = 0;
    %FLUX_C_EMISSIONS_PCF_R(1)         = FLUX_PROP_DECOMP_PCF_R(1)*FLUX_VULN_PCF_R(1);
    %CUM_C_EMISSIONS_PCF_R(1)          = FLUX_C_EMISSIONS_PCF_R(1);
    %FLUX_CH4_EMISSIONS_PCF_R(1)       = FLUX_C_EMISSIONS_PCF_R(1)*prop_CH4*1000*coeff_CH4;
    %CUM_CH4_EMISSIONS_PCF_R(1)        = FLUX_CH4_EMISSIONS_PCF_R(1);
    %FLUX_CO2_EMISSIONS_PCF_R(1)       = FLUX_C_EMISSIONS_PCF_R(1)*(1-prop_CH4);
    %CUM_CO2_EMISSIONS_PCF_R(1)        = FLUX_CO2_EMISSIONS_PCF_R(1);
    %FLUX_CO2_EMISSIONS_GTCO2_PCF_R(1) = FLUX_C_EMISSIONS_PCF_R(1)*(1-prop_CH4)/coeff_CO2;
    %CUM_CO2_EMISSIONS_GTCO2_PCF_R(1)  = FLUX_CO2_EMISSIONS_GTCO2_PCF_R(1);
    %CH4_CONC_PCF_R(1)                 = CH4_CONC0;
    %CH4_CONC_PPMV_PCF_R(1)            = CH4_CONC_PCF_R(1)/CH4_conv;
    %RAD_CH4_PCF_R(1)                  = CH4_lambda*(CH4_CONC_PPMV_PCF_R(1)^0.5-CH4_M0^0.5)-(0.47*log(1+2.01*10^(-5)*(CH4_CONC_PPMV_PCF_R(1)*N2O_CONC_0(1))^0.75+5.31*10^(-15)*CH4_CONC_PPMV_PCF_R(1)*(CH4_CONC_PPMV_PCF_R(1)*N2O_CONC_0(1))^1.52)-0.47*log(1+2.01*10^(-5)*(CH4_M0*N2O_CONC_0(1))^0.75+5.31*10^(-15)*CH4_M0*(CH4_M0*N2O_CONC_0(1))^1.52));
    %RAD_N2O_PCF_R(1)                  = CH4_mu*(N2O_CONC_0(1)^0.5-N2O_N0^0.5)-(0.47*log(1+2.01*10^(-5)*(CH4_CONC_PPMV_PCF_R(1)*N2O_CONC_0(1))^0.75+5.31*10^(-15)*CH4_CONC_PPMV_PCF_R(1)*(CH4_CONC_PPMV_PCF_R(1)*N2O_CONC_0(1))^1.52)-0.47*log(1+2.01*10^(-5)*(CH4_CONC_PPMV_PCF_R(1)*N2O_N0)^0.75+5.31*10^(-15)*CH4_CONC_PPMV_PCF_R(1)*(CH4_CONC_PPMV_PCF_R(1)*N2O_N0)^1.52));
    %RAD_TOT_PCF_R(1)                  = RAD_CH4_PCF_R(1)+ RAD_N2O_PCF_R(1) + RAD_OTHER_PCF_0(1);
    
    %TOCEAN_PCF_R(1)                 = TOCEAN0; 
    
        % Damages (quadratic or as in Dietz and Asheim, depending on the
        % initial setting - cf lines 35-40) 
        %if QUADRATIC == 1
        %DAMAGES_PCF_R(1) = YGROSS_PCF_R(1)*(AD1*TATM_PCF_R(1) + AD2*TATM_PCF_R(1)^2)/(1+(AD1*TATM_PCF_R(1) + AD2*TATM_PCF_R(1)^2)^10);
        %REL_DAMAGES_PCF_R(1) = AD1*TATM_PCF_R(1) + AD2*TATM_PCF_R(1)^2;
        %elseif WEITZMAN == 1
        %DAMAGES_PCF_R(1) = YGROSS_PCF_R(1)-YGROSS_PCF_R(1)/(1 + (AW2*TATM_PCF_R(1))^2 + (AW7*TATM_PCF_R(1))^AWGAMMA);
        %REL_DAMAGES_PCF_R(1) = 1-1/(1 + (AW2*TATM_PCF_R(1))^2 + (AW7*TATM_PCF_R(1))^AWGAMMA);
        %end;
        
    %YNET_PCF_R(1)                   = YGROSS_PCF_R(1)-DAMAGES_PCF_R(1);
    %ABATECOST_PCF_R(1)              = (PARTFRACT_0(1)^(1-EXPCOST2))*YGROSS_PCF_R(1)*COST1_0(1)*(MIU(1)^EXPCOST2);
    %Y_PCF_R(1)                      = YNET_PCF_R(1)-ABATECOST_PCF_R(1);
    %I_PCF_R(1)                      = S(1)*Y_PCF_R(1);
    %C_PCF_R(1)                      = max(C_LOW, Y_PCF_R(1)-I_PCF_R(1));
    %CperC_PCF_R(1)                  = (C_PCF_R(1)/L_0(1))*1000;
    %K_PCF_R(2)                      = max(K_LOW, ((1-DK)^TSTEP)*K_PCF_R(1)+TSTEP*I_PCF_R(1));
    %YGROSS_PCF_R(2)                 = AL_0(2)*(L_0(2)/1000)^(1-GAMMA)*(K_PCF_R(2)^GAMMA);
    %EIND_PCF_R(2)                   = SIGMA_0(2)*(1-MIU(2))*YGROSS_PCF_R(2);
    
    % Reference paths calculations:
    %t=1;
    %for year = years(1:end-1)'; t = t + 1;
        %CumEIND_PCF_R(t)            = CumEIND_PCF_R(t-1) + EIND_PCF_R(t)*coeff_CO2*5;
        %MAT_PCF_R(t)                = max(MAT_LOW, B11/100*MAT_PCF_R(t-1) + B21/100*MU_PCF_R(t-1) + E_PCF_R(t-1)*5/coeff_CO2); % cf lower bound MAT_LOW
        %ML_PCF_R(t)                 = max(ML_LOW, B23/100*MU_PCF_R(t-1) + B33/100*ML_PCF_R(t-1)); % cf lower bound ML_LOW
        %MU_PCF_R(t)                 = max(MU_LOW, B12/100*MAT_PCF_R(t-1) + B22/100*MU_PCF_R(t-1) + B32/100*ML_PCF_R(t-1)); % cf lower bound MU_LOW
        
        %if PCF == 0
            %FORC_PCF_R(t)           = FCO22X * (log((MAT_PCF_R(t)/588.000))/log(2)) + FORCOTH_0(t); 
        %elseif PCF == 1
            %FORC_PCF_R(t)           = FCO22X * (log((MAT_PCF_R(t)/588.000))/log(2)) + RAD_TOT_PCF_R(t-1);
        %end;
           
        %TATM_PCF_R(t)               = min(TATM_HIGH, TATM_PCF_R(t-1) + C1*(FORC_PCF_R(t) - FCO22X/T2XCO2*TATM_PCF_R(t-1) - C3*(TATM_PCF_R(t-1) - TOCEAN_PCF_R(t-1))));
        
        % PCF MODULE: THAWING (GtC)
        %PROP_REMAIN_PCF_R(t)       = max(1-PCF_beta*(TATM_PCF_R(t)-TATM_PCF_R(1)),0);
        %CUM_THAWED_PCF_R(t)         = (1-PROP_REMAIN_PCF_R(t))*PF_C;
        %FLUX_THAWED_PCF_R(t)        = CUM_THAWED_PCF_R(t)-CUM_THAWED_PCF_R(t-1);
                
        % PCF MODULE: CARBON DECOMPOSITION SCHEDULE
        %CUM_PROP_DECOMP_PCF_R(t)    = (1-exp(-5*(t-1)/e_fold));
        %FLUX_PROP_DECOMP_PCF_R(t)   = CUM_PROP_DECOMP_PCF_R(t)-CUM_PROP_DECOMP_PCF_R(t-1); % DO NOT PREALLOCATE FOR SPEED (cf flip)
        
        % PCF MODULE: VULNERABLE CARBON (GtC)
        %FLUX_VULN_PCF_R(t)          = (1-prop_passive)*FLUX_THAWED_PCF_R(t);
        
        % PCF MODULE: DECOMPOSED CARBON (GtC)
        %FLUX_C_EMISSIONS_PCF_R(t)   = sum(FLUX_VULN_PCF_R(1:t).*flip(FLUX_PROP_DECOMP_PCF_R(1:t)));
        %CUM_C_EMISSIONS_PCF_R(t)    = CUM_C_EMISSIONS_PCF_R(t-1)+ FLUX_C_EMISSIONS_PCF_R(t);
        
        % PCF MODULE: METHANE EMISSIONS(Tg CH4)
        %FLUX_CH4_EMISSIONS_PCF_R(t) = FLUX_C_EMISSIONS_PCF_R(t)*prop_CH4*1000*coeff_CH4;
        %CUM_CH4_EMISSIONS_PCF_R(t)  = CUM_CH4_EMISSIONS_PCF_R(t-1)+FLUX_CH4_EMISSIONS_PCF_R(t);
        
        % PCF MODULE: CO2 EMISSIONS(GtC)
        %FLUX_CO2_EMISSIONS_PCF_R(t) = FLUX_C_EMISSIONS_PCF_R(t)*(1-prop_CH4);
        %CUM_CO2_EMISSIONS_PCF_R(t)  = CUM_CO2_EMISSIONS_PCF_R(t-1)+FLUX_CO2_EMISSIONS_PCF_R(t);
        
        % PCF MODULE: CO2 EMISSIONS(GtC)
        %FLUX_CO2_EMISSIONS_GTCO2_PCF_R(t) = FLUX_C_EMISSIONS_PCF_R(t)*(1-prop_CH4)/coeff_CO2;
        %CUM_CO2_EMISSIONS_GTCO2_PCF_R(t)  = CUM_CO2_EMISSIONS_GTCO2_PCF_R(t-1)+FLUX_CO2_EMISSIONS_GTCO2_PCF_R(t);
        
        % METHANE CYCLE (Tg CH4)
        %CH4_CONC_PCF_R(t)           = CH4_CONC_PCF_R(t-1)*(1-1/CH4_net_lft)+FLUX_CH4_EMISSIONS_PCF_R(t) + CH4_OTHER_EMISSIONS_0(t);
        %CH4_CONC_PPMV_PCF_R(t)      = CH4_CONC_PCF_R(t)/CH4_conv; 

        % RADIATIVE FORCING FROM CH4 AND N2O
        %RAD_CH4_PCF_R(t)            = CH4_lambda*(CH4_CONC_PPMV_PCF_R(t)^0.5-CH4_M0^0.5)-(0.47*log(1+2.01*10^(-5)*(CH4_CONC_PPMV_PCF_R(t)*N2O_CONC_0(t))^0.75+5.31*10^(-15)*CH4_CONC_PPMV_PCF_R(t)*(CH4_CONC_PPMV_PCF_R(t)*N2O_CONC_0(t))^1.52)-0.47*log(1+2.01*10^(-5)*(CH4_M0*N2O_CONC_0(t))^0.75+5.31*10^(-15)*CH4_M0*(CH4_M0*N2O_CONC_0(t))^1.52));
        %RAD_N2O_PCF_R(t)            = CH4_mu*(N2O_CONC_0(t)^0.5-N2O_N0^0.5)-(0.47*log(1+2.01*10^(-5)*(CH4_CONC_PPMV_PCF_R(t)*N2O_CONC_0(t))^0.75+5.31*10^(-15)*CH4_CONC_PPMV_PCF_R(t)*(CH4_CONC_PPMV_PCF_R(t)*N2O_CONC_0(t))^1.52)-0.47*log(1+2.01*10^(-5)*(CH4_CONC_PPMV_PCF_R(t)*N2O_N0)^0.75+5.31*10^(-15)*CH4_CONC_PPMV_PCF_R(t)*(CH4_CONC_PPMV_PCF_R(t)*N2O_N0)^1.52));
        
                                                   
        
        % TOTAL NON CO2 RADIATIVE FORCING
        %RAD_TOT_PCF_R(t)            = RAD_CH4_PCF_R(t)+ RAD_N2O_PCF_R(t)+ RAD_OTHER_PCF_0(t);

        
        %if PCF == 0
            %E_PCF_R(t)              = EIND_PCF_R(t)+ ETREE_0(t); 
        %elseif PCF == 1
            %E_PCF_R(t)              = EIND_PCF_R(t)+ ETREE_0(t)+FLUX_CO2_EMISSIONS_PCF_R(t)/5*coeff_CO2;
        %end;
                    
        % Upper and lower bounds on atmospheric temperature
        %if TOCEAN_PCF_R(t-1) + C4*(TATM_PCF_R(t-1)-TOCEAN_PCF_R(t-1))>=0
        %TOCEAN_PCF_R(t)    = min(TOCEAN_HIGH, TOCEAN_PCF_R(t-1) + C4*(TATM_PCF_R(t-1)-TOCEAN_PCF_R(t-1)));
            %elseif TOCEAN_PCF_R(t-1) + C4*(TATM_PCF_R(t-1)-TOCEAN_PCF_R(t-1))<0
        %TOCEAN_PCF_R(t)    = max(TOCEAN_LOW, TOCEAN_PCF_R(t-1) + C4*(TATM_PCF_R(t-1)-TOCEAN_PCF_R(t-1)));
        %end;
        
        % Damages (quadratic or as in Dietz and Asheim, depending on the
        % initial setting - cf lines 35-40) 
        %if QUADRATIC == 1
        %DAMAGES_PCF_R(t) = YGROSS_PCF_R(t)*(AD1*TATM_PCF_R(t) + AD2*TATM_PCF_R(t)^2)/(1+(AD1*TATM_PCF_R(t) + AD2*TATM_PCF_R(t)^2)^10);
        %REL_DAMAGES_PCF_R(t) = AD1*TATM_PCF_R(t) + AD2*TATM_PCF_R(t)^2;
            %elseif WEITZMAN == 1
        %DAMAGES_PCF_R(t) = YGROSS_PCF_R(t)-YGROSS_PCF_R(t)/(1 + (AW2*TATM_PCF_R(t))^2 + (AW7*TATM_PCF_R(t))^AWGAMMA);
        %REL_DAMAGES_PCF_R(t) = 1-1/(1 + (AW2*TATM_PCF_R(t))^2 + (AW7*TATM_PCF_R(t))^AWGAMMA);
        %end;
                       
        %YNET_PCF_R(t)      = YGROSS_PCF_R(t)-DAMAGES_PCF_R(t);
        %ABATECOST_PCF_R(t) = (PARTFRACT_0(t)^(1-EXPCOST2))*YGROSS_PCF_R(t)*COST1_0(t)*(MIU(t)^EXPCOST2);
        %Y_PCF_R(t)         = YNET_PCF_R(t)-ABATECOST_PCF_R(t);
        %I_PCF_R(t)         = S(t)*Y_PCF_R(t);
        %C_PCF_R(t)         = max(C_LOW, Y_PCF_R(t)-I_PCF_R(t));
        %CperC_PCF_R(t)     = (C_PCF_R(t)/L_0(t))*1000;
        %K_PCF_R(t+1)       = ((1-DK)^TSTEP)*K_PCF_R(t)+TSTEP*I_PCF_R(t);
        %YGROSS_PCF_R(t+1)  = AL_0(t+1)*((L_0(t+1)/1000)^(1-GAMMA))*(K_PCF_R(t+1)^GAMMA);
        %EIND_PCF_R(t+1)    = SIGMA_0(t+1)*(1-MIU(t+1))*YGROSS_PCF_R(t+1); 
    %end;          
    
    %----------------------------------------------------------------------      
    % E.2.b) Introduction of a mitigation project
    %----------------------------------------------------------------------  
    
    % We now introduce a mitigation project: as in the SCC exercise by the EPA (2008), the perturbed emissions' path is modelled as a reduction of 1 unit of
    % emissions in year 2. We then calculate the consequently perturbed paths.
    
    % The following paths do not change
    % L_0         = Population
    % GFACPOP_0   = Growth factor of population
    % GA_0        = Growth rate of productivity
    % AL_0        = Level of total factor productivity
    % GSIG_0      = Cumulative improvement of energy efficiency
    % SIGMA_0     = Co2-eq emissions-output ratio
    % FORCOTH_0   = Exogenous forcing
    % PARTFRACT_0 = Fraction of emissions in control regime
    % ETREE_0     = Emissions from land use change
    % COST1_0     = Adjusted cost for backstop
 
    
    % Paths initialization:
    %K_PCF(1)                        = K0; 
    %YGROSS_PCF(1)                   = AL_0(1)*(L_0(1)/1000)^(1-GAMMA)*(K_PCF(1)^GAMMA);
    %YGROSS_PCF(1)                   = round(YGROSS_PCF(1)*1e3)/1e3;
    %EIND_PCF(1)                     = SIGMA_0(1)*(1-MIU(1))*YGROSS_PCF(1);
    %CumEIND_PCF(1)                  = EIND_PCF(1)*coeff_CO2*5;
    %E_PCF(1)                        = EIND_PCF(1)+ ETREE_0(1);
    %MAT_PCF(1)                      = MAT0;
    %ML_PCF(1)                       = ML0; 
    %MU_PCF(1)                       = MU0; 
    %FORC_PCF(1)                     = FCO22X*log((MAT_PCF(1)/588.000))/log(2) + FORCOTH_0(1); 
    %TATM_PCF(1)                     = TATM0;
    
    %PROP_REMAIN_PCF(1)              = 1;
    %CUM_THAWED_PCF(1)               =(1-PROP_REMAIN_PCF(1))*PF_C;
    %FLUX_THAWED_PCF(1)              = CUM_THAWED_PCF(1)-CUM_THAWED_PCF(1);
    %FLUX_VULN_PCF(1)                = (1-prop_passive)*FLUX_THAWED_PCF(1);
    %CUM_PROP_DECOMP_PCF(1)          = 0;
    %FLUX_PROP_DECOMP_PCF(1)         = 0;
    %FLUX_C_EMISSIONS_PCF(1)         = FLUX_PROP_DECOMP_PCF(1)*FLUX_VULN_PCF(1);
    %CUM_C_EMISSIONS_PCF(1)          = FLUX_C_EMISSIONS_PCF(1);
    %FLUX_CH4_EMISSIONS_PCF(1)       = FLUX_C_EMISSIONS_PCF(1)*prop_CH4*1000*coeff_CH4;
    %CUM_CH4_EMISSIONS_PCF(1)        = FLUX_CH4_EMISSIONS_PCF(1);
    %FLUX_CO2_EMISSIONS_PCF(1)       = FLUX_C_EMISSIONS_PCF(1)*(1-prop_CH4);
    %CUM_CO2_EMISSIONS_PCF(1)        = FLUX_CO2_EMISSIONS_PCF(1);
    %FLUX_CO2_EMISSIONS_GTCO2_PCF(1) = FLUX_C_EMISSIONS_PCF(1)*(1-prop_CH4)/coeff_CO2;
    %CUM_CO2_EMISSIONS_GTCO2_PCF(1)  = FLUX_CO2_EMISSIONS_GTCO2_PCF(1);
    %CH4_CONC_PCF(1)                 = CH4_CONC0;
    %CH4_CONC_PPMV_PCF(1)            = CH4_CONC_PCF(1)/CH4_conv;
    %RAD_CH4_PCF(1)                  = CH4_lambda*(CH4_CONC_PPMV_PCF(1)^0.5-CH4_M0^0.5)-(0.47*log(1+2.01*10^(-5)*(CH4_CONC_PPMV_PCF(1)*N2O_CONC_0(1))^0.75+5.31*10^(-15)*CH4_CONC_PPMV_PCF(1)*(CH4_CONC_PPMV_PCF(1)*N2O_CONC_0(1))^1.52)-0.47*log(1+2.01*10^(-5)*(CH4_M0*N2O_CONC_0(1))^0.75+5.31*10^(-15)*CH4_M0*(CH4_M0*N2O_CONC_0(1))^1.52));
    %RAD_N2O_PCF(1)                  = CH4_mu*(N2O_CONC_0(1)^0.5-N2O_N0^0.5)-(0.47*log(1+2.01*10^(-5)*(CH4_CONC_PPMV_PCF(1)*N2O_CONC_0(1))^0.75+5.31*10^(-15)*CH4_CONC_PPMV_PCF(1)*(CH4_CONC_PPMV_PCF(1)*N2O_CONC_0(1))^1.52)-0.47*log(1+2.01*10^(-5)*(CH4_CONC_PPMV_PCF(1)*N2O_N0)^0.75+5.31*10^(-15)*CH4_CONC_PPMV_PCF(1)*(CH4_CONC_PPMV_PCF(1)*N2O_N0)^1.52));
    %RAD_TOT_PCF(1)                  = RAD_CH4_PCF(1)+ RAD_N2O_PCF(1)+ RAD_OTHER_PCF_0(1);
    
    %TOCEAN_PCF(1)                   = TOCEAN0; 
    
        % Damages (quadratic or as in Dietz and Asheim, depending on the
        % initial setting - cf lines 35-40) 
        %if QUADRATIC == 1
        %DAMAGES_PCF(1) = YGROSS_PCF(1)*(AD1*TATM_PCF(1) + AD2*TATM_PCF(1)^2)/(1+(AD1*TATM_PCF(1) + AD2*TATM_PCF(1)^2)^10);
        %REL_DAMAGES_PCF(1) = AD1*TATM_PCF(1) + AD2*TATM_PCF(1)^2;
        %elseif WEITZMAN == 1
        %DAMAGES_PCF(1) = YGROSS_PCF(1)-YGROSS_PCF(1)/(1 + (AW2*TATM_PCF(1))^2 + (AW7*TATM_PCF(1))^AWGAMMA);
        %REL_DAMAGES_PCF(1) = 1-1/(1 + (AW2*TATM_PCF(1))^2 + (AW7*TATM_PCF(1))^AWGAMMA);
        %end;
        
    %YNET_PCF(1)                   = YGROSS_PCF(1)-DAMAGES_PCF(1);
    %ABATECOST_PCF(1)              = (PARTFRACT_0(1)^(1-EXPCOST2))*YGROSS_PCF(1)*COST1_0(1)*(MIU(1)^EXPCOST2);
    %Y_PCF(1)                      = YNET_PCF(1)-ABATECOST_PCF(1);
    %I_PCF(1)                      = S(1)*Y_PCF(1);
    %C_PCF(1)                      = max(C_LOW, Y_PCF(1)-I_PCF(1));
    %CperC_PCF(1)                  = (C_PCF(1)/L_0(1))*1000;
    %K_PCF(2)                      = max(K_LOW, ((1-DK)^TSTEP)*K_PCF(1)+TSTEP*I_PCF(1));
    %YGROSS_PCF(2)                 = AL_0(2)*(L_0(2)/1000)^(1-GAMMA)*(K_PCF(2)^GAMMA);
         
        % Additional unit of emissions in year 2:
    %EIND_PCF(2)                   = SIGMA_0(2)*(1-MIU(2))*YGROSS_PCF(2) + 1;
    
    % Reference paths calculations:
    %t=1;
    %for year = years(1:end-1)'; t = t + 1;
        %CumEIND_PCF(t)            = CumEIND_PCF(t-1) + EIND_PCF(t)*coeff_CO2*5;
        %MAT_PCF(t)                = max(MAT_LOW, B11/100*MAT_PCF(t-1) + B21/100*MU_PCF(t-1) + E_PCF(t-1)*5/coeff_CO2); % cf lower bound MAT_LOW
        %ML_PCF(t)                 = max(ML_LOW, B23/100*MU_PCF(t-1) + B33/100*ML_PCF(t-1)); % cf lower bound ML_LOW
        %MU_PCF(t)                 = max(MU_LOW, B12/100*MAT_PCF(t-1) + B22/100*MU_PCF(t-1) + B32/100*ML_PCF(t-1)); % cf lower bound MU_LOW
        
        %if PCF == 0
            %FORC_PCF(t)           = FCO22X * (log((MAT_PCF(t)/588.000))/log(2)) + FORCOTH_0(t); 
        %elseif PCF == 1
            %FORC_PCF(t)           = FCO22X * (log((MAT_PCF(t)/588.000))/log(2)) + RAD_TOT_PCF(t-1);
        %end;
           
        %TATM_PCF(t)               = min(TATM_HIGH, TATM_PCF(t-1) + C1*(FORC_PCF(t) - FCO22X/T2XCO2*TATM_PCF(t-1) - C3*(TATM_PCF(t-1) - TOCEAN_PCF(t-1))));
        
        % PCF MODULE: THAWING (GtC)
        %PROP_REMAIN_PCF(t)        = max(1-PCF_beta*(TATM_PCF(t)-TATM_PCF(1)),0);
        %CUM_THAWED_PCF(t)         = (1-PROP_REMAIN_PCF(t))*PF_C;
        %FLUX_THAWED_PCF(t)        = CUM_THAWED_PCF(t)-CUM_THAWED_PCF(t-1);
                
        % PCF MODULE: CARBON DECOMPOSITION SCHEDULE
        %CUM_PROP_DECOMP_PCF(t)    = (1-exp(-5*(t-1)/e_fold));
        %FLUX_PROP_DECOMP_PCF(t)   = CUM_PROP_DECOMP_PCF(t)-CUM_PROP_DECOMP_PCF(t-1); % DO NOT PREALLOCATE FOR SPEED (cf flip)
        
        % PCF MODULE: VULNERABLE CARBON (GtC)
        %FLUX_VULN_PCF(t)          = (1-prop_passive)*FLUX_THAWED_PCF(t);
        
        % PCF MODULE: DECOMPOSED CARBON (GtC)
        %FLUX_C_EMISSIONS_PCF(t)   = sum(FLUX_VULN_PCF(1:t).*flip(FLUX_PROP_DECOMP_PCF(1:t)));
        %CUM_C_EMISSIONS_PCF(t)    = CUM_C_EMISSIONS_PCF(t-1)+ FLUX_C_EMISSIONS_PCF(t);
        
        % PCF MODULE: METHANE EMISSIONS(Tg CH4)
        %FLUX_CH4_EMISSIONS_PCF(t) = FLUX_C_EMISSIONS_PCF(t)*prop_CH4*1000*coeff_CH4;
        %CUM_CH4_EMISSIONS_PCF(t)  = CUM_CH4_EMISSIONS_PCF(t-1)+FLUX_CH4_EMISSIONS_PCF(t);
        
        % PCF MODULE: CO2 EMISSIONS(GtC)
        %FLUX_CO2_EMISSIONS_PCF(t) = FLUX_C_EMISSIONS_PCF(t)*(1-prop_CH4);
        %CUM_CO2_EMISSIONS_PCF(t)  = CUM_CO2_EMISSIONS_PCF(t-1)+FLUX_CO2_EMISSIONS_PCF(t);
        
        % PCF MODULE: CO2 EMISSIONS(GtC)
        %FLUX_CO2_EMISSIONS_GTCO2_PCF(t) = FLUX_C_EMISSIONS_PCF(t)*(1-prop_CH4)/coeff_CO2;
        %CUM_CO2_EMISSIONS_GTCO2_PCF(t)  = CUM_CO2_EMISSIONS_GTCO2_PCF(t-1)+FLUX_CO2_EMISSIONS_GTCO2_PCF(t);
        
        % METHANE CYCLE (Tg CH4)
        %CH4_CONC_PCF(t)           = CH4_CONC_PCF(t-1)*(1-1/CH4_net_lft)+FLUX_CH4_EMISSIONS_PCF(t) + CH4_OTHER_EMISSIONS_0(t);
        %CH4_CONC_PPMV_PCF(t)      = CH4_CONC_PCF(t)/CH4_conv; 

        % RADIATIVE FORCING FROM CH4 AND N2O
        %RAD_CH4_PCF(t)            = CH4_lambda*(CH4_CONC_PPMV_PCF(t)^0.5-CH4_M0^0.5)-(0.47*log(1+2.01*10^(-5)*(CH4_CONC_PPMV_PCF(t)*N2O_CONC_0(t))^0.75+5.31*10^(-15)*CH4_CONC_PPMV_PCF(t)*(CH4_CONC_PPMV_PCF(t)*N2O_CONC_0(t))^1.52)-0.47*log(1+2.01*10^(-5)*(CH4_M0*N2O_CONC_0(t))^0.75+5.31*10^(-15)*CH4_M0*(CH4_M0*N2O_CONC_0(t))^1.52));
        %RAD_N2O_PCF(t)            = CH4_mu*(N2O_CONC_0(t)^0.5-N2O_N0^0.5)-(0.47*log(1+2.01*10^(-5)*(CH4_CONC_PPMV_PCF(t)*N2O_CONC_0(t))^0.75+5.31*10^(-15)*CH4_CONC_PPMV_PCF(t)*(CH4_CONC_PPMV_PCF(t)*N2O_CONC_0(t))^1.52)-0.47*log(1+2.01*10^(-5)*(CH4_CONC_PPMV_PCF(t)*N2O_N0)^0.75+5.31*10^(-15)*CH4_CONC_PPMV_PCF(t)*(CH4_CONC_PPMV_PCF(t)*N2O_N0)^1.52));
        
                                                   
        % TOTAL NON CO2 RADIATIVE FORCING
        %RAD_TOT_PCF(t)            = RAD_CH4_PCF(t)+ RAD_N2O_PCF(t)+ RAD_OTHER_PCF_0(t);

        
        %if PCF == 0
            %E_PCF(t)              = EIND_PCF(t)+ ETREE_0(t); 
        %elseif PCF == 1
            %E_PCF(t)              = EIND_PCF(t)+ ETREE_0(t)+FLUX_CO2_EMISSIONS_PCF(t)/5*coeff_CO2;
        %end;
                    
        % Upper and lower bounds on atmospheric temperature
        %if TOCEAN_PCF(t-1) + C4*(TATM_PCF(t-1)-TOCEAN_PCF(t-1))>=0
        %TOCEAN_PCF(t)    = min(TOCEAN_HIGH, TOCEAN_PCF(t-1) + C4*(TATM_PCF(t-1)-TOCEAN_PCF(t-1)));
            %elseif TOCEAN_PCF(t-1) + C4*(TATM_PCF(t-1)-TOCEAN_PCF(t-1))<0
        %TOCEAN_PCF(t)    = max(TOCEAN_LOW, TOCEAN_PCF(t-1) + C4*(TATM_PCF(t-1)-TOCEAN_PCF(t-1)));
        %end;
        
        % Damages (quadratic or as in Dietz and Asheim, depending on the
        % initial setting - cf lines 35-40) 
        %if QUADRATIC == 1
        %DAMAGES_PCF(t) = YGROSS_PCF(t)*(AD1*TATM_PCF(t) + AD2*TATM_PCF(t)^2)/(1+(AD1*TATM_PCF(t) + AD2*TATM_PCF(t)^2)^10);
        %REL_DAMAGES_PCF(t) = AD1*TATM_PCF(t) + AD2*TATM_PCF(t)^2;
            %elseif WEITZMAN == 1
        %DAMAGES_PCF(t) = YGROSS_PCF(t)-YGROSS_PCF(t)/(1 + (AW2*TATM_PCF(t))^2 + (AW7*TATM_PCF(t))^AWGAMMA);
        %REL_DAMAGES_PCF(t) = 1-1/(1 +(AW2*TATM_PCF(t))^2 + (AW7*TATM_PCF(t))^AWGAMMA);
        %end;
                       
        %YNET_PCF(t)      = YGROSS_PCF(t)-DAMAGES_PCF(t);
        %ABATECOST_PCF(t) = (PARTFRACT_0(t)^(1-EXPCOST2))*YGROSS_PCF(t)*COST1_0(t)*(MIU(t)^EXPCOST2);
        %Y_PCF(t)         = YNET_PCF(t)-ABATECOST_PCF(t);
        %I_PCF(t)         = S(t)*Y_PCF(t);
        %C_PCF(t)         = max(C_LOW, Y_PCF(t)-I_PCF(t));
        %CperC_PCF(t)     = (C_PCF(t)/L_0(t))*1000;
        %K_PCF(t+1)       = ((1-DK)^TSTEP)*K_PCF(t)+TSTEP*I_PCF(t);
        %YGROSS_PCF(t+1)  = AL_0(t+1)*((L_0(t+1)/1000)^(1-GAMMA))*(K_PCF(t+1)^GAMMA);
        %EIND_PCF(t+1)    = SIGMA_0(t+1)*(1-MIU(t+1))*YGROSS_PCF(t+1); 
    %end;          
    
    %----------------------------------------------------------------------      
    % Carbon price calculations
    %----------------------------------------------------------------------  
    
    t = 0;
    for year = years(1:end)'; t = t + 1;
        CPRICE_0(t)= (MIU(t)^(EXPCOST2-1))*PBACKTIME_0(t);
    end;
    
        

    %----------------------------------------------------------------------      
    % F) SCC calculations 
    %----------------------------------------------------------------------  
    %----------------------------------------------------------------------
    
    %----------------------------------------------------------------------      
    % F.1) SCC (w/out the PCF)
    %----------------------------------------------------------------------
    
    %SCC_const = zeros(length(years(1:last_period_SCC)),1);
    %SCC_ram   = zeros(length(years(1:last_period_SCC)),1);
    
    L_0(end) = []; % to get rid of the last (t+1)
    
    %t = 1;
    %for year  =  years(2:last_period_SCC)'; t = t + 1; % replace 3 by last_period_SCC
    
    % Interpolation: 
    %C_R_i    = interp1(years(t:end),C_R(t:end),years(t):years(end),'linear')'; 
    %L_0_i    = interp1(years(t:end),L_0(t:end),years(t):years(end),'linear')'; 
    %C_i      = interp1(years(t:end),C(t:end),years(t):years(end),'linear')'; 
                
    % Constant discount rate:
    %tt = 0;
    %for tau = years(t):end_date-1; tt = tt + 1;
    %SCC_const(t) = SCC_const(t) + ( C_R_i(tt+1) - C_i(tt+1) ) * 1/((1+rate)^(tt)); 
    %end;
               
    % Ramsey discounting:
    %tt = 0;
    %for tau = years(t):end_date; tt = tt + 1;
    %SCC_ram(t) = SCC_ram(t) + ( C_R_i(tt) - C_i(tt) ) * exp(-(eta*1/(tt-1+eps)*log((C_R_i(tt)/L_0_i(tt))/(C_R_i(1)/L_0_i(1)))+rho)*(tt-1));  
    %end;
       
    %end;
    
    % Convert SCC path from trillion$/GtC/yr to $/tCO2/yr:
    %SCC_const = SCC_const / (10^-3) * 12/44;
    %SCC_ram = SCC_ram / (10^-3) * 12/44; 
          
    
    %----------------------------------------------------------------------      
    % F.2) SCC (with PCF)
    %----------------------------------------------------------------------
    
    %SCC_PCF_const = zeros(length(years(1:last_period_SCC)),1);
    %SCC_PCF_ram   = zeros(length(years(1:last_period_SCC)),1);
    
    %t = 1;
    %for year  =  years(2:last_period_SCC)'; t = t + 1; % replace 3 by last_period_SCC
    
    % Interpolation: 
    %C_PCF_R_i    = interp1(years(t:end),C_PCF_R(t:end),years(t):years(end),'linear')'; 
    %L_0_i        = interp1(years(t:end),L_0(t:end),years(t):years(end),'linear')'; 
    %C_PCF_i      = interp1(years(t:end),C_PCF(t:end),years(t):years(end),'linear')'; 
                
    % Constant discount rate:
    %tt = 0;
    %for tau = years(t):end_date-1; tt = tt + 1;
    %SCC_PCF_const(t) = SCC_PCF_const(t) + ( C_PCF_R_i(tt+1) - C_PCF_i(tt+1) ) * 1/((1+rate)^(tt)); 
    %end;
               
    % Ramsey discounting:
    %tt = 0;
    %for tau = years(t):end_date; tt = tt + 1;
    %SCC_PCF_ram(t) = SCC_PCF_ram(t) + ( C_PCF_R_i(tt) - C_PCF_i(tt) ) * exp(-(eta*1/(tt-1+eps)*log((C_PCF_R_i(tt)/L_0_i(tt))/(C_PCF_R_i(1)/L_0_i(1)))+rho)*(tt-1));  
    %end;
       
    %end;
    
    % Convert SCC path from trillion$/GtC/yr to $/tCO2/yr:
    %SCC_PCF_const = SCC_PCF_const / (10^-3) * 12/44;
    %SCC_PCF_ram = SCC_PCF_ram / (10^-3) * 12/44;  
    
    
    %----------------------------------------------------------------------      
    % G) Fill in MC matrices
    %----------------------------------------------------------------------  
    %----------------------------------------------------------------------
    
    % - for the 8 uncertain inputs (column vectors)
    
    %PF_C_Vect(mc,1)          = PF_C;
    %PCF_beta_Vect(mc,1)      = PCF_beta;
    %e_fold_Vect(mc,1)        = e_fold;
    %prop_passive_Vect(mc,1)  = prop_passive;
    %prop_CH4_Vect(mc,1)      = prop_CH4;
    
    
       
    % - for the number of MC simulations (colum vectors)  
    MC_Nb(mc) = mc;
       
    % - for variables' paths (MC x Years matrices)  
    
        % -- matrices:
        MIU(end)               = []; % to get rid of the last (t+1)
        S(end)                 = [];
        L_0_MC(mc,:)           = L_0';
        GA_0(end)              = [];
        GA_0_MC(mc,:)          = GA_0';
        AL_0(end)              = [];
        AL_0_MC(mc,:)          = AL_0';
        GSIG_0(end)            = [];
        GSIG_0_MC(mc,:)        = GSIG_0';
        SIGMA_0(end)           = [];
        SIGMA_0_MC(mc,:)       = SIGMA_0';
        CPRICE_0_MC(mc,:)      = CPRICE_0';
        PBACKTIME_0(end)       = [];
        PBACKTIME_0_MC(mc,:)   = PBACKTIME_0';
        COST1_0(end)           = [];
        COST1_0_MC(mc,:)       = COST1_0';
        ETREE_0(end)           = []; % to get rid of the last (t+1)
        ETREE_0_MC(mc,:)       = ETREE_0';
        FORCOTH_0(end)         = []; % to get rid of the last (t+1)
        FORCOTH_0_MC(mc,:)     = FORCOTH_0';
        
        MAT_R_MC(mc,:)         = MAT_R';
        MAT_MC(mc,:)           = MAT';
        %MAT_PCF_R_MC(mc,:)    = MAT_PCF_R';
        %MAT_PCF_MC(mc,:)      = MAT_PCF';
        
        ML_R_MC(mc,:)          = ML_R';
        ML_MC(mc,:)            = ML';
        %ML_PCF_R_MC(mc,:)      = ML_PCF_R';
        %ML_PCF_MC(mc,:)        = ML_PCF';
                
        MU_R_MC(mc,:)          = MU_R'; 
        MU_MC(mc,:)            = MU';
        %MU_PCF_R_MC(mc,:)     = MU_PCF_R'; 
        %MU_PCF_MC(mc,:)       = MU_PCF';
        
        FORC_R_MC(mc,:)        = FORC_R';
        FORC_MC(mc,:)          = FORC';
        %FORC_PCF_R_MC(mc,:)   = FORC_PCF_R';
        %FORC_PCF_MC(mc,:)     = FORC_PCF';
        
        YGROSS_R(end)          = []; % to get rid of the last (t+1)
        YGROSS_R_MC(mc,:)      = YGROSS_R';
        YGROSS(end)            = []; % to get rid of the last (t+1)
        YGROSS_MC(mc,:)        = YGROSS';
        
        %YGROSS_PCF_R(end)     = []; % to get rid of the last (t+1)
        %YGROSS_PCF_R_MC(mc,:) = YGROSS_PCF_R';
        %YGROSS_PCF(end)       = []; % to get rid of the last (t+1)
        %YGROSS_PCF_MC(mc,:)   = YGROSS_PCF';
        
        EIND_R(end)            = []; % to get rid of the last (t+1)
        EIND_R_MC(mc,:)        = EIND_R';
        EIND(end)              = []; % to get rid of the last (t+1)
        EIND_MC(mc,:)          = EIND';
        
        %EIND_PCF_R(end)       = []; % to get rid of the last (t+1)
        %EIND_PCF_R_MC(mc,:)   = EIND_PCF_R';
        %EIND_PCF(end)         = []; % to get rid of the last (t+1)
        %EIND_PCF_MC(mc,:)     = EIND_PCF';
        
        E_R_MC(mc,:)           = E_R';
        E_MC(mc,:)             = E';
        %E_PCF_R_MC(mc,:)      = E_PCF_R';
        %E_PCF_MC(mc,:)        = E_PCF';
        
        TATM_R_MC(mc,:)        = TATM_R';
        TATM_MC(mc,:)          = TATM';
        %TATM_PCF_R_MC(mc,:)   = TATM_PCF_R';
        %TATM_PCF_MC(mc,:)     = TATM_PCF';
        
        %CH4_OTHER_EMISSIONS_0_MC(mc,:)  = CH4_OTHER_EMISSIONS_0';
        
        %N2O_CONC_0_MC(mc,:)   = N2O_CONC_0';
        
        %FLUX_CH4_EMISSIONS_PCF_R_MC(mc,:) = FLUX_CH4_EMISSIONS_PCF_R';
        %FLUX_CH4_EMISSIONS_PCF_MC(mc,:)   = FLUX_CH4_EMISSIONS_PCF';
       
     
        %CH4_CONC_PPMV_PCF_R_MC(mc,:)      = CH4_CONC_PPMV_PCF_R';
        %CH4_CONC_PPMV_PCF_MC(mc,:)        = CH4_CONC_PPMV_PCF';
                
        %RAD_CH4_PCF_R_MC(mc,:)= RAD_CH4_PCF_R';
        %RAD_CH4_PCF_MC(mc,:)  = RAD_CH4_PCF';
     
        %RAD_N2O_PCF_R_MC(mc,:)= RAD_N2O_PCF_R';
        %RAD_N2O_PCF_MC(mc,:)  = RAD_N2O_PCF';
        
        %RAD_TOT_PCF_R_MC(mc,:)= RAD_TOT_PCF_R';
        %RAD_TOT_PCF_MC(mc,:)  = RAD_TOT_PCF';
        
        TOCEAN_R_MC(mc,:)      = TOCEAN_R';
        TOCEAN_MC(mc,:)        = TOCEAN';
        %TOCEAN_PCF_R_MC(mc,:) = TOCEAN_PCF_R';
        %TOCEAN_PCF_MC(mc,:)   = TOCEAN_PCF';
        
        DAMAGES_R_MC(mc,:)     = DAMAGES_R';
        DAMAGES_MC(mc,:)       = DAMAGES';
        %DAMAGES_PCF_R_MC(mc,:)= DAMAGES_PCF_R';
        %DAMAGES_PCF_MC(mc,:)  = DAMAGES_PCF';
        
        REL_DAMAGES_R_MC(mc,:) = REL_DAMAGES_R';
        REL_DAMAGES_MC(mc,:)   = REL_DAMAGES';
        %REL_DAMAGES_PCF_R_MC(mc,:) = REL_DAMAGES_PCF_R';
        %REL_DAMAGES_PCF_MC(mc,:)   = REL_DAMAGES_PCF';
        
        YNET_R_MC(mc,:)        = YNET_R';
        YNET_MC(mc,:)          = YNET';
        %YNET_PCF_R_MC(mc,:)   = YNET_PCF_R';
        %YNET_PCF_MC(mc,:)     = YNET_PCF';
        
        ABATECOST_R_MC(mc,:)   = ABATECOST_R';
        ABATECOST_MC(mc,:)     = ABATECOST';
        %ABATECOST_PCF_R_MC(mc,:) = ABATECOST_PCF_R';
        %ABATECOST_PCF_MC(mc,:)   = ABATECOST_PCF';
        
        Y_R_MC(mc,:)           = Y_R';
        Y_MC(mc,:)             = Y';
        %Y_PCF_R_MC(mc,:)      = Y_PCF_R';
        %Y_PCF_MC(mc,:)        = Y_PCF';
        
        I_R_MC(mc,:)           = I_R';
        I_MC(mc,:)             = I';            
        %I_PCF_R_MC(mc,:)      = I_PCF_R';
        %I_PCF_MC(mc,:)        = I_PCF';
        
        C_R_MC(mc,:)           = C_R';
        C_MC(mc,:)             = C';
        %C_PCF_R_MC(mc,:)      = C_PCF_R';
        %C_PCF_MC(mc,:)        = C_PCF';
        
        CperC_R_MC(mc,:)       = CperC_R';
        CperC_MC(mc,:)         = CperC';
        %CperC_PCF_R_MC(mc,:)  = CperC_PCF_R';
        %CperC_PCF_MC(mc,:)    = CperC_PCF';
        
        K_R(end)               = []; % to get rid of the last (t+1)
        K_R_MC(mc,:)           = K_R';
        K(end)                 = []; % to get rid of the last (t+1)
        K_MC(mc,:)             = K';
        
        %K_PCF_R(end)          = []; % to get rid of the last (t+1)
        %K_PCF_R_MC(mc,:)      = K_PCF_R';
        %K_PCF(end)            = []; % to get rid of the last (t+1)
        %K_PCF_MC(mc,:)        = K_PCF';
                       
        %SCC_const_MC(mc,:)    = SCC_const';
        %SCC_ram_MC(mc,:)      = SCC_ram';
        %SCC_PCF_const_MC(mc,:)= SCC_PCF_const';
        %SCC_PCF_ram_MC(mc,:)  = SCC_PCF_ram';
        
       
        
% End of MC simulations loop
    
end;


%==========================================================================
%==========================================================================
%==========================================================================

 warning off MATLAB:xlswrite:AddSheet;  
 
 
 if QUADRATIC == 1
       filename = [pwd,'\OUTPUT_OPT_W_PATHS_NOPCF_T2C_QUAD.xlsx'];
       
       sheet       = ['OPT_NOPCF_QUAD_MIU'];
       data        = [years MIU];
       data_cells  = num2cell(data);
       xlswrite(filename,data_cells,sheet,'A1');
       
       sheet       = ['OPT_NOPCF_QUAD_CPRICE'];
       data        = [years CPRICE_0];
       data_cells  = num2cell(data);
       xlswrite(filename,data_cells,sheet,'A1');
       
       sheet       = ['OPT_NOPCF_QUAD_E'];
       data        = [years E_R];
       data_cells  = num2cell(data);
       xlswrite(filename,data_cells,sheet,'A1');
       
       sheet       = ['OPT_NOPCF_QUAD_EIND'];
       data        = [years EIND_R];
       data_cells  = num2cell(data);
       xlswrite(filename,data_cells,sheet,'A1');
       
       sheet       = ['OPT_NOPCF_QUAD_MAT'];
       data        = [years MAT_R];
       data_cells  = num2cell(data);
       xlswrite(filename,data_cells,sheet,'A1');
       
       sheet       = ['OPT_NOPCF_QUAD_TATM'];
       data        = [years TATM_R];
       data_cells  = num2cell(data);
       xlswrite(filename,data_cells,sheet,'A1');
       
       sheet       = ['OPT_NOPCF_QUAD_YGROSS'];
       data        = [years YGROSS_R];
       data_cells  = num2cell(data);
       xlswrite(filename,data_cells,sheet,'A1');
 
       sheet       = ['OPT_NOPCF_QUAD_DAMAGES'];
       data        = [years DAMAGES_R];
       data_cells  = num2cell(data);
       xlswrite(filename,data_cells,sheet,'A1');
 
       sheet       = ['OPT_NOPCF_QUAD_ABATECOST'];
       data        = [years ABATECOST_R];
       data_cells  = num2cell(data);
       xlswrite(filename,data_cells,sheet,'A1');

       sheet       = ['OPT_NOPCF_QUAD_REL_ABATECOST'];
       data        = [years ABATECOST_R*100./YGROSS_R];
       data_cells  = num2cell(data);
       xlswrite(filename,data_cells,sheet,'A1')
 
       sheet       = ['OPT_NOPCF_QUAD_C'];
       data        = [years C_R];
       data_cells  = num2cell(data);
       xlswrite(filename,data_cells,sheet,'A1');
       
       
       
 elseif WEITZMAN == 1
       filename = [pwd,'\OUTPUT_OPT_W_PATHS_NOPCF_T2C_WEITZ.xlsx'];
       
       sheet       = ['OPT_NOPCF_WEITZ_MIU'];
       data        = [years MIU];
       data_cells  = num2cell(data);
       xlswrite(filename,data_cells,sheet,'A1');
       
       sheet       = ['OPT_NOPCF_WEITZ_CPRICE'];
       data        = [years CPRICE_0];
       data_cells  = num2cell(data);
       xlswrite(filename,data_cells,sheet,'A1');
       
       sheet       = ['OPT_NOPCF_WEITZ_E'];
       data        = [years E_R];
       data_cells  = num2cell(data);
       xlswrite(filename,data_cells,sheet,'A1');
       
       sheet       = ['OPT_NOPCF_WEITZ_EIND'];
       data        = [years EIND_R];
       data_cells  = num2cell(data);
       xlswrite(filename,data_cells,sheet,'A1');
       
       sheet       = ['OPT_NOPCF_WEITZ_MAT'];
       data        = [years MAT_R];
       data_cells  = num2cell(data);
       xlswrite(filename,data_cells,sheet,'A1');
 
       sheet       = ['OPT_NOPCF_WEITZ_TATM'];
       data        = [years TATM_R];
       data_cells  = num2cell(data);
       xlswrite(filename,data_cells,sheet,'A1');
       
       sheet       = ['OPT_NOPCF_WEITZ_YGROSS'];
       data        = [years YGROSS_R];
       data_cells  = num2cell(data);
       xlswrite(filename,data_cells,sheet,'A1');
       
       sheet       = ['OPT_NOPCF_WEITZ_DAMAGES'];
       data        = [years DAMAGES_R];
       data_cells  = num2cell(data);
       xlswrite(filename,data_cells,sheet,'A1');
 
       sheet       = ['OPT_NOPCF_WEITZ_ABATECOST'];
       data        = [years ABATECOST_R];
       data_cells  = num2cell(data);
       xlswrite(filename,data_cells,sheet,'A1');

       sheet       = ['OPT_NOPCF_WEITZ_REL_ABATECOST'];
       data        = [years ABATECOST_R*100./YGROSS_R];
       data_cells  = num2cell(data);
       xlswrite(filename,data_cells,sheet,'A1')
 
       sheet       = ['OPT_NOPCF_WEITZ_C'];
       data        = [years C_R];
       data_cells  = num2cell(data);
       xlswrite(filename,data_cells,sheet,'A1');
    
 end;
 
 
 
 
%==========================================================================
%==========================================================================
%==========================================================================

% Show when programme has finished running

scriptname = mfilename('fullpath'); 
EndMessage=[scriptname, ' has finished running'];
disp(EndMessage);

%--------------------------------------------------------------------------
%--------------------------------------------------------------------------


 

