function [c, ceq] = constraints_W_PCF_T2C_WEITZ_noconsend(MIU_X)
%UNTITLED Summary of this function goes here
%   Detailed explanation goes here


%==========================================================================
end_date = 2300;
nb_periods = (end_date-2010)/5+1;
years      = [2010:5:end_date]'; % (NB: model is based on a 5 year time step)

%==========================================================================
 % PCF switch   
    PCF = 1; % replace 1 by 0 if you want to remove the PCF
        
%==========================================================================    
  % Choice of damage function specification
    QUADRATIC  = 0;  
        % 1 if choice of quadratic function, 0 if use of alternative damage function based on Weitzman 2012  
        % If QUADRATIC = 1, this means the damage function is as in
        % DICE-2007 (NOT DICE-2013): DAMAGES = YGROSS(t)* [AD1*TATM(t)+AD2*TATM(t)^2]/[1+(AD1*TATM(t)+AD2*TATM(t)^2)^10];
        
    WEITZMAN   = 1;  
        % 1 if choice of alternative damage function based on Weitzman 2012, 0 if quadratic
        % If WEITZMAN = 1, this means the damage function is as in
        % WEITZMAN 2012: DAMAGES = YGROSS(t)-YGROSS(t)/(1+(AW2*TATM(t))^2+(AW7*TATM(t))^AWGAMMA);
       
 
%==========================================================================
  % Optimization
  
  MIU(1) = (1/344)^(1/(2.8-1)); 
  
  MIU_end = ones(8,1);
  
  MIU = [MIU(1);MIU_X;MIU_end]; 

    
%==========================================================================



%--------------------------------------------------------------------------
% DICE-2013 FIXED PARAMETERS
%--------------------------------------------------------------------------
count      = 0;
starttime  = cputime;
      
% Time step
TSTEP       = 5;         % Years per period

% Population
POP0        = 6838;      % Initial population (in millions) 
POPADJ      = 0.134490;  % Growth rate to calibrate to 2050 pop projection

% Technology
GAMMA       = 0.300;     % Capital elasticity in production function
DK          = 0.100;     % Depreciation rate on capital per year
Q0          = 66.950;    % 2005 world gross output trill 2005 US dollars   
K0          = 135;       % 2005 value capital trill 2005 US dollars
AL0         = 3.7976214; % Initial level of total factor productivity
DELA        = 0.006;     % Decline rate of technological change per decade

% Emissions
ELAND0      = 1.53972;   % Carbon emissions from land 2010 [GtC per year]
DELAND      = 0.2;       % Decline rate of land emissions (per period)
E0          = 32.73738;  % Industrial emissions GtC 2010 (GtCO2 per year)
MIU0        = 0.005;     % Initial emissions control rate for base case 2010
SIG0        = 8930*3.666/66.95/1000;% Carbon intensity 2010 (kgCO2 per output 2005 USD 2010)
    SIG0 = round(SIG0*1e9)/1e9;
DSIG        = -0.001;    % Decline rate of decarbonization (per period)

% Carbon cycle
    % Initial conditions
MAT0        = 818.985;          % Initial concentration in atmosphere 2010 (GtC)
MU0         = 1527;             % Initial concentration in upper strata 2010 (GtC)
ML0         = 10010;            % Initial concentration in lower strata 2010 (GtC)
MATEQ       = 588;              % Equilibrium concentration atmosphere
MUEQ        = 1350;             % Equilibrium concentration in upper strata
MLEQ        = 10000;            % Equilibrium concentration in lower strate 
 
% Climate model parameters
FEX0        = -0.06;     % Estimate of 2010 forcings of non-C02 GHG (Wm -2)
FEX1        = 0.62;      % Estimate of 2100 forcings of non-C02 GHG (Wm -2)
TOCEAN0     = 0.0068;    % Initial lower strat. temp change (degrees C) from  1900
TATM0       = 0.830;     % Initial atmpspheric temp change [C] from  1900
C3          = 0.088;     % Transfer coefficient upper to lower stratum
C4          = 0.025;     % Transfer coefficient for lower level
FCO22X      = 3.8;       % Estimated forcings of equilibrium CO2 doubling (Wm -2)

% Climate damage parameters 
AD1          = 0;            % Damage intercept

% Abatement cost
EXPCOST2    = 2.8;       % Exponent of control cost function
GBACK       = 0.025;     % Initial cost decline backstop cost per period
MIU_LIMIT2  = 0.8448;    % Emissions control rate in 2050 in the Limit2 scenario of DICE-2013R
LIMMIU      = 1.2;       % Upper limit on control rate after 2150
TNOPOL      = 45;        % Period before which no emissions control base
CPRICE0     = 1.0;       % Initial base carbon price (2005$ per tCO2)
GCPRICE     = 0.02;      % Growth rate of base carbon price per year

% Participation
PERIODFULLPART  = 21;    % Period at which we have full participation
PARTFRACT2010   = 1;     % Fraction of emissions under control regime in 2010
PARTFRACTFULL   = 1;     % Fraction of emissions under control at full time

% Transient TSC correction ("Speed of Adjustment Parameter")
C1 = 0.104;

% Coefficients from Gt[CO2/CH4] to GtC
coeff_CO2 = round((44/12)*1e3)/1e3;
coeff_CH4 = round((16/12)*1e3)/1e3;


% WEITZMAN damage function
AW2     = 1/20.46; 
AW7     = 1/6.081;
AWGAMMA = 6.754;

% OTHER PARAMETERS        
POPASYM       = 10500;
T2XCO2        = 3.2;
B12           = 8.8;
AD2           = 0.002131*1.25;
GA0           = (1/(1-0.079))^(1/5)-1; 
GSIGMA1       = -0.01;
CPRICE2050    = 260;

% Retrieve initial growth of TFP per 5 years
    GA0_5yrs = 1-(1/(1+GA0))^5;
    GA0_5yrs = round(GA0_5yrs*1e9)/1e9;
   
% ******* ACHTUNG*******
    GA0_5yrs = 0.079; % DICE ORIGINAL SETTING
   
% Retrieve initial cost of backstop price (PBACK)
% cf formula in Word document
% NB: 2050 = period 9
    PBACK = CPRICE2050/((1-GBACK)^(9-1)*MIU_LIMIT2^(EXPCOST2-1));
    PBACK = round(PBACK*1e9)/1e9;
   
% ******* ACHTUNG*******
    PBACK = 344; % DICE ORIGINAL SETTING



%--------------------------------------------------------------------------
% PCF MODULE PARAMETERS
%--------------------------------------------------------------------------

% PCF module
PF_C            = 1035;  % amount of carbon in near-surface permafrost (GtC)
PCF_beta        = 0.172; % beta coefficient
e_fold          = 70;    % e-folding time of permafrost carbon decomposition (years)
prop_passive    = 0.4;   % proportion of thawed carbon in the passive pool
prop_CH4        = 0.023; % proportion of methane emissions

% Methane cycle
CH4_conv        = 2.7476;  
CH4_tropo       = 9.8; 
CH4_soil        = 120;
CH4_strato      = 150;
CH4_net_lft     = 1/(1/CH4_tropo + 1/CH4_soil + 1/CH4_strato);
CH4_net_lft     = round(CH4_net_lft*1e6)/1e6;
CH4_lambda      = 0.036;
CH4_mu          = 0.12;
CH4_M0          = 722;
N2O_N0          = 270;
CH4_CONC0       = 4860; % Initial methane concentration (Tg CH4)


% Other forcings
FHA_2010 = -0.40722;
FHA_2100 = -0.15944;


% Import other (non PCF) CH4 emissions (RCP scenarios)
CH4_OTHER_EMISSIONS_0 = [0.000
592.275
595.021
588.197
589.828
638.980
646.175
666.379
675.091
670.540
677.699
654.492
658.101
601.131
597.647
457.658
438.200
351.805
324.511
450.169
440.777
431.384
421.993
480.213
478.735
477.255
475.778
484.583
484.308
484.030
483.757
485.832
485.832
485.832
485.832
485.832
485.832
485.832
485.832
485.832
485.832
485.832
485.832
485.832
485.832
485.832
485.832
485.832
485.832
485.832
485.832
485.832
485.832
485.832
485.832
485.832
485.832
485.832
485.832];






% 5. Import N2O concentration path(RCP scenarios)

N2O_CONC_0 = [323.07147
326.63661
330.20175
333.680185
337.15862
341.248845
345.33907
349.965675
354.59228
359.65308
364.71388
370.11434
375.5148
380.989905
386.46501
391.662225
396.85944
401.562365
406.26529
409.70788
413.15047
416.59306
420.03565
421.59367
423.15169
424.70971
426.26773
426.441325
426.61492
426.788515
426.96211
426.96211
426.96211
426.96211
426.96211
426.96211
426.96211
426.96211
426.96211
426.96211
426.96211
426.96211
426.96211
426.96211
426.96211
426.96211
426.96211
426.96211
426.96211
426.96211
426.96211
426.96211
426.96211
426.96211
426.96211
426.96211
426.96211
426.96211
426.96211
426.96211];


% 6. Calculate other radiative forcing ( halocarbons, aerosols) 
RAD_OTHER_PCF_0= zeros(length(years),1);  
t = 0;
for year = years(1:end)'; t = t + 1;
if t<19
RAD_OTHER_PCF_0(t) = FHA_2010+(t-1)/((2100-2010)/5)*(FHA_2100-FHA_2010);
elseif t>=19
RAD_OTHER_PCF_0(t) = FHA_2100;
end;
end;

%--------------------------------------------------------------------------
% STABILITY CONSTRAINTS (from DICE 2008 GAMS script)
%--------------------------------------------------------------------------
K_LOW       = 1;     % Minimum capital (US$ trillions)
MAT_LOW     = 10;    % Maximum carbon concentration in the atmosphere
MU_LOW      = 100;   % Minimum carbon concentration in shallow oceans
ML_LOW      = 1000;  % Minimum carbon concentration in lower oceans
C_LOW       = 2;     % Minimum consumption (US$ trillions)
TOCEAN_HIGH = 20;    % Maximum temperature of lower oceans (degrees C)
TOCEAN_LOW  = -1;    % Minimum temperature of lower oceans (degrees C)
TATM_HIGH   = 40;    % Maximum temperature of atmosphere (degrees C)
CPC_LOW     = 0.01;  % Minimum consumption per capita

%--------------------------------------------------------------------------
% Import savings rate (S) from Excel file
%--------------------------------------------------------------------------

   S = [0.258
   0.255
   0.253
   0.250
   0.248
   0.246
   0.245
   0.243
   0.242
   0.241
   0.240
   0.239
   0.239
   0.238
   0.238
   0.237
   0.237
   0.237
   0.237
   0.236
   0.236
   0.236
   0.236
   0.236
   0.237
   0.237
   0.237
   0.237
   0.238
   0.237
   0.238
   0.238
   0.239
   0.239
   0.239
   0.240
   0.240
   0.241
   0.241
   0.242
   0.243
   0.244
   0.245
   0.247
   0.249
   0.247
   0.247
   0.246
   0.244
   0.242
   0.258
   0.258
   0.258
   0.258
   0.258
   0.258
   0.258
   0.258
   0.258
   0.258];

%--------------------------------------------------------------------------
% Carbon cycle coefficients matrix
%--------------------------------------------------------------------------  
        
    B23     = 0.250;              % Carbon cycle transition matrix
    B11     = 100 - B12;          % Carbon cycle transition matrix
    B21     = B12*MATEQ/MUEQ;     % Carbon cycle transition matrix
    B21     = round(B21*1e3)/1e3; % (to avoid discrepancies with the Excel file)
    B22     = 100 - B21 - B23;    % Carbon cycle transition matrix
    B32     = B23*MUEQ/MLEQ;      % Carbon cycle transition matrix
    B32     = round(B32*1e5)/1e5; % (to avoid discrepancies with the Excel file)
    B33     = 100 - B32;          % Carbon cycle transition matrix
    
%--------------------------------------------------------------------------
% Initialize output variables paths (column vectors for each MC iteration)  
%--------------------------------------------------------------------------  
       
    % Reference paths which don't depend on emissions
    L_0               = zeros(length(years),1);  % Population
    AL_0              = zeros(length(years),1);  % Level of total factor productivity
    GFACPOP_R         = zeros(length(years),1);  % Growth factor of population
    GA_0              = zeros(length(years),1);  % Growth rate of productivity
    GSIG_0            = zeros(length(years),1);  % Cumulative improvement of energy efficiency
    SIGMA_0           = zeros(length(years),1);  % Co2-eq emissions-output ratio
    FORCOTH_0         = zeros(length(years),1);  % Exogenous forcing
    PARTFRACT_0       = zeros(length(years),1);  % Fraction of emissions in control regime
    PBACKTIME_0       = zeros(length(years),1);  % Backstop price
    COST1_0           = zeros(length(years),1);  % Adjusted cost for backstop
    ETREE_0           = zeros(length(years),1);  % decline rate of land emissions per year = 0.1
    
    % Reference paths of variables which depend on emissions (PCF)
    YGROSS_PCF_R                    = zeros(length(years),1);  % World product gross of abatement and damages
    MAT_PCF_R                       = zeros(length(years),1);  % Atmospheric carbon concentration
    MU_PCF_R                        = zeros(length(years),1);  % Upper ocean carbon concentration
    ML_PCF_R                        = zeros(length(years),1);  % Lower ocean carbon concentration
    MATAV_PCF_R                     = zeros(length(years),1);  % 2-decade lag atmospheric carbon conc.
    FORC_PCF_R                      = zeros(length(years),1);  % Total forcing 
    TATM_PCF_R                      = zeros(length(years),1);  % Atmospheric temperature
    TOCEAN_PCF_R                    = zeros(length(years),1);  % Ocean temperature
    REL_DAMAGES_PCF_R               = zeros(length(years),1);  % Relative damages
    DAMAGES_PCF_R                   = zeros(length(years),1);  % Climate damages
    YNET_PCF_R                      = zeros(length(years),1);  % Output after damages before abatement
    ABATECOST_PCF_R                 = zeros(length(years),1);  % Cost of emissions reduction
    Y_PCF_R                         = zeros(length(years),1);  % Output net of damages and abatement
    I_PCF_R                         = zeros(length(years),1);  % Investment
    C_PCF_R                         = zeros(length(years),1);  % Consumption
    CperC_PCF_R                     = zeros(length(years),1);  % Consumption per capita ($000s per year)
    K_PCF_R                         = zeros(length(years),1);  % Capital stock
    EIND_PCF_R                      = zeros(length(years),1);  % Industrial emissions
    E_PCF_R                         = zeros(length(years),1);  % Total emissions 
    
    
    PROP_REMAIN_PCF_R               = zeros(length(years),1); 
    CUM_THAWED_PCF_R                = zeros(length(years),1);  
    FLUX_THAWED_PCF_R               = zeros(length(years),1); 
    CUM_PROP_DECOMP_PCF_R           = zeros(length(years),1); 
    FLUX_PROP_DECOMP_PCF_R          = zeros(length(years),1);   
    FLUX_VULN_PCF_R                 = zeros(length(years),1);  
    FLUX_C_EMISSIONS_PCF_R          = zeros(length(years),1);  
    CUM_C_EMISSIONS_PCF_R           = zeros(length(years),1);
    FLUX_CH4_EMISSIONS_PCF_R        = zeros(length(years),1);
    CUM_CH4_EMISSIONS_PCF_R         = zeros(length(years),1);
    FLUX_CO2_EMISSIONS_PCF_R        = zeros(length(years),1);
    CUM_CO2_EMISSIONS_PCF_R         = zeros(length(years),1);     
    FLUX_CO2_EMISSIONS_GTCO2_PCF_R  = zeros(length(years),1);
    CUM_CO2_EMISSIONS_GTCO2_PCF_R   = zeros(length(years),1);  
    CH4_CONC_PCF_R                  = zeros(length(years),1);
    CH4_CONC_PPMV_PCF_R             = zeros(length(years),1);
    RAD_CH4_PCF_R                   = zeros(length(years),1);            
    RAD_N2O_PCF_R                   = zeros(length(years),1);          
    RAD_TOT_PCF_R                   = zeros(length(years),1);          
        
%--------------------------------------------------------------------------
% Calculate paths for variables that DO NOT depend on emissions levels (noted NAME_0)    
%--------------------------------------------------------------------------             
        
    % Variables
    % L_0         = Population
    % GFACPOP_0   = Growth factor of population
    % GA_0        = Growth rate of productivity
    % AL_0        = Level of total factor productivity
    % GSIG_0      = Cumulative improvement of energy efficiency
    % SIGMA_0     = Co2-eq emissions-output ratio
    % FORCOTH_0   = Exogenous forcing
    % PARTFRACT_0 = Fraction of emissions in control regime
    % ETREE_0     = Emissions from land use change
    % COST1_0     = Adjusted cost for backstop
        
    % Paths initialization:
    L_0(1)          = POP0;
    GA_0(1)         = GA0_5yrs; 
    AL_0(1)         = AL0;
    GSIG_0(1)       = GSIGMA1; 
    SIGMA_0(1)      = SIG0;
    PBACKTIME_0(1)  = PBACK;
    COST1_0(1)      = PBACK*SIGMA_0(1)/EXPCOST2/1000;
    ETREE_0(1)      = ELAND0;
    FORCOTH_0(1)    = FEX0+0.05*(FEX1-FEX0)*(1+1);
    PARTFRACT_0(1)  = PARTFRACT2010;
    
    % Paths calculations:
    t = 1;
    for year = years(1:end)'; t = t + 1;
        L_0(t)= L_0(t-1)*(POPASYM/L_0(t-1))^POPADJ; 
        GA_0(t) = GA0_5yrs*exp(-DELA*TSTEP*(t-1)); 
        AL_0(t) = AL_0(t-1)/((1-GA_0(t-1))); 
            
        % **GSIG** - first value of GSIG = GSIGMA1 is for year 2 (as GSIG = growth rate)
        if t<=2
        GSIG_0(t)  = GSIGMA1;
        elseif t>2
        GSIG_0(t)  = GSIG_0(t-1)*((1+DSIG)^TSTEP);
        end;
        
        SIGMA_0(t) = SIGMA_0(t-1)*(exp(GSIG_0(t)*TSTEP));
        PBACKTIME_0(t) = PBACK*(1-GBACK)^(t-1);
        COST1_0(t)  = PBACKTIME_0(t)*SIGMA_0(t)/EXPCOST2/1000;
        ETREE_0(t) = ELAND0*((1-DELAND)^(t-1)); 
        
        % **FORCOTH** - change after period 19
        if t<19
        FORCOTH_0(t) = FEX0+0.05*(FEX1-FEX0)*(t+1); % as in the Excel model for DICE 2013R on Nordhaus' website
        elseif t>=19
        FORCOTH_0(t) = FEX1;
        end;
                
        PARTFRACT_0(t) = (PARTFRACT2010 + (PARTFRACTFULL-PARTFRACT2010)*(t-1)/PERIODFULLPART)*(t<PERIODFULLPART+1) + PARTFRACTFULL*(t>PERIODFULLPART) ;
    end;
  
%--------------------------------------------------------------------------
% Calculate paths for variables that DO depend on emissions levels (noted NAME_0)    
%--------------------------------------------------------------------------                
       
    % Reference paths initialization:
    K_PCF_R(1)                        = K0; 
    YGROSS_PCF_R(1)                   = AL_0(1)*(L_0(1)/1000)^(1-GAMMA)*(K_PCF_R(1)^GAMMA);
    YGROSS_PCF_R(1)                   = round(YGROSS_PCF_R(1)*1e3)/1e3;
    EIND_PCF_R(1)                     = SIGMA_0(1)*(1-MIU(1))*YGROSS_PCF_R(1);
    CumEIND_PCF_R(1)                  = EIND_PCF_R(1)*coeff_CO2*5;
    E_PCF_R(1)                        = EIND_PCF_R(1)+ ETREE_0(1);
    MAT_PCF_R(1)                      = MAT0;
    ML_PCF_R(1)                       = ML0; 
    MU_PCF_R(1)                       = MU0; 
    FORC_PCF_R(1)                     = FCO22X*log((MAT_PCF_R(1)/588.000))/log(2) + FORCOTH_0(1); 
    TATM_PCF_R(1)                     = TATM0;
    
    PROP_REMAIN_PCF_R(1)              = 1;
    CUM_THAWED_PCF_R(1)               =(1-PROP_REMAIN_PCF_R(1))*PF_C;
    FLUX_THAWED_PCF_R(1)              = CUM_THAWED_PCF_R(1)-CUM_THAWED_PCF_R(1);
    FLUX_VULN_PCF_R(1)                = (1-prop_passive)*FLUX_THAWED_PCF_R(1);
    CUM_PROP_DECOMP_PCF_R(1)          = 0;
    FLUX_PROP_DECOMP_PCF_R(1)         = 0;
    FLUX_C_EMISSIONS_PCF_R(1)         = FLUX_PROP_DECOMP_PCF_R(1)*FLUX_VULN_PCF_R(1);
    CUM_C_EMISSIONS_PCF_R(1)          = FLUX_C_EMISSIONS_PCF_R(1);
    FLUX_CH4_EMISSIONS_PCF_R(1)       = FLUX_C_EMISSIONS_PCF_R(1)*prop_CH4*1000*coeff_CH4;
    CUM_CH4_EMISSIONS_PCF_R(1)        = FLUX_CH4_EMISSIONS_PCF_R(1);
    FLUX_CO2_EMISSIONS_PCF_R(1)       = FLUX_C_EMISSIONS_PCF_R(1)*(1-prop_CH4);
    CUM_CO2_EMISSIONS_PCF_R(1)        = FLUX_CO2_EMISSIONS_PCF_R(1);
    FLUX_CO2_EMISSIONS_GTCO2_PCF_R(1) = FLUX_C_EMISSIONS_PCF_R(1)*(1-prop_CH4)/coeff_CO2;
    CUM_CO2_EMISSIONS_GTCO2_PCF_R(1)  = FLUX_CO2_EMISSIONS_GTCO2_PCF_R(1);
    CH4_CONC_PCF_R(1)                 = CH4_CONC0;
    CH4_CONC_PPMV_PCF_R(1)            = CH4_CONC_PCF_R(1)/CH4_conv;
    RAD_CH4_PCF_R(1)                  = CH4_lambda*(CH4_CONC_PPMV_PCF_R(1)^0.5-CH4_M0^0.5)-(0.47*log(1+2.01*10^(-5)*(CH4_CONC_PPMV_PCF_R(1)*N2O_CONC_0(1))^0.75+5.31*10^(-15)*CH4_CONC_PPMV_PCF_R(1)*(CH4_CONC_PPMV_PCF_R(1)*N2O_CONC_0(1))^1.52)-0.47*log(1+2.01*10^(-5)*(CH4_M0*N2O_CONC_0(1))^0.75+5.31*10^(-15)*CH4_M0*(CH4_M0*N2O_CONC_0(1))^1.52));
    RAD_N2O_PCF_R(1)                  = CH4_mu*(N2O_CONC_0(1)^0.5-N2O_N0^0.5)-(0.47*log(1+2.01*10^(-5)*(CH4_CONC_PPMV_PCF_R(1)*N2O_CONC_0(1))^0.75+5.31*10^(-15)*CH4_CONC_PPMV_PCF_R(1)*(CH4_CONC_PPMV_PCF_R(1)*N2O_CONC_0(1))^1.52)-0.47*log(1+2.01*10^(-5)*(CH4_CONC_PPMV_PCF_R(1)*N2O_N0)^0.75+5.31*10^(-15)*CH4_CONC_PPMV_PCF_R(1)*(CH4_CONC_PPMV_PCF_R(1)*N2O_N0)^1.52));
    RAD_TOT_PCF_R(1)                  = RAD_CH4_PCF_R(1)+ RAD_N2O_PCF_R(1) + RAD_OTHER_PCF_0(1);
    
    TOCEAN_PCF_R(1)                 = TOCEAN0; 
    
        % Damages (quadratic or as in Dietz and Asheim, depending on the
        % initial setting - cf lines 35-40) 
        if QUADRATIC == 1
        DAMAGES_PCF_R(1) = YGROSS_PCF_R(1)*(AD1*TATM_PCF_R(1) + AD2*TATM_PCF_R(1)^2)/(1+(AD1*TATM_PCF_R(1) + AD2*TATM_PCF_R(1)^2)^10);
        REL_DAMAGES_PCF_R(1) = AD1*TATM_PCF_R(1) + AD2*TATM_PCF_R(1)^2;
        elseif WEITZMAN == 1
        DAMAGES_PCF_R(1) = YGROSS_PCF_R(1)-YGROSS_PCF_R(1)/(1 + (AW2*TATM_PCF_R(1))^2 + (AW7*TATM_PCF_R(1))^AWGAMMA);
        REL_DAMAGES_PCF_R(1) = 1-1/(1 + (AW2*TATM_PCF_R(1))^2 + (AW7*TATM_PCF_R(1))^AWGAMMA);
        end;
        
    YNET_PCF_R(1)                   = YGROSS_PCF_R(1)-DAMAGES_PCF_R(1);
    ABATECOST_PCF_R(1)              = (PARTFRACT_0(1)^(1-EXPCOST2))*YGROSS_PCF_R(1)*COST1_0(1)*(MIU(1)^EXPCOST2);
    Y_PCF_R(1)                      = YNET_PCF_R(1)-ABATECOST_PCF_R(1);
    I_PCF_R(1)                      = S(1)*Y_PCF_R(1);
    C_PCF_R(1)                      = max(C_LOW, Y_PCF_R(1)-I_PCF_R(1));
    CperC_PCF_R(1)                  = (C_PCF_R(1)/L_0(1))*1000;
    K_PCF_R(2)                      = max(K_LOW, ((1-DK)^TSTEP)*K_PCF_R(1)+TSTEP*I_PCF_R(1));
    YGROSS_PCF_R(2)                 = AL_0(2)*(L_0(2)/1000)^(1-GAMMA)*(K_PCF_R(2)^GAMMA);
    EIND_PCF_R(2)                   = SIGMA_0(2)*(1-MIU(2))*YGROSS_PCF_R(2);
    
    % Reference paths calculations:
    t=1;
    for year = years(1:end-1)'; t = t + 1;
        CumEIND_PCF_R(t)            = CumEIND_PCF_R(t-1) + EIND_PCF_R(t)*coeff_CO2*5;
        MAT_PCF_R(t)                = max(MAT_LOW, B11/100*MAT_PCF_R(t-1) + B21/100*MU_PCF_R(t-1) + E_PCF_R(t-1)*5/coeff_CO2); % cf lower bound MAT_LOW
        ML_PCF_R(t)                 = max(ML_LOW, B23/100*MU_PCF_R(t-1) + B33/100*ML_PCF_R(t-1)); % cf lower bound ML_LOW
        MU_PCF_R(t)                 = max(MU_LOW, B12/100*MAT_PCF_R(t-1) + B22/100*MU_PCF_R(t-1) + B32/100*ML_PCF_R(t-1)); % cf lower bound MU_LOW
        
        if PCF == 0
            FORC_PCF_R(t)           = FCO22X * (log((MAT_PCF_R(t)/588.000))/log(2)) + FORCOTH_0(t); 
        elseif PCF == 1
            FORC_PCF_R(t)           = FCO22X * (log((MAT_PCF_R(t)/588.000))/log(2)) + RAD_TOT_PCF_R(t-1);
        end;
           
        TATM_PCF_R(t)               = min(TATM_HIGH, TATM_PCF_R(t-1) + C1*(FORC_PCF_R(t) - FCO22X/T2XCO2*TATM_PCF_R(t-1) - C3*(TATM_PCF_R(t-1) - TOCEAN_PCF_R(t-1))));
        
        % PCF MODULE: THAWING (GtC)
        PROP_REMAIN_PCF_R(t)       = max(1-PCF_beta*(TATM_PCF_R(t)-TATM_PCF_R(1)),0);
        CUM_THAWED_PCF_R(t)         = (1-PROP_REMAIN_PCF_R(t))*PF_C;
        FLUX_THAWED_PCF_R(t)        = CUM_THAWED_PCF_R(t)-CUM_THAWED_PCF_R(t-1);
                
        % PCF MODULE: CARBON DECOMPOSITION SCHEDULE
        CUM_PROP_DECOMP_PCF_R(t)    = (1-exp(-5*(t-1)/e_fold));
        FLUX_PROP_DECOMP_PCF_R(t)   = CUM_PROP_DECOMP_PCF_R(t)-CUM_PROP_DECOMP_PCF_R(t-1); % DO NOT PREALLOCATE FOR SPEED (cf flip)
        
        % PCF MODULE: VULNERABLE CARBON (GtC)
        FLUX_VULN_PCF_R(t)          = (1-prop_passive)*FLUX_THAWED_PCF_R(t);
        
        % PCF MODULE: DECOMPOSED CARBON (GtC)
        FLUX_C_EMISSIONS_PCF_R(t)   = sum(FLUX_VULN_PCF_R(1:t).*flip(FLUX_PROP_DECOMP_PCF_R(1:t)));
        CUM_C_EMISSIONS_PCF_R(t)    = CUM_C_EMISSIONS_PCF_R(t-1)+ FLUX_C_EMISSIONS_PCF_R(t);
        
        % PCF MODULE: METHANE EMISSIONS(Tg CH4)
        FLUX_CH4_EMISSIONS_PCF_R(t) = FLUX_C_EMISSIONS_PCF_R(t)*prop_CH4*1000*coeff_CH4;
        CUM_CH4_EMISSIONS_PCF_R(t)  = CUM_CH4_EMISSIONS_PCF_R(t-1)+FLUX_CH4_EMISSIONS_PCF_R(t);
        
        % PCF MODULE: CO2 EMISSIONS(GtC)
        FLUX_CO2_EMISSIONS_PCF_R(t) = FLUX_C_EMISSIONS_PCF_R(t)*(1-prop_CH4);
        CUM_CO2_EMISSIONS_PCF_R(t)  = CUM_CO2_EMISSIONS_PCF_R(t-1)+FLUX_CO2_EMISSIONS_PCF_R(t);
        
        % PCF MODULE: CO2 EMISSIONS(GtC)
        FLUX_CO2_EMISSIONS_GTCO2_PCF_R(t) = FLUX_C_EMISSIONS_PCF_R(t)*(1-prop_CH4)/coeff_CO2;
        CUM_CO2_EMISSIONS_GTCO2_PCF_R(t)  = CUM_CO2_EMISSIONS_GTCO2_PCF_R(t-1)+FLUX_CO2_EMISSIONS_GTCO2_PCF_R(t);
        
        % METHANE CYCLE (Tg CH4)
        CH4_CONC_PCF_R(t)           = CH4_CONC_PCF_R(t-1)*(1-1/CH4_net_lft)+FLUX_CH4_EMISSIONS_PCF_R(t) + CH4_OTHER_EMISSIONS_0(t);
        CH4_CONC_PPMV_PCF_R(t)      = CH4_CONC_PCF_R(t)/CH4_conv; 

        % RADIATIVE FORCING FROM CH4 AND N2O
        RAD_CH4_PCF_R(t)            = CH4_lambda*(CH4_CONC_PPMV_PCF_R(t)^0.5-CH4_M0^0.5)-(0.47*log(1+2.01*10^(-5)*(CH4_CONC_PPMV_PCF_R(t)*N2O_CONC_0(t))^0.75+5.31*10^(-15)*CH4_CONC_PPMV_PCF_R(t)*(CH4_CONC_PPMV_PCF_R(t)*N2O_CONC_0(t))^1.52)-0.47*log(1+2.01*10^(-5)*(CH4_M0*N2O_CONC_0(t))^0.75+5.31*10^(-15)*CH4_M0*(CH4_M0*N2O_CONC_0(t))^1.52));
        RAD_N2O_PCF_R(t)            = CH4_mu*(N2O_CONC_0(t)^0.5-N2O_N0^0.5)-(0.47*log(1+2.01*10^(-5)*(CH4_CONC_PPMV_PCF_R(t)*N2O_CONC_0(t))^0.75+5.31*10^(-15)*CH4_CONC_PPMV_PCF_R(t)*(CH4_CONC_PPMV_PCF_R(t)*N2O_CONC_0(t))^1.52)-0.47*log(1+2.01*10^(-5)*(CH4_CONC_PPMV_PCF_R(t)*N2O_N0)^0.75+5.31*10^(-15)*CH4_CONC_PPMV_PCF_R(t)*(CH4_CONC_PPMV_PCF_R(t)*N2O_N0)^1.52));
        
                                                   
        
        % TOTAL NON CO2 RADIATIVE FORCING
        RAD_TOT_PCF_R(t)            = RAD_CH4_PCF_R(t)+ RAD_N2O_PCF_R(t)+ RAD_OTHER_PCF_0(t);

        
        if PCF == 0
            E_PCF_R(t)              = EIND_PCF_R(t)+ ETREE_0(t); 
        elseif PCF == 1
            E_PCF_R(t)              = EIND_PCF_R(t)+ ETREE_0(t)+FLUX_CO2_EMISSIONS_PCF_R(t)/5*coeff_CO2;
        end;
                    
        % Upper and lower bounds on atmospheric temperature
        if TOCEAN_PCF_R(t-1) + C4*(TATM_PCF_R(t-1)-TOCEAN_PCF_R(t-1))>=0
        TOCEAN_PCF_R(t)    = min(TOCEAN_HIGH, TOCEAN_PCF_R(t-1) + C4*(TATM_PCF_R(t-1)-TOCEAN_PCF_R(t-1)));
            elseif TOCEAN_PCF_R(t-1) + C4*(TATM_PCF_R(t-1)-TOCEAN_PCF_R(t-1))<0
        TOCEAN_PCF_R(t)    = max(TOCEAN_LOW, TOCEAN_PCF_R(t-1) + C4*(TATM_PCF_R(t-1)-TOCEAN_PCF_R(t-1)));
        end;
        
        % Damages (quadratic or as in Dietz and Asheim, depending on the
        % initial setting - cf lines 35-40) 
        if QUADRATIC == 1
        DAMAGES_PCF_R(t) = YGROSS_PCF_R(t)*(AD1*TATM_PCF_R(t) + AD2*TATM_PCF_R(t)^2)/(1+(AD1*TATM_PCF_R(t) + AD2*TATM_PCF_R(t)^2)^10);
        REL_DAMAGES_PCF_R(t) = AD1*TATM_PCF_R(t) + AD2*TATM_PCF_R(t)^2;
            elseif WEITZMAN == 1
        DAMAGES_PCF_R(t) = YGROSS_PCF_R(t)-YGROSS_PCF_R(t)/(1 + (AW2*TATM_PCF_R(t))^2 + (AW7*TATM_PCF_R(t))^AWGAMMA);
        REL_DAMAGES_PCF_R(t) = 1-1/(1 + (AW2*TATM_PCF_R(t))^2 + (AW7*TATM_PCF_R(t))^AWGAMMA);
        end;
                       
        YNET_PCF_R(t)      = YGROSS_PCF_R(t)-DAMAGES_PCF_R(t);
        ABATECOST_PCF_R(t) = (PARTFRACT_0(t)^(1-EXPCOST2))*YGROSS_PCF_R(t)*COST1_0(t)*(MIU(t)^EXPCOST2);
        Y_PCF_R(t)         = YNET_PCF_R(t)-ABATECOST_PCF_R(t);
        I_PCF_R(t)         = S(t)*Y_PCF_R(t);
        C_PCF_R(t)         = max(C_LOW, Y_PCF_R(t)-I_PCF_R(t));
        CperC_PCF_R(t)     = (C_PCF_R(t)/L_0(t))*1000;
        K_PCF_R(t+1)       = ((1-DK)^TSTEP)*K_PCF_R(t)+TSTEP*I_PCF_R(t);
        YGROSS_PCF_R(t+1)  = AL_0(t+1)*((L_0(t+1)/1000)^(1-GAMMA))*(K_PCF_R(t+1)^GAMMA);
        EIND_PCF_R(t+1)    = SIGMA_0(t+1)*(1-MIU(t+1))*YGROSS_PCF_R(t+1); 
    end;          
 
%--------------------------------------------------------------------------
% Constraints    
%--------------------------------------------------------------------------       
    
        constraint_vect = 2*ones(length(years),1);
        c = [TATM_PCF_R - constraint_vect]';  

% No nonlinear equality constraint
        ceq = [];
    

end

